package androidx.appcompat.graphics.drawable;

import android.animation.ObjectAnimator;
import android.animation.TimeInterpolator;
import android.annotation.SuppressLint;
import android.content.Context;
import android.content.res.Resources;
import android.content.res.TypedArray;
import android.graphics.drawable.Animatable;
import android.graphics.drawable.AnimationDrawable;
import android.graphics.drawable.Drawable;
import android.util.AttributeSet;
import android.util.StateSet;
import androidx.appcompat.graphics.drawable.DrawableContainer;
import androidx.appcompat.graphics.drawable.StateListDrawable;
import androidx.appcompat.resources.R$styleable;
import androidx.appcompat.widget.ResourceManagerInternal;
import androidx.collection.LongSparseArray;
import androidx.collection.SparseArrayCompat;
import androidx.core.content.res.ResourcesCompat$ThemeCompat;
import androidx.core.graphics.drawable.TintAwareDrawable;
import androidx.vectordrawable.graphics.drawable.AnimatedVectorDrawableCompat;
import androidx.vectordrawable.graphics.drawable.VectorDrawableCompat;
import com.android.tools.r8.GeneratedOutlineSupport;
import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;

@SuppressLint({"RestrictedAPI"})
public class AnimatedStateListDrawableCompat extends StateListDrawable implements TintAwareDrawable {
    public boolean mMutated;
    public AnimatedStateListState mState;
    public Transition mTransition;
    public int mTransitionFromIndex = -1;
    public int mTransitionToIndex = -1;

    public class AnimatableTransition extends Transition {
        public final Animatable mA;

        public AnimatableTransition(Animatable animatable) {
            super(null);
            this.mA = animatable;
        }

        @Override // androidx.appcompat.graphics.drawable.AnimatedStateListDrawableCompat.Transition
        public void start() {
            this.mA.start();
        }

        @Override // androidx.appcompat.graphics.drawable.AnimatedStateListDrawableCompat.Transition
        public void stop() {
            this.mA.stop();
        }
    }

    public class AnimatedStateListState extends StateListDrawable.StateListState {
        public SparseArrayCompat<Integer> mStateIds;
        public LongSparseArray<Long> mTransitions;

        public AnimatedStateListState(AnimatedStateListState animatedStateListState, AnimatedStateListDrawableCompat animatedStateListDrawableCompat, Resources resources) {
            super(animatedStateListState, animatedStateListDrawableCompat, resources);
            if (animatedStateListState != null) {
                this.mTransitions = animatedStateListState.mTransitions;
                this.mStateIds = animatedStateListState.mStateIds;
                return;
            }
            this.mTransitions = new LongSparseArray<>();
            this.mStateIds = new SparseArrayCompat<>();
        }

        public static long generateTransitionKey(int i, int i2) {
            return ((long) i2) | (((long) i) << 32);
        }

        public int getKeyframeIdAt(int i) {
            if (i < 0) {
                return 0;
            }
            return this.mStateIds.get(i, 0).intValue();
        }

        @Override // androidx.appcompat.graphics.drawable.DrawableContainer.DrawableContainerState
        public void mutate() {
            this.mTransitions = this.mTransitions.clone();
            this.mStateIds = this.mStateIds.clone();
        }

        public Drawable newDrawable() {
            return new AnimatedStateListDrawableCompat(this, null);
        }

        public Drawable newDrawable(Resources resources) {
            return new AnimatedStateListDrawableCompat(this, resources);
        }
    }

    public class AnimatedVectorDrawableTransition extends Transition {
        public final AnimatedVectorDrawableCompat mAvd;

        public AnimatedVectorDrawableTransition(AnimatedVectorDrawableCompat animatedVectorDrawableCompat) {
            super(null);
            this.mAvd = animatedVectorDrawableCompat;
        }

        @Override // androidx.appcompat.graphics.drawable.AnimatedStateListDrawableCompat.Transition
        public void start() {
            this.mAvd.start();
        }

        @Override // androidx.appcompat.graphics.drawable.AnimatedStateListDrawableCompat.Transition
        public void stop() {
            this.mAvd.stop();
        }
    }

    public class AnimationDrawableTransition extends Transition {
        public final ObjectAnimator mAnim;
        public final boolean mHasReversibleFlag;

        public AnimationDrawableTransition(AnimationDrawable animationDrawable, boolean z, boolean z2) {
            super(null);
            int numberOfFrames = animationDrawable.getNumberOfFrames();
            int i = z ? numberOfFrames - 1 : 0;
            int i2 = z ? 0 : numberOfFrames - 1;
            FrameInterpolator frameInterpolator = new FrameInterpolator(animationDrawable, z);
            ObjectAnimator ofInt = ObjectAnimator.ofInt(animationDrawable, "currentIndex", i, i2);
            ofInt.setAutoCancel(true);
            ofInt.setDuration((long) frameInterpolator.mTotalDuration);
            ofInt.setInterpolator(frameInterpolator);
            this.mHasReversibleFlag = z2;
            this.mAnim = ofInt;
        }

        @Override // androidx.appcompat.graphics.drawable.AnimatedStateListDrawableCompat.Transition
        public boolean canReverse() {
            return this.mHasReversibleFlag;
        }

        @Override // androidx.appcompat.graphics.drawable.AnimatedStateListDrawableCompat.Transition
        public void reverse() {
            this.mAnim.reverse();
        }

        @Override // androidx.appcompat.graphics.drawable.AnimatedStateListDrawableCompat.Transition
        public void start() {
            this.mAnim.start();
        }

        @Override // androidx.appcompat.graphics.drawable.AnimatedStateListDrawableCompat.Transition
        public void stop() {
            this.mAnim.cancel();
        }
    }

    public class FrameInterpolator implements TimeInterpolator {
        public int[] mFrameTimes;
        public int mFrames;
        public int mTotalDuration;

        public FrameInterpolator(AnimationDrawable animationDrawable, boolean z) {
            int numberOfFrames = animationDrawable.getNumberOfFrames();
            this.mFrames = numberOfFrames;
            int[] iArr = this.mFrameTimes;
            if (iArr == null || iArr.length < numberOfFrames) {
                this.mFrameTimes = new int[numberOfFrames];
            }
            int[] iArr2 = this.mFrameTimes;
            int i = 0;
            for (int i2 = 0; i2 < numberOfFrames; i2++) {
                int duration = animationDrawable.getDuration(z ? (numberOfFrames - i2) - 1 : i2);
                iArr2[i2] = duration;
                i += duration;
            }
            this.mTotalDuration = i;
        }

        public float getInterpolation(float f) {
            int i = (int) ((f * ((float) this.mTotalDuration)) + 0.5f);
            int i2 = this.mFrames;
            int[] iArr = this.mFrameTimes;
            int i3 = 0;
            while (i3 < i2 && i >= iArr[i3]) {
                i -= iArr[i3];
                i3++;
            }
            return (((float) i3) / ((float) i2)) + (i3 < i2 ? ((float) i) / ((float) this.mTotalDuration) : 0.0f);
        }
    }

    public abstract class Transition {
        public Transition(AnonymousClass1 r1) {
        }

        public boolean canReverse() {
            return false;
        }

        public void reverse() {
        }

        public abstract void start();

        public abstract void stop();
    }

    public AnimatedStateListDrawableCompat(AnimatedStateListState animatedStateListState, Resources resources) {
        super(null);
        setConstantState(new AnimatedStateListState(animatedStateListState, this, resources));
        onStateChange(getState());
        jumpToCurrentState();
    }

    /* JADX WARNING: Code restructure failed: missing block: B:75:0x0207, code lost:
        throw new org.xmlpull.v1.XmlPullParserException(com.android.tools.r8.GeneratedOutlineSupport.outline23(r20, new java.lang.StringBuilder(), ": <transition> tag requires 'fromId' & 'toId' attributes"));
     */
    public static AnimatedStateListDrawableCompat createFromXmlInner(Context context, Resources resources, XmlPullParser xmlPullParser, AttributeSet attributeSet, Resources.Theme theme) {
        int depth;
        int next;
        int next2;
        AttributeSet attributeSet2 = attributeSet;
        Resources.Theme theme2 = theme;
        String name = xmlPullParser.getName();
        if (name.equals("animated-selector")) {
            Drawable drawable = null;
            AnimatedStateListDrawableCompat animatedStateListDrawableCompat = new AnimatedStateListDrawableCompat(null, null);
            TypedArray obtainAttributes = ResourcesCompat$ThemeCompat.obtainAttributes(resources, theme2, attributeSet2, R$styleable.AnimatedStateListDrawableCompat);
            int i = 1;
            animatedStateListDrawableCompat.setVisible(obtainAttributes.getBoolean(R$styleable.AnimatedStateListDrawableCompat_android_visible, true), true);
            AnimatedStateListState animatedStateListState = animatedStateListDrawableCompat.mState;
            animatedStateListState.mChangingConfigurations |= obtainAttributes.getChangingConfigurations();
            animatedStateListState.mVariablePadding = obtainAttributes.getBoolean(R$styleable.AnimatedStateListDrawableCompat_android_variablePadding, animatedStateListState.mVariablePadding);
            animatedStateListState.mConstantSize = obtainAttributes.getBoolean(R$styleable.AnimatedStateListDrawableCompat_android_constantSize, animatedStateListState.mConstantSize);
            animatedStateListState.mEnterFadeDuration = obtainAttributes.getInt(R$styleable.AnimatedStateListDrawableCompat_android_enterFadeDuration, animatedStateListState.mEnterFadeDuration);
            animatedStateListState.mExitFadeDuration = obtainAttributes.getInt(R$styleable.AnimatedStateListDrawableCompat_android_exitFadeDuration, animatedStateListState.mExitFadeDuration);
            animatedStateListDrawableCompat.setDither(obtainAttributes.getBoolean(R$styleable.AnimatedStateListDrawableCompat_android_dither, animatedStateListState.mDither));
            animatedStateListDrawableCompat.mDrawableContainerState.updateDensity(resources);
            obtainAttributes.recycle();
            int depth2 = xmlPullParser.getDepth() + 1;
            Context context2 = context;
            Resources resources2 = resources;
            while (true) {
                int next3 = xmlPullParser.next();
                if (next3 == i || ((depth = xmlPullParser.getDepth()) < depth2 && next3 == 3)) {
                    animatedStateListDrawableCompat.onStateChange(animatedStateListDrawableCompat.getState());
                } else if (next3 == 2 && depth <= depth2) {
                    if (xmlPullParser.getName().equals("item")) {
                        TypedArray obtainAttributes2 = ResourcesCompat$ThemeCompat.obtainAttributes(resources2, theme2, attributeSet2, R$styleable.AnimatedStateListDrawableItem);
                        int resourceId = obtainAttributes2.getResourceId(R$styleable.AnimatedStateListDrawableItem_android_id, 0);
                        int resourceId2 = obtainAttributes2.getResourceId(R$styleable.AnimatedStateListDrawableItem_android_drawable, -1);
                        if (resourceId2 > 0) {
                            drawable = ResourceManagerInternal.get().getDrawable(context2, resourceId2);
                        }
                        obtainAttributes2.recycle();
                        int attributeCount = attributeSet.getAttributeCount();
                        int[] iArr = new int[attributeCount];
                        int i2 = 0;
                        for (int i3 = 0; i3 < attributeCount; i3++) {
                            int attributeNameResource = attributeSet2.getAttributeNameResource(i3);
                            if (!(attributeNameResource == 0 || attributeNameResource == 16842960 || attributeNameResource == 16843161)) {
                                int i4 = i2 + 1;
                                if (!attributeSet2.getAttributeBooleanValue(i3, false)) {
                                    attributeNameResource = -attributeNameResource;
                                }
                                iArr[i2] = attributeNameResource;
                                i2 = i4;
                            }
                        }
                        int[] trimStateSet = StateSet.trimStateSet(iArr, i2);
                        if (drawable == null) {
                            do {
                                next2 = xmlPullParser.next();
                            } while (next2 == 4);
                            if (next2 != 2) {
                                throw new XmlPullParserException(GeneratedOutlineSupport.outline23(xmlPullParser, new StringBuilder(), ": <item> tag requires a 'drawable' attribute or child tag defining a drawable"));
                            } else if (xmlPullParser.getName().equals("vector")) {
                                drawable = VectorDrawableCompat.createFromXmlInner(resources, xmlPullParser, attributeSet, theme);
                            } else {
                                drawable = Drawable.createFromXmlInner(resources, xmlPullParser, attributeSet, theme);
                            }
                        }
                        if (drawable != null) {
                            AnimatedStateListState animatedStateListState2 = animatedStateListDrawableCompat.mState;
                            int addChild = animatedStateListState2.addChild(drawable);
                            animatedStateListState2.mStateSets[addChild] = trimStateSet;
                            animatedStateListState2.mStateIds.put(addChild, Integer.valueOf(resourceId));
                        } else {
                            throw new XmlPullParserException(GeneratedOutlineSupport.outline23(xmlPullParser, new StringBuilder(), ": <item> tag requires a 'drawable' attribute or child tag defining a drawable"));
                        }
                    } else {
                        if (xmlPullParser.getName().equals("transition")) {
                            TypedArray obtainAttributes3 = ResourcesCompat$ThemeCompat.obtainAttributes(resources2, theme2, attributeSet2, R$styleable.AnimatedStateListDrawableTransition);
                            int resourceId3 = obtainAttributes3.getResourceId(R$styleable.AnimatedStateListDrawableTransition_android_fromId, -1);
                            int resourceId4 = obtainAttributes3.getResourceId(R$styleable.AnimatedStateListDrawableTransition_android_toId, -1);
                            int resourceId5 = obtainAttributes3.getResourceId(R$styleable.AnimatedStateListDrawableTransition_android_drawable, -1);
                            AnimatedVectorDrawableCompat drawable2 = resourceId5 > 0 ? ResourceManagerInternal.get().getDrawable(context2, resourceId5) : null;
                            boolean z = obtainAttributes3.getBoolean(R$styleable.AnimatedStateListDrawableTransition_android_reversible, false);
                            obtainAttributes3.recycle();
                            AnimatedVectorDrawableCompat animatedVectorDrawableCompat = drawable2;
                            if (drawable2 == null) {
                                do {
                                    next = xmlPullParser.next();
                                } while (next == 4);
                                if (next != 2) {
                                    throw new XmlPullParserException(GeneratedOutlineSupport.outline23(xmlPullParser, new StringBuilder(), ": <transition> tag requires a 'drawable' attribute or child tag defining a drawable"));
                                } else if (xmlPullParser.getName().equals("animated-vector")) {
                                    AnimatedVectorDrawableCompat animatedVectorDrawableCompat2 = new AnimatedVectorDrawableCompat(context2, null, null);
                                    animatedVectorDrawableCompat2.inflate(resources2, xmlPullParser, attributeSet2, theme2);
                                    animatedVectorDrawableCompat = animatedVectorDrawableCompat2;
                                } else {
                                    animatedVectorDrawableCompat = Drawable.createFromXmlInner(resources, xmlPullParser, attributeSet, theme);
                                }
                            }
                            if (animatedVectorDrawableCompat == null) {
                                throw new XmlPullParserException(GeneratedOutlineSupport.outline23(xmlPullParser, new StringBuilder(), ": <transition> tag requires a 'drawable' attribute or child tag defining a drawable"));
                            } else if (resourceId3 != -1 && resourceId4 != -1) {
                                AnimatedStateListState animatedStateListState3 = animatedStateListDrawableCompat.mState;
                                int addChild2 = animatedStateListState3.addChild(animatedVectorDrawableCompat);
                                long generateTransitionKey = AnimatedStateListState.generateTransitionKey(resourceId3, resourceId4);
                                long j = z ? 8589934592L : 0;
                                long j2 = (long) addChild2;
                                animatedStateListState3.mTransitions.append(generateTransitionKey, Long.valueOf(j2 | j));
                                if (z) {
                                    animatedStateListState3.mTransitions.append(AnimatedStateListState.generateTransitionKey(resourceId4, resourceId3), Long.valueOf(j2 | 4294967296L | j));
                                }
                            }
                        }
                        context2 = context;
                        resources2 = resources;
                    }
                    drawable = null;
                    i = 1;
                    attributeSet2 = attributeSet;
                    theme2 = theme;
                }
            }
            animatedStateListDrawableCompat.onStateChange(animatedStateListDrawableCompat.getState());
            return animatedStateListDrawableCompat;
        }
        throw new XmlPullParserException(xmlPullParser.getPositionDescription() + ": invalid animated-selector tag " + name);
    }

    public boolean isStateful() {
        return true;
    }

    @Override // androidx.appcompat.graphics.drawable.DrawableContainer
    public void jumpToCurrentState() {
        super.jumpToCurrentState();
        Transition transition = this.mTransition;
        if (transition != null) {
            transition.stop();
            this.mTransition = null;
            selectDrawable(this.mTransitionToIndex);
            this.mTransitionToIndex = -1;
            this.mTransitionFromIndex = -1;
        }
    }

    @Override // androidx.appcompat.graphics.drawable.DrawableContainer, androidx.appcompat.graphics.drawable.StateListDrawable
    public Drawable mutate() {
        if (!this.mMutated) {
            super.mutate();
            if (this == this) {
                this.mState.mutate();
                this.mMutated = true;
            }
        }
        return this;
    }

    @Override // androidx.appcompat.graphics.drawable.StateListDrawable
    public boolean onStateChange(int[] iArr) {
        boolean z;
        Transition transition;
        AnimatedStateListState animatedStateListState = this.mState;
        int indexOfStateSet = animatedStateListState.indexOfStateSet(iArr);
        if (indexOfStateSet < 0) {
            indexOfStateSet = animatedStateListState.indexOfStateSet(StateSet.WILD_CARD);
        }
        int i = this.mCurIndex;
        boolean z2 = false;
        if (indexOfStateSet != i) {
            Transition transition2 = this.mTransition;
            if (transition2 != null) {
                if (indexOfStateSet != this.mTransitionToIndex) {
                    if (indexOfStateSet != this.mTransitionFromIndex || !transition2.canReverse()) {
                        i = this.mTransitionToIndex;
                        transition2.stop();
                    } else {
                        transition2.reverse();
                        this.mTransitionToIndex = this.mTransitionFromIndex;
                        this.mTransitionFromIndex = indexOfStateSet;
                    }
                }
                z = true;
                if (z || selectDrawable(indexOfStateSet)) {
                    z2 = true;
                }
            }
            this.mTransition = null;
            this.mTransitionFromIndex = -1;
            this.mTransitionToIndex = -1;
            AnimatedStateListState animatedStateListState2 = this.mState;
            int keyframeIdAt = animatedStateListState2.getKeyframeIdAt(i);
            int keyframeIdAt2 = animatedStateListState2.getKeyframeIdAt(indexOfStateSet);
            if (!(keyframeIdAt2 == 0 || keyframeIdAt == 0)) {
                int longValue = (int) animatedStateListState2.mTransitions.get(AnimatedStateListState.generateTransitionKey(keyframeIdAt, keyframeIdAt2), -1L).longValue();
                if (longValue >= 0) {
                    boolean z3 = (animatedStateListState2.mTransitions.get(AnimatedStateListState.generateTransitionKey(keyframeIdAt, keyframeIdAt2), -1L).longValue() & 8589934592L) != 0;
                    selectDrawable(longValue);
                    Drawable drawable = this.mCurrDrawable;
                    if (drawable instanceof AnimationDrawable) {
                        transition = new AnimationDrawableTransition((AnimationDrawable) drawable, (animatedStateListState2.mTransitions.get(AnimatedStateListState.generateTransitionKey(keyframeIdAt, keyframeIdAt2), -1L).longValue() & 4294967296L) != 0, z3);
                    } else if (drawable instanceof AnimatedVectorDrawableCompat) {
                        transition = new AnimatedVectorDrawableTransition((AnimatedVectorDrawableCompat) drawable);
                    } else if (drawable instanceof Animatable) {
                        transition = new AnimatableTransition((Animatable) drawable);
                    }
                    transition.start();
                    this.mTransition = transition;
                    this.mTransitionFromIndex = i;
                    this.mTransitionToIndex = indexOfStateSet;
                    z = true;
                    z2 = true;
                }
            }
            z = false;
            z2 = true;
        }
        Drawable drawable2 = this.mCurrDrawable;
        return drawable2 != null ? z2 | drawable2.setState(iArr) : z2;
    }

    @Override // androidx.appcompat.graphics.drawable.DrawableContainer
    public void setConstantState(DrawableContainer.DrawableContainerState drawableContainerState) {
        this.mDrawableContainerState = drawableContainerState;
        int i = this.mCurIndex;
        if (i >= 0) {
            Drawable child = drawableContainerState.getChild(i);
            this.mCurrDrawable = child;
            if (child != null) {
                initializeDrawableForDisplay(child);
            }
        }
        this.mLastDrawable = null;
        this.mStateListState = (StateListDrawable.StateListState) drawableContainerState;
        if (drawableContainerState instanceof AnimatedStateListState) {
            this.mState = (AnimatedStateListState) drawableContainerState;
        }
    }

    @Override // androidx.appcompat.graphics.drawable.DrawableContainer
    public boolean setVisible(boolean z, boolean z2) {
        boolean visible = super.setVisible(z, z2);
        Transition transition = this.mTransition;
        if (transition != null && (visible || z2)) {
            if (z) {
                transition.start();
            } else {
                jumpToCurrentState();
            }
        }
        return visible;
    }
}
