package androidx.work.impl;

import android.annotation.SuppressLint;
import android.content.Context;
import android.database.Cursor;
import androidx.room.RoomSQLiteQuery;
import androidx.room.util.DBUtil;
import androidx.work.Configuration;
import androidx.work.Data;
import androidx.work.InputMerger;
import androidx.work.InputMergerFactory$1;
import androidx.work.ListenableWorker;
import androidx.work.Logger$LogcatLogger;
import androidx.work.WorkInfo$State;
import androidx.work.WorkerFactory$1;
import androidx.work.WorkerParameters;
import androidx.work.impl.background.systemalarm.RescheduleReceiver;
import androidx.work.impl.foreground.ForegroundProcessor;
import androidx.work.impl.model.DependencyDao_Impl;
import androidx.work.impl.model.WorkSpec;
import androidx.work.impl.model.WorkSpecDao_Impl;
import androidx.work.impl.model.WorkTagDao_Impl;
import androidx.work.impl.utils.PackageManagerHelper;
import androidx.work.impl.utils.WorkForegroundUpdater;
import androidx.work.impl.utils.WorkProgressUpdater;
import androidx.work.impl.utils.futures.SettableFuture;
import androidx.work.impl.utils.taskexecutor.WorkManagerTaskExecutor;
import com.android.tools.r8.GeneratedOutlineSupport;
import com.google.common.util.concurrent.ListenableFuture;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Objects;
import java.util.UUID;
import java.util.concurrent.CancellationException;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.Executor;

public class WorkerWrapper implements Runnable {
    public static final String TAG = Logger$LogcatLogger.tagWithPrefix("WorkerWrapper");
    public Context mAppContext;
    public Configuration mConfiguration;
    public DependencyDao_Impl mDependencyDao;
    public ForegroundProcessor mForegroundProcessor;
    public SettableFuture<Boolean> mFuture = new SettableFuture<>();
    public ListenableFuture<ListenableWorker.Result> mInnerFuture = null;
    public volatile boolean mInterrupted;
    public ListenableWorker.Result mResult = new ListenableWorker.Result.Failure();
    public WorkerParameters.RuntimeExtras mRuntimeExtras;
    public List<Scheduler> mSchedulers;
    public List<String> mTags;
    public WorkDatabase mWorkDatabase;
    public String mWorkDescription;
    public WorkSpec mWorkSpec;
    public WorkSpecDao_Impl mWorkSpecDao;
    public String mWorkSpecId;
    public WorkTagDao_Impl mWorkTagDao;
    public WorkManagerTaskExecutor mWorkTaskExecutor;
    public ListenableWorker mWorker;

    public class Builder {
        public Context mAppContext;
        public Configuration mConfiguration;
        public ForegroundProcessor mForegroundProcessor;
        public WorkerParameters.RuntimeExtras mRuntimeExtras = new WorkerParameters.RuntimeExtras();
        public List<Scheduler> mSchedulers;
        public WorkDatabase mWorkDatabase;
        public String mWorkSpecId;
        public WorkManagerTaskExecutor mWorkTaskExecutor;

        public Builder(Context context, Configuration configuration, WorkManagerTaskExecutor workManagerTaskExecutor, ForegroundProcessor foregroundProcessor, WorkDatabase workDatabase, String str) {
            this.mAppContext = context.getApplicationContext();
            this.mWorkTaskExecutor = workManagerTaskExecutor;
            this.mForegroundProcessor = foregroundProcessor;
            this.mConfiguration = configuration;
            this.mWorkDatabase = workDatabase;
            this.mWorkSpecId = str;
        }
    }

    public WorkerWrapper(Builder builder) {
        this.mAppContext = builder.mAppContext;
        this.mWorkTaskExecutor = builder.mWorkTaskExecutor;
        this.mForegroundProcessor = builder.mForegroundProcessor;
        this.mWorkSpecId = builder.mWorkSpecId;
        this.mSchedulers = builder.mSchedulers;
        this.mRuntimeExtras = builder.mRuntimeExtras;
        this.mWorker = null;
        this.mConfiguration = builder.mConfiguration;
        WorkDatabase workDatabase = builder.mWorkDatabase;
        this.mWorkDatabase = workDatabase;
        this.mWorkSpecDao = workDatabase.workSpecDao();
        this.mDependencyDao = this.mWorkDatabase.dependencyDao();
        this.mWorkTagDao = this.mWorkDatabase.workTagDao();
    }

    public final void handleResult(ListenableWorker.Result result) {
        if (result instanceof ListenableWorker.Result.Success) {
            Logger$LogcatLogger.get().info(TAG, String.format("Worker result SUCCESS for %s", this.mWorkDescription), new Throwable[0]);
            if (this.mWorkSpec.isPeriodic()) {
                resetPeriodicAndResolve();
                return;
            }
            this.mWorkDatabase.beginTransaction();
            try {
                this.mWorkSpecDao.setState(WorkInfo$State.SUCCEEDED, this.mWorkSpecId);
                this.mWorkSpecDao.setOutput(this.mWorkSpecId, ((ListenableWorker.Result.Success) this.mResult).mOutputData);
                long currentTimeMillis = System.currentTimeMillis();
                Iterator it = ((ArrayList) this.mDependencyDao.getDependentWorkIds(this.mWorkSpecId)).iterator();
                while (it.hasNext()) {
                    String str = (String) it.next();
                    if (this.mWorkSpecDao.getState(str) == WorkInfo$State.BLOCKED && this.mDependencyDao.hasCompletedAllPrerequisites(str)) {
                        Logger$LogcatLogger.get().info(TAG, String.format("Setting status to enqueued for %s", str), new Throwable[0]);
                        this.mWorkSpecDao.setState(WorkInfo$State.ENQUEUED, str);
                        this.mWorkSpecDao.setPeriodStartTime(str, currentTimeMillis);
                    }
                }
                this.mWorkDatabase.setTransactionSuccessful();
            } finally {
                this.mWorkDatabase.endTransaction();
                resolve(false);
            }
        } else if (result instanceof ListenableWorker.Result.Retry) {
            Logger$LogcatLogger.get().info(TAG, String.format("Worker result RETRY for %s", this.mWorkDescription), new Throwable[0]);
            rescheduleAndResolve();
        } else {
            Logger$LogcatLogger.get().info(TAG, String.format("Worker result FAILURE for %s", this.mWorkDescription), new Throwable[0]);
            if (this.mWorkSpec.isPeriodic()) {
                resetPeriodicAndResolve();
            } else {
                setFailedAndResolve();
            }
        }
    }

    public final void iterativelyFailWorkAndDependents(String str) {
        LinkedList linkedList = new LinkedList();
        linkedList.add(str);
        while (!linkedList.isEmpty()) {
            String str2 = (String) linkedList.remove();
            if (this.mWorkSpecDao.getState(str2) != WorkInfo$State.CANCELLED) {
                this.mWorkSpecDao.setState(WorkInfo$State.FAILED, str2);
            }
            linkedList.addAll(this.mDependencyDao.getDependentWorkIds(str2));
        }
    }

    public void onWorkFinished() {
        boolean z = false;
        if (!tryCheckForInterruptionAndResolve()) {
            this.mWorkDatabase.beginTransaction();
            try {
                WorkInfo$State state = this.mWorkSpecDao.getState(this.mWorkSpecId);
                this.mWorkDatabase.workProgressDao().delete(this.mWorkSpecId);
                if (state == null) {
                    resolve(false);
                    z = true;
                } else if (state == WorkInfo$State.RUNNING) {
                    handleResult(this.mResult);
                    z = this.mWorkSpecDao.getState(this.mWorkSpecId).isFinished();
                } else if (!state.isFinished()) {
                    rescheduleAndResolve();
                }
                this.mWorkDatabase.setTransactionSuccessful();
            } finally {
                this.mWorkDatabase.endTransaction();
            }
        }
        List<Scheduler> list = this.mSchedulers;
        if (list != null) {
            if (z) {
                for (Scheduler scheduler : list) {
                    scheduler.cancel(this.mWorkSpecId);
                }
            }
            Schedulers.schedule(this.mConfiguration, this.mWorkDatabase, this.mSchedulers);
        }
    }

    public final void rescheduleAndResolve() {
        this.mWorkDatabase.beginTransaction();
        try {
            this.mWorkSpecDao.setState(WorkInfo$State.ENQUEUED, this.mWorkSpecId);
            this.mWorkSpecDao.setPeriodStartTime(this.mWorkSpecId, System.currentTimeMillis());
            this.mWorkSpecDao.markWorkSpecScheduled(this.mWorkSpecId, -1);
            this.mWorkDatabase.setTransactionSuccessful();
        } finally {
            this.mWorkDatabase.endTransaction();
            resolve(true);
        }
    }

    public final void resetPeriodicAndResolve() {
        this.mWorkDatabase.beginTransaction();
        try {
            this.mWorkSpecDao.setPeriodStartTime(this.mWorkSpecId, System.currentTimeMillis());
            this.mWorkSpecDao.setState(WorkInfo$State.ENQUEUED, this.mWorkSpecId);
            this.mWorkSpecDao.resetWorkSpecRunAttemptCount(this.mWorkSpecId);
            this.mWorkSpecDao.markWorkSpecScheduled(this.mWorkSpecId, -1);
            this.mWorkDatabase.setTransactionSuccessful();
        } finally {
            this.mWorkDatabase.endTransaction();
            resolve(false);
        }
    }

    /* JADX INFO: finally extract failed */
    public final void resolve(boolean z) {
        ListenableWorker listenableWorker;
        this.mWorkDatabase.beginTransaction();
        try {
            if (((ArrayList) this.mWorkDatabase.workSpecDao().getAllUnfinishedWork()).isEmpty()) {
                PackageManagerHelper.setComponentEnabled(this.mAppContext, RescheduleReceiver.class, false);
            }
            if (!(this.mWorkSpec == null || (listenableWorker = this.mWorker) == null)) {
                Objects.requireNonNull(listenableWorker);
            }
            this.mWorkDatabase.setTransactionSuccessful();
            this.mWorkDatabase.endTransaction();
            this.mFuture.set(Boolean.valueOf(z));
        } catch (Throwable th) {
            this.mWorkDatabase.endTransaction();
            throw th;
        }
    }

    public final void resolveIncorrectStatus() {
        WorkInfo$State state = this.mWorkSpecDao.getState(this.mWorkSpecId);
        if (state == WorkInfo$State.RUNNING) {
            Logger$LogcatLogger.get().debug(TAG, String.format("Status for %s is RUNNING;not doing any work and rescheduling for later execution", this.mWorkSpecId), new Throwable[0]);
            resolve(true);
            return;
        }
        Logger$LogcatLogger.get().debug(TAG, String.format("Status for %s is %s; not doing any work", this.mWorkSpecId, state), new Throwable[0]);
        resolve(false);
    }

    /* JADX INFO: finally extract failed */
    public void run() {
        InputMerger inputMerger;
        Data merge;
        WorkTagDao_Impl workTagDao_Impl = this.mWorkTagDao;
        String str = this.mWorkSpecId;
        Objects.requireNonNull(workTagDao_Impl);
        boolean z = true;
        RoomSQLiteQuery acquire = RoomSQLiteQuery.acquire("SELECT DISTINCT tag FROM worktag WHERE work_spec_id=?", 1);
        if (str == null) {
            acquire.bindNull(1);
        } else {
            acquire.bindString(1, str);
        }
        workTagDao_Impl.__db.assertNotSuspendingTransaction();
        Cursor query = DBUtil.query(workTagDao_Impl.__db, acquire, false, null);
        try {
            ArrayList<String> arrayList = new ArrayList(query.getCount());
            while (query.moveToNext()) {
                arrayList.add(query.getString(0));
            }
            query.close();
            acquire.release();
            this.mTags = arrayList;
            StringBuilder sb = new StringBuilder("Work [ id=");
            sb.append(this.mWorkSpecId);
            sb.append(", tags={ ");
            boolean z2 = true;
            for (String str2 : arrayList) {
                if (z2) {
                    z2 = false;
                } else {
                    sb.append(", ");
                }
                sb.append(str2);
            }
            sb.append(" } ]");
            this.mWorkDescription = sb.toString();
            if (!tryCheckForInterruptionAndResolve()) {
                this.mWorkDatabase.beginTransaction();
                try {
                    WorkSpec workSpec = this.mWorkSpecDao.getWorkSpec(this.mWorkSpecId);
                    this.mWorkSpec = workSpec;
                    if (workSpec == null) {
                        Logger$LogcatLogger.get().error(TAG, String.format("Didn't find WorkSpec for id %s", this.mWorkSpecId), new Throwable[0]);
                        resolve(false);
                    } else if (workSpec.state != WorkInfo$State.ENQUEUED) {
                        resolveIncorrectStatus();
                        this.mWorkDatabase.setTransactionSuccessful();
                        Logger$LogcatLogger.get().debug(TAG, String.format("%s is not in ENQUEUED state. Nothing more to do.", this.mWorkSpec.workerClassName), new Throwable[0]);
                    } else {
                        if (workSpec.isPeriodic() || this.mWorkSpec.isBackedOff()) {
                            long currentTimeMillis = System.currentTimeMillis();
                            WorkSpec workSpec2 = this.mWorkSpec;
                            if (!(workSpec2.periodStartTime == 0) && currentTimeMillis < workSpec2.calculateNextRunTime()) {
                                Logger$LogcatLogger.get().debug(TAG, String.format("Delaying execution for %s because it is being executed before schedule.", this.mWorkSpec.workerClassName), new Throwable[0]);
                                resolve(true);
                            }
                        }
                        this.mWorkDatabase.setTransactionSuccessful();
                        this.mWorkDatabase.endTransaction();
                        if (this.mWorkSpec.isPeriodic()) {
                            merge = this.mWorkSpec.input;
                        } else {
                            InputMergerFactory$1 inputMergerFactory$1 = this.mConfiguration.mInputMergerFactory;
                            String str3 = this.mWorkSpec.inputMergerClassName;
                            Objects.requireNonNull(inputMergerFactory$1);
                            String str4 = InputMerger.TAG;
                            try {
                                inputMerger = (InputMerger) Class.forName(str3).newInstance();
                            } catch (Exception e) {
                                Logger$LogcatLogger.get().error(InputMerger.TAG, GeneratedOutlineSupport.outline18("Trouble instantiating + ", str3), e);
                                inputMerger = null;
                            }
                            if (inputMerger == null) {
                                Logger$LogcatLogger.get().error(TAG, String.format("Could not create Input Merger %s", this.mWorkSpec.inputMergerClassName), new Throwable[0]);
                                setFailedAndResolve();
                                return;
                            }
                            ArrayList arrayList2 = new ArrayList();
                            arrayList2.add(this.mWorkSpec.input);
                            WorkSpecDao_Impl workSpecDao_Impl = this.mWorkSpecDao;
                            String str5 = this.mWorkSpecId;
                            Objects.requireNonNull(workSpecDao_Impl);
                            RoomSQLiteQuery acquire2 = RoomSQLiteQuery.acquire("SELECT output FROM workspec WHERE id IN (SELECT prerequisite_id FROM dependency WHERE work_spec_id=?)", 1);
                            if (str5 == null) {
                                acquire2.bindNull(1);
                            } else {
                                acquire2.bindString(1, str5);
                            }
                            workSpecDao_Impl.__db.assertNotSuspendingTransaction();
                            Cursor query2 = DBUtil.query(workSpecDao_Impl.__db, acquire2, false, null);
                            try {
                                ArrayList arrayList3 = new ArrayList(query2.getCount());
                                while (query2.moveToNext()) {
                                    arrayList3.add(Data.fromByteArray(query2.getBlob(0)));
                                }
                                query2.close();
                                acquire2.release();
                                arrayList2.addAll(arrayList3);
                                merge = inputMerger.merge(arrayList2);
                            } catch (Throwable th) {
                                query2.close();
                                acquire2.release();
                                throw th;
                            }
                        }
                        UUID fromString = UUID.fromString(this.mWorkSpecId);
                        List<String> list = this.mTags;
                        WorkerParameters.RuntimeExtras runtimeExtras = this.mRuntimeExtras;
                        int i = this.mWorkSpec.runAttemptCount;
                        Configuration configuration = this.mConfiguration;
                        Executor executor = configuration.mExecutor;
                        WorkManagerTaskExecutor workManagerTaskExecutor = this.mWorkTaskExecutor;
                        WorkerFactory$1 workerFactory$1 = configuration.mWorkerFactory;
                        WorkDatabase workDatabase = this.mWorkDatabase;
                        WorkManagerTaskExecutor workManagerTaskExecutor2 = this.mWorkTaskExecutor;
                        WorkerParameters workerParameters = new WorkerParameters(fromString, merge, list, runtimeExtras, i, executor, workManagerTaskExecutor, workerFactory$1, new WorkProgressUpdater(workDatabase, workManagerTaskExecutor2), new WorkForegroundUpdater(this.mForegroundProcessor, workManagerTaskExecutor2));
                        if (this.mWorker == null) {
                            this.mWorker = this.mConfiguration.mWorkerFactory.createWorkerWithDefaultFallback(this.mAppContext, this.mWorkSpec.workerClassName, workerParameters);
                        }
                        ListenableWorker listenableWorker = this.mWorker;
                        if (listenableWorker == null) {
                            Logger$LogcatLogger.get().error(TAG, String.format("Could not create Worker %s", this.mWorkSpec.workerClassName), new Throwable[0]);
                            setFailedAndResolve();
                        } else if (listenableWorker.mUsed) {
                            Logger$LogcatLogger.get().error(TAG, String.format("Received an already-used Worker %s; WorkerFactory should return new instances", this.mWorkSpec.workerClassName), new Throwable[0]);
                            setFailedAndResolve();
                        } else {
                            listenableWorker.mUsed = true;
                            this.mWorkDatabase.beginTransaction();
                            try {
                                if (this.mWorkSpecDao.getState(this.mWorkSpecId) == WorkInfo$State.ENQUEUED) {
                                    this.mWorkSpecDao.setState(WorkInfo$State.RUNNING, this.mWorkSpecId);
                                    this.mWorkSpecDao.incrementWorkSpecRunAttemptCount(this.mWorkSpecId);
                                } else {
                                    z = false;
                                }
                                this.mWorkDatabase.setTransactionSuccessful();
                                if (!z) {
                                    resolveIncorrectStatus();
                                } else if (!tryCheckForInterruptionAndResolve()) {
                                    final SettableFuture settableFuture = new SettableFuture();
                                    this.mWorkTaskExecutor.mMainThreadExecutor.execute(new Runnable() {
                                        /* class androidx.work.impl.WorkerWrapper.AnonymousClass1 */

                                        public void run() {
                                            try {
                                                Logger$LogcatLogger.get().debug(WorkerWrapper.TAG, String.format("Starting work for %s", WorkerWrapper.this.mWorkSpec.workerClassName), new Throwable[0]);
                                                WorkerWrapper workerWrapper = WorkerWrapper.this;
                                                workerWrapper.mInnerFuture = workerWrapper.mWorker.startWork();
                                                settableFuture.setFuture(WorkerWrapper.this.mInnerFuture);
                                            } catch (Throwable th) {
                                                settableFuture.setException(th);
                                            }
                                        }
                                    });
                                    final String str6 = this.mWorkDescription;
                                    settableFuture.addListener(new Runnable() {
                                        /* class androidx.work.impl.WorkerWrapper.AnonymousClass2 */

                                        @SuppressLint({"SyntheticAccessor"})
                                        public void run() {
                                            try {
                                                ListenableWorker.Result result = (ListenableWorker.Result) settableFuture.get();
                                                if (result == null) {
                                                    Logger$LogcatLogger.get().error(WorkerWrapper.TAG, String.format("%s returned a null result. Treating it as a failure.", WorkerWrapper.this.mWorkSpec.workerClassName), new Throwable[0]);
                                                } else {
                                                    Logger$LogcatLogger.get().debug(WorkerWrapper.TAG, String.format("%s returned a %s result.", WorkerWrapper.this.mWorkSpec.workerClassName, result), new Throwable[0]);
                                                    WorkerWrapper.this.mResult = result;
                                                }
                                            } catch (CancellationException e) {
                                                Logger$LogcatLogger.get().info(WorkerWrapper.TAG, String.format("%s was cancelled", str6), e);
                                            } catch (InterruptedException | ExecutionException e2) {
                                                Logger$LogcatLogger.get().error(WorkerWrapper.TAG, String.format("%s failed because it threw an exception/error", str6), e2);
                                            } catch (Throwable th) {
                                                WorkerWrapper.this.onWorkFinished();
                                                throw th;
                                            }
                                            WorkerWrapper.this.onWorkFinished();
                                        }
                                    }, this.mWorkTaskExecutor.mBackgroundExecutor);
                                }
                            } finally {
                                this.mWorkDatabase.endTransaction();
                            }
                        }
                    }
                } finally {
                    this.mWorkDatabase.endTransaction();
                }
            }
        } catch (Throwable th2) {
            query.close();
            acquire.release();
            throw th2;
        }
    }

    public void setFailedAndResolve() {
        this.mWorkDatabase.beginTransaction();
        try {
            iterativelyFailWorkAndDependents(this.mWorkSpecId);
            this.mWorkSpecDao.setOutput(this.mWorkSpecId, ((ListenableWorker.Result.Failure) this.mResult).mOutputData);
            this.mWorkDatabase.setTransactionSuccessful();
        } finally {
            this.mWorkDatabase.endTransaction();
            resolve(false);
        }
    }

    public final boolean tryCheckForInterruptionAndResolve() {
        if (!this.mInterrupted) {
            return false;
        }
        Logger$LogcatLogger.get().debug(TAG, String.format("Work interrupted for %s", this.mWorkDescription), new Throwable[0]);
        WorkInfo$State state = this.mWorkSpecDao.getState(this.mWorkSpecId);
        if (state == null) {
            resolve(false);
        } else {
            resolve(!state.isFinished());
        }
        return true;
    }
}
