package com.bumptech.glide;

import android.content.ComponentCallbacks2;
import android.content.Context;
import android.content.res.Configuration;
import android.graphics.Bitmap;
import android.graphics.drawable.Drawable;
import android.util.Log;
import androidx.core.content.ContextCompat;
import com.bumptech.glide.load.engine.DiskCacheStrategy;
import com.bumptech.glide.load.resource.gif.GifDrawable;
import com.bumptech.glide.manager.ConnectivityMonitor;
import com.bumptech.glide.manager.DefaultConnectivityMonitor;
import com.bumptech.glide.manager.DefaultConnectivityMonitorFactory;
import com.bumptech.glide.manager.Lifecycle;
import com.bumptech.glide.manager.LifecycleListener;
import com.bumptech.glide.manager.NullConnectivityMonitor;
import com.bumptech.glide.manager.RequestManagerTreeNode;
import com.bumptech.glide.manager.RequestTracker;
import com.bumptech.glide.manager.TargetTracker;
import com.bumptech.glide.request.Request;
import com.bumptech.glide.request.RequestListener;
import com.bumptech.glide.request.RequestOptions;
import com.bumptech.glide.request.target.Target;
import com.bumptech.glide.util.Util;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.Objects;
import java.util.concurrent.CopyOnWriteArrayList;

public class RequestManager implements ComponentCallbacks2, LifecycleListener {
    public static final RequestOptions DECODE_TYPE_BITMAP;
    public static final RequestOptions DOWNLOAD_ONLY_OPTIONS = ((RequestOptions) ((RequestOptions) ((RequestOptions) new RequestOptions().diskCacheStrategy(DiskCacheStrategy.DATA)).priority(Priority.LOW)).skipMemoryCache(true));
    public final Runnable addSelfToLifecycle;
    public final ConnectivityMonitor connectivityMonitor;
    public final Context context;
    public final CopyOnWriteArrayList<RequestListener<Object>> defaultRequestListeners;
    public final Glide glide;
    public final Lifecycle lifecycle;
    public RequestOptions requestOptions;
    public final RequestTracker requestTracker;
    public final TargetTracker targetTracker = new TargetTracker();
    public final RequestManagerTreeNode treeNode;

    public class RequestManagerConnectivityListener implements ConnectivityMonitor.ConnectivityListener {
        public final RequestTracker requestTracker;

        public RequestManagerConnectivityListener(RequestTracker requestTracker2) {
            this.requestTracker = requestTracker2;
        }
    }

    static {
        RequestOptions requestOptions2 = (RequestOptions) new RequestOptions().decode(Bitmap.class);
        requestOptions2.isLocked = true;
        DECODE_TYPE_BITMAP = requestOptions2;
        ((RequestOptions) new RequestOptions().decode(GifDrawable.class)).isLocked = true;
    }

    public RequestManager(Glide glide2, Lifecycle lifecycle2, RequestManagerTreeNode requestManagerTreeNode, Context context2) {
        ConnectivityMonitor connectivityMonitor2;
        RequestOptions requestOptions2;
        RequestTracker requestTracker2 = new RequestTracker();
        DefaultConnectivityMonitorFactory defaultConnectivityMonitorFactory = glide2.connectivityMonitorFactory;
        AnonymousClass1 r2 = new Runnable() {
            /* class com.bumptech.glide.RequestManager.AnonymousClass1 */

            public void run() {
                RequestManager requestManager = RequestManager.this;
                requestManager.lifecycle.addListener(requestManager);
            }
        };
        this.addSelfToLifecycle = r2;
        this.glide = glide2;
        this.lifecycle = lifecycle2;
        this.treeNode = requestManagerTreeNode;
        this.requestTracker = requestTracker2;
        this.context = context2;
        Context applicationContext = context2.getApplicationContext();
        RequestManagerConnectivityListener requestManagerConnectivityListener = new RequestManagerConnectivityListener(requestTracker2);
        Objects.requireNonNull(defaultConnectivityMonitorFactory);
        boolean z = ContextCompat.checkSelfPermission(applicationContext, "android.permission.ACCESS_NETWORK_STATE") == 0;
        if (Log.isLoggable("ConnectivityMonitor", 3)) {
            Log.d("ConnectivityMonitor", z ? "ACCESS_NETWORK_STATE permission granted, registering connectivity monitor" : "ACCESS_NETWORK_STATE permission missing, cannot register connectivity monitor");
        }
        if (z) {
            connectivityMonitor2 = new DefaultConnectivityMonitor(applicationContext, requestManagerConnectivityListener);
        } else {
            connectivityMonitor2 = new NullConnectivityMonitor();
        }
        this.connectivityMonitor = connectivityMonitor2;
        if (Util.isOnBackgroundThread()) {
            Util.getUiThreadHandler().post(r2);
        } else {
            lifecycle2.addListener(this);
        }
        lifecycle2.addListener(connectivityMonitor2);
        this.defaultRequestListeners = new CopyOnWriteArrayList<>(glide2.glideContext.defaultRequestListeners);
        GlideContext glideContext = glide2.glideContext;
        synchronized (glideContext) {
            if (glideContext.defaultRequestOptions == null) {
                Objects.requireNonNull(glideContext.defaultRequestOptionsFactory);
                RequestOptions requestOptions3 = new RequestOptions();
                requestOptions3.isLocked = true;
                glideContext.defaultRequestOptions = requestOptions3;
            }
            requestOptions2 = glideContext.defaultRequestOptions;
        }
        synchronized (this) {
            RequestOptions requestOptions4 = (RequestOptions) requestOptions2.clone();
            if (requestOptions4.isLocked) {
                if (!requestOptions4.isAutoCloneEnabled) {
                    throw new IllegalStateException("You cannot auto lock an already locked options object, try clone() first");
                }
            }
            requestOptions4.isAutoCloneEnabled = true;
            requestOptions4.isLocked = true;
            this.requestOptions = requestOptions4;
        }
        synchronized (glide2.managers) {
            if (!glide2.managers.contains(this)) {
                glide2.managers.add(this);
            } else {
                throw new IllegalStateException("Cannot register already registered manager");
            }
        }
    }

    public <ResourceType> RequestBuilder<ResourceType> as(Class<ResourceType> cls) {
        return new RequestBuilder<>(this.glide, this, cls, this.context);
    }

    public void clear(Target<?> target) {
        boolean z;
        if (target != null) {
            boolean untrack = untrack(target);
            Request request = target.getRequest();
            if (!untrack) {
                Glide glide2 = this.glide;
                synchronized (glide2.managers) {
                    Iterator<RequestManager> it = glide2.managers.iterator();
                    while (true) {
                        if (it.hasNext()) {
                            if (it.next().untrack(target)) {
                                z = true;
                                break;
                            }
                        } else {
                            z = false;
                            break;
                        }
                    }
                }
                if (!z && request != null) {
                    target.setRequest(null);
                    request.clear();
                }
            }
        }
    }

    public RequestBuilder<Drawable> load(String str) {
        return as(Drawable.class).loadGeneric(str);
    }

    public void onConfigurationChanged(Configuration configuration) {
    }

    @Override // com.bumptech.glide.manager.LifecycleListener
    public synchronized void onDestroy() {
        this.targetTracker.onDestroy();
        for (Target<?> target : Util.getSnapshot(this.targetTracker.targets)) {
            clear(target);
        }
        this.targetTracker.targets.clear();
        RequestTracker requestTracker2 = this.requestTracker;
        Iterator it = ((ArrayList) Util.getSnapshot(requestTracker2.requests)).iterator();
        while (it.hasNext()) {
            requestTracker2.clearAndRemove((Request) it.next());
        }
        requestTracker2.pendingRequests.clear();
        this.lifecycle.removeListener(this);
        this.lifecycle.removeListener(this.connectivityMonitor);
        Util.getUiThreadHandler().removeCallbacks(this.addSelfToLifecycle);
        Glide glide2 = this.glide;
        synchronized (glide2.managers) {
            if (glide2.managers.contains(this)) {
                glide2.managers.remove(this);
            } else {
                throw new IllegalStateException("Cannot unregister not yet registered manager");
            }
        }
    }

    public void onLowMemory() {
    }

    @Override // com.bumptech.glide.manager.LifecycleListener
    public synchronized void onStart() {
        resumeRequests();
        this.targetTracker.onStart();
    }

    @Override // com.bumptech.glide.manager.LifecycleListener
    public synchronized void onStop() {
        pauseRequests();
        this.targetTracker.onStop();
    }

    public void onTrimMemory(int i) {
    }

    public synchronized void pauseRequests() {
        RequestTracker requestTracker2 = this.requestTracker;
        requestTracker2.isPaused = true;
        Iterator it = ((ArrayList) Util.getSnapshot(requestTracker2.requests)).iterator();
        while (it.hasNext()) {
            Request request = (Request) it.next();
            if (request.isRunning()) {
                request.pause();
                requestTracker2.pendingRequests.add(request);
            }
        }
    }

    public synchronized void resumeRequests() {
        RequestTracker requestTracker2 = this.requestTracker;
        requestTracker2.isPaused = false;
        Iterator it = ((ArrayList) Util.getSnapshot(requestTracker2.requests)).iterator();
        while (it.hasNext()) {
            Request request = (Request) it.next();
            if (!request.isComplete() && !request.isRunning()) {
                request.begin();
            }
        }
        requestTracker2.pendingRequests.clear();
    }

    public synchronized String toString() {
        return super.toString() + "{tracker=" + this.requestTracker + ", treeNode=" + this.treeNode + "}";
    }

    public synchronized boolean untrack(Target<?> target) {
        Request request = target.getRequest();
        if (request == null) {
            return true;
        }
        if (!this.requestTracker.clearAndRemove(request)) {
            return false;
        }
        this.targetTracker.targets.remove(target);
        target.setRequest(null);
        return true;
    }
}
