package com.bumptech.glide.load.engine;

import android.os.SystemClock;
import android.util.Log;
import androidx.core.util.Pools$Pool;
import com.android.tools.r8.GeneratedOutlineSupport;
import com.bumptech.glide.GlideContext;
import com.bumptech.glide.Priority;
import com.bumptech.glide.load.DataSource;
import com.bumptech.glide.load.Key;
import com.bumptech.glide.load.Options;
import com.bumptech.glide.load.Transformation;
import com.bumptech.glide.load.engine.ActiveResources;
import com.bumptech.glide.load.engine.DecodeJob;
import com.bumptech.glide.load.engine.EngineResource;
import com.bumptech.glide.load.engine.cache.DiskCache;
import com.bumptech.glide.load.engine.cache.DiskCacheAdapter;
import com.bumptech.glide.load.engine.cache.DiskLruCacheFactory;
import com.bumptech.glide.load.engine.cache.DiskLruCacheWrapper;
import com.bumptech.glide.load.engine.cache.InternalCacheDiskCacheFactory;
import com.bumptech.glide.load.engine.cache.LruResourceCache;
import com.bumptech.glide.load.engine.cache.MemoryCache$ResourceRemovedListener;
import com.bumptech.glide.load.engine.executor.GlideExecutor;
import com.bumptech.glide.request.ResourceCallback;
import com.bumptech.glide.request.SingleRequest;
import com.bumptech.glide.util.LogTime;
import com.bumptech.glide.util.LruCache;
import com.bumptech.glide.util.pool.FactoryPools;
import java.io.File;
import java.util.Map;
import java.util.Objects;
import java.util.concurrent.Executor;

public class Engine implements EngineJobListener, MemoryCache$ResourceRemovedListener, EngineResource.ResourceListener {
    public static final boolean VERBOSE_IS_LOGGABLE = Log.isLoggable("Engine", 2);
    public final ActiveResources activeResources;
    public final LruResourceCache cache;
    public final DecodeJobFactory decodeJobFactory;
    public final LazyDiskCacheProvider diskCacheProvider;
    public final EngineJobFactory engineJobFactory;
    public final Jobs jobs;
    public final EngineKeyFactory keyFactory;
    public final ResourceRecycler resourceRecycler;

    public class DecodeJobFactory {
        public int creationOrder;
        public final LazyDiskCacheProvider diskCacheProvider;
        public final Pools$Pool<DecodeJob<?>> pool = FactoryPools.threadSafe(150, new FactoryPools.Factory<DecodeJob<?>>() {
            /* class com.bumptech.glide.load.engine.Engine.DecodeJobFactory.AnonymousClass1 */

            /* Return type fixed from 'java.lang.Object' to match base method */
            @Override // com.bumptech.glide.util.pool.FactoryPools.Factory
            public DecodeJob<?> create() {
                DecodeJobFactory decodeJobFactory = DecodeJobFactory.this;
                return new DecodeJob(decodeJobFactory.diskCacheProvider, decodeJobFactory.pool);
            }
        });

        public DecodeJobFactory(LazyDiskCacheProvider lazyDiskCacheProvider) {
            this.diskCacheProvider = lazyDiskCacheProvider;
        }
    }

    public class EngineJobFactory {
        public final GlideExecutor animationExecutor;
        public final GlideExecutor diskCacheExecutor;
        public final EngineJobListener engineJobListener;
        public final Pools$Pool<EngineJob<?>> pool = FactoryPools.threadSafe(150, new FactoryPools.Factory<EngineJob<?>>() {
            /* class com.bumptech.glide.load.engine.Engine.EngineJobFactory.AnonymousClass1 */

            /* Return type fixed from 'java.lang.Object' to match base method */
            @Override // com.bumptech.glide.util.pool.FactoryPools.Factory
            public EngineJob<?> create() {
                EngineJobFactory engineJobFactory = EngineJobFactory.this;
                return new EngineJob(engineJobFactory.diskCacheExecutor, engineJobFactory.sourceExecutor, engineJobFactory.sourceUnlimitedExecutor, engineJobFactory.animationExecutor, engineJobFactory.engineJobListener, engineJobFactory.resourceListener, engineJobFactory.pool);
            }
        });
        public final EngineResource.ResourceListener resourceListener;
        public final GlideExecutor sourceExecutor;
        public final GlideExecutor sourceUnlimitedExecutor;

        public EngineJobFactory(GlideExecutor glideExecutor, GlideExecutor glideExecutor2, GlideExecutor glideExecutor3, GlideExecutor glideExecutor4, EngineJobListener engineJobListener2, EngineResource.ResourceListener resourceListener2) {
            this.diskCacheExecutor = glideExecutor;
            this.sourceExecutor = glideExecutor2;
            this.sourceUnlimitedExecutor = glideExecutor3;
            this.animationExecutor = glideExecutor4;
            this.engineJobListener = engineJobListener2;
            this.resourceListener = resourceListener2;
        }
    }

    public class LazyDiskCacheProvider {
        public volatile DiskCache diskCache;
        public final DiskLruCacheFactory factory;

        public LazyDiskCacheProvider(DiskLruCacheFactory diskLruCacheFactory) {
            this.factory = diskLruCacheFactory;
        }

        public DiskCache getDiskCache() {
            if (this.diskCache == null) {
                synchronized (this) {
                    if (this.diskCache == null) {
                        DiskLruCacheFactory diskLruCacheFactory = this.factory;
                        InternalCacheDiskCacheFactory.AnonymousClass1 r1 = diskLruCacheFactory.cacheDirectoryGetter;
                        File cacheDir = r4.getCacheDir();
                        DiskLruCacheWrapper diskLruCacheWrapper = null;
                        if (cacheDir == null) {
                            cacheDir = null;
                        } else if ("image_manager_disk_cache" != null) {
                            cacheDir = new File(cacheDir, "image_manager_disk_cache");
                        }
                        if (cacheDir != null) {
                            if (cacheDir.isDirectory() || cacheDir.mkdirs()) {
                                diskLruCacheWrapper = new DiskLruCacheWrapper(cacheDir, diskLruCacheFactory.diskCacheSize);
                            }
                        }
                        this.diskCache = diskLruCacheWrapper;
                    }
                    if (this.diskCache == null) {
                        this.diskCache = new DiskCacheAdapter();
                    }
                }
            }
            return this.diskCache;
        }
    }

    public class LoadStatus {
        public final ResourceCallback cb;
        public final EngineJob<?> engineJob;

        public LoadStatus(ResourceCallback resourceCallback, EngineJob<?> engineJob2) {
            this.cb = resourceCallback;
            this.engineJob = engineJob2;
        }
    }

    public Engine(LruResourceCache lruResourceCache, DiskLruCacheFactory diskLruCacheFactory, GlideExecutor glideExecutor, GlideExecutor glideExecutor2, GlideExecutor glideExecutor3, GlideExecutor glideExecutor4, boolean z) {
        this.cache = lruResourceCache;
        LazyDiskCacheProvider lazyDiskCacheProvider = new LazyDiskCacheProvider(diskLruCacheFactory);
        this.diskCacheProvider = lazyDiskCacheProvider;
        ActiveResources activeResources2 = new ActiveResources(z);
        this.activeResources = activeResources2;
        synchronized (this) {
            synchronized (activeResources2) {
                activeResources2.listener = this;
            }
        }
        this.keyFactory = new EngineKeyFactory();
        this.jobs = new Jobs();
        this.engineJobFactory = new EngineJobFactory(glideExecutor, glideExecutor2, glideExecutor3, glideExecutor4, this, this);
        this.decodeJobFactory = new DecodeJobFactory(lazyDiskCacheProvider);
        this.resourceRecycler = new ResourceRecycler();
        lruResourceCache.listener = this;
    }

    public static void logWithTimeAndKey(String str, long j, Key key) {
        StringBuilder outline28 = GeneratedOutlineSupport.outline28(str, " in ");
        outline28.append(LogTime.getElapsedMillis(j));
        outline28.append("ms, key: ");
        outline28.append(key);
        Log.v("Engine", outline28.toString());
    }

    public <R> LoadStatus load(GlideContext glideContext, Object obj, Key key, int i, int i2, Class<?> cls, Class<R> cls2, Priority priority, DiskCacheStrategy diskCacheStrategy, Map<Class<?>, Transformation<?>> map, boolean z, boolean z2, Options options, boolean z3, boolean z4, boolean z5, boolean z6, ResourceCallback resourceCallback, Executor executor) {
        long j;
        if (VERBOSE_IS_LOGGABLE) {
            int i3 = LogTime.$r8$clinit;
            j = SystemClock.elapsedRealtimeNanos();
        } else {
            j = 0;
        }
        Objects.requireNonNull(this.keyFactory);
        EngineKey engineKey = new EngineKey(obj, key, i, i2, map, cls, cls2, options);
        synchronized (this) {
            EngineResource<?> loadFromMemory = loadFromMemory(engineKey, z3, j);
            if (loadFromMemory == null) {
                return waitForExistingOrStartNewJob(glideContext, obj, key, i, i2, cls, cls2, priority, diskCacheStrategy, map, z, z2, options, z3, z4, z5, z6, resourceCallback, executor, engineKey, j);
            }
            ((SingleRequest) resourceCallback).onResourceReady((Resource<?>) loadFromMemory, DataSource.MEMORY_CACHE, false);
            return null;
        }
    }

    public final EngineResource<?> loadFromMemory(EngineKey engineKey, boolean z, long j) {
        EngineResource<?> engineResource;
        Y y;
        Y y2;
        if (!z) {
            return null;
        }
        ActiveResources activeResources2 = this.activeResources;
        synchronized (activeResources2) {
            ActiveResources.ResourceWeakReference resourceWeakReference = activeResources2.activeEngineResources.get(engineKey);
            if (resourceWeakReference == null) {
                engineResource = null;
            } else {
                engineResource = (EngineResource) resourceWeakReference.get();
                if (engineResource == null) {
                    activeResources2.cleanupActiveReference(resourceWeakReference);
                }
            }
        }
        if (engineResource != null) {
            engineResource.acquire();
        }
        if (engineResource != null) {
            if (VERBOSE_IS_LOGGABLE) {
                logWithTimeAndKey("Loaded resource from active resources", j, engineKey);
            }
            return engineResource;
        }
        LruResourceCache lruResourceCache = this.cache;
        synchronized (lruResourceCache) {
            LruCache.Entry<Y> remove = lruResourceCache.cache.remove(engineKey);
            if (remove == null) {
                y = null;
            } else {
                lruResourceCache.currentSize -= (long) remove.size;
                y = remove.value;
            }
        }
        Y y3 = y;
        if (y3 == null) {
            y2 = null;
        } else if (y3 instanceof EngineResource) {
            y2 = y3;
        } else {
            y2 = new EngineResource<>(y3, true, true, engineKey, this);
        }
        if (y2 != null) {
            y2.acquire();
            this.activeResources.activate(engineKey, y2);
        }
        if (y2 == null) {
            return null;
        }
        if (VERBOSE_IS_LOGGABLE) {
            logWithTimeAndKey("Loaded resource from cache", j, engineKey);
        }
        return y2;
    }

    public synchronized void onEngineJobComplete(EngineJob<?> engineJob, Key key, EngineResource<?> engineResource) {
        if (engineResource != null) {
            if (engineResource.isMemoryCacheable) {
                this.activeResources.activate(key, engineResource);
            }
        }
        Jobs jobs2 = this.jobs;
        Objects.requireNonNull(jobs2);
        Map<Key, EngineJob<?>> jobMap = jobs2.getJobMap(engineJob.onlyRetrieveFromCache);
        if (engineJob.equals(jobMap.get(key))) {
            jobMap.remove(key);
        }
    }

    public void onResourceReleased(Key key, EngineResource<?> engineResource) {
        ActiveResources activeResources2 = this.activeResources;
        synchronized (activeResources2) {
            ActiveResources.ResourceWeakReference remove = activeResources2.activeEngineResources.remove(key);
            if (remove != null) {
                remove.resource = null;
                remove.clear();
            }
        }
        if (engineResource.isMemoryCacheable) {
            Resource resource = (Resource) this.cache.put(key, engineResource);
        } else {
            this.resourceRecycler.recycle(engineResource, false);
        }
    }

    public void release(Resource<?> resource) {
        if (resource instanceof EngineResource) {
            ((EngineResource) resource).release();
            return;
        }
        throw new IllegalArgumentException("Cannot release anything but an EngineResource");
    }

    /* JADX DEBUG: Multi-variable search result rejected for r23v0, resolved type: java.lang.Class<R> */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARNING: Removed duplicated region for block: B:27:0x00e9  */
    /* JADX WARNING: Removed duplicated region for block: B:28:0x00ec  */
    public final <R> LoadStatus waitForExistingOrStartNewJob(GlideContext glideContext, Object obj, Key key, int i, int i2, Class<?> cls, Class<R> cls2, Priority priority, DiskCacheStrategy diskCacheStrategy, Map<Class<?>, Transformation<?>> map, boolean z, boolean z2, Options options, boolean z3, boolean z4, boolean z5, boolean z6, ResourceCallback resourceCallback, Executor executor, EngineKey engineKey, long j) {
        boolean z7;
        GlideExecutor glideExecutor;
        Jobs jobs2 = this.jobs;
        EngineJob<?> engineJob = (z6 ? jobs2.onlyCacheJobs : jobs2.jobs).get(engineKey);
        if (engineJob != null) {
            engineJob.addCallback(resourceCallback, executor);
            if (VERBOSE_IS_LOGGABLE) {
                logWithTimeAndKey("Added to existing load", j, engineKey);
            }
            return new LoadStatus(resourceCallback, engineJob);
        }
        EngineJob<?> acquire = this.engineJobFactory.pool.acquire();
        Objects.requireNonNull(acquire, "Argument must not be null");
        synchronized (acquire) {
            acquire.key = engineKey;
            acquire.isCacheable = z3;
            acquire.useUnlimitedSourceGeneratorPool = z4;
            acquire.useAnimationPool = z5;
            acquire.onlyRetrieveFromCache = z6;
        }
        DecodeJobFactory decodeJobFactory2 = this.decodeJobFactory;
        DecodeJob<R> decodeJob = (DecodeJob<R>) decodeJobFactory2.pool.acquire();
        Objects.requireNonNull(decodeJob, "Argument must not be null");
        int i3 = decodeJobFactory2.creationOrder;
        decodeJobFactory2.creationOrder = i3 + 1;
        DecodeHelper<R> decodeHelper = decodeJob.decodeHelper;
        LazyDiskCacheProvider lazyDiskCacheProvider = decodeJob.diskCacheProvider;
        decodeHelper.glideContext = glideContext;
        decodeHelper.model = obj;
        decodeHelper.signature = key;
        decodeHelper.width = i;
        decodeHelper.height = i2;
        decodeHelper.diskCacheStrategy = diskCacheStrategy;
        decodeHelper.resourceClass = cls;
        decodeHelper.diskCacheProvider = lazyDiskCacheProvider;
        decodeHelper.transcodeClass = cls2;
        decodeHelper.priority = priority;
        decodeHelper.options = options;
        decodeHelper.transformations = map;
        decodeHelper.isTransformationRequired = z;
        decodeHelper.isScaleOnlyOrNoTransform = z2;
        decodeJob.glideContext = glideContext;
        decodeJob.signature = key;
        decodeJob.priority = priority;
        decodeJob.loadKey = engineKey;
        decodeJob.width = i;
        decodeJob.height = i2;
        decodeJob.diskCacheStrategy = diskCacheStrategy;
        decodeJob.onlyRetrieveFromCache = z6;
        decodeJob.options = options;
        decodeJob.callback = acquire;
        decodeJob.order = i3;
        decodeJob.runReason = DecodeJob.RunReason.INITIALIZE;
        decodeJob.model = obj;
        Jobs jobs3 = this.jobs;
        Objects.requireNonNull(jobs3);
        jobs3.getJobMap(acquire.onlyRetrieveFromCache).put(engineKey, acquire);
        acquire.addCallback(resourceCallback, executor);
        synchronized (acquire) {
            acquire.decodeJob = decodeJob;
            DecodeJob.Stage nextStage = decodeJob.getNextStage(DecodeJob.Stage.INITIALIZE);
            if (nextStage != DecodeJob.Stage.RESOURCE_CACHE) {
                if (nextStage != DecodeJob.Stage.DATA_CACHE) {
                    z7 = false;
                    if (!z7) {
                        glideExecutor = acquire.diskCacheExecutor;
                    } else if (acquire.useUnlimitedSourceGeneratorPool) {
                        glideExecutor = acquire.sourceUnlimitedExecutor;
                    } else {
                        glideExecutor = acquire.useAnimationPool ? acquire.animationExecutor : acquire.sourceExecutor;
                    }
                    glideExecutor.delegate.execute(decodeJob);
                }
            }
            z7 = true;
            if (!z7) {
            }
            glideExecutor.delegate.execute(decodeJob);
        }
        if (VERBOSE_IS_LOGGABLE) {
            logWithTimeAndKey("Started new load", j, engineKey);
        }
        return new LoadStatus(resourceCallback, acquire);
    }
}
