package com.bumptech.glide.load.engine.bitmap_recycle;

import android.annotation.SuppressLint;
import android.graphics.Bitmap;
import android.os.Build;
import android.util.Log;
import com.android.tools.r8.GeneratedOutlineSupport;
import com.bumptech.glide.util.Util;
import java.util.Arrays;
import java.util.Collections;
import java.util.HashSet;
import java.util.Objects;
import java.util.Set;

public class LruBitmapPool implements BitmapPool {
    public static final Bitmap.Config DEFAULT_CONFIG = Bitmap.Config.ARGB_8888;
    public final Set<Bitmap.Config> allowedConfigs;
    public long currentSize;
    public int evictions;
    public int hits;
    public long maxSize;
    public int misses;
    public int puts;
    public final LruPoolStrategy strategy;
    public final NullBitmapTracker tracker;

    public final class NullBitmapTracker {
    }

    public LruBitmapPool(long j) {
        SizeConfigStrategy sizeConfigStrategy = new SizeConfigStrategy();
        HashSet hashSet = new HashSet(Arrays.asList(Bitmap.Config.values()));
        int i = Build.VERSION.SDK_INT;
        hashSet.add(null);
        if (i >= 26) {
            hashSet.remove(Bitmap.Config.HARDWARE);
        }
        Set<Bitmap.Config> unmodifiableSet = Collections.unmodifiableSet(hashSet);
        this.maxSize = j;
        this.strategy = sizeConfigStrategy;
        this.allowedConfigs = unmodifiableSet;
        this.tracker = new NullBitmapTracker();
    }

    @Override // com.bumptech.glide.load.engine.bitmap_recycle.BitmapPool
    public void clearMemory() {
        if (Log.isLoggable("LruBitmapPool", 3)) {
            Log.d("LruBitmapPool", "clearMemory");
        }
        trimToSize(0);
    }

    public final void dump() {
        if (Log.isLoggable("LruBitmapPool", 2)) {
            dumpUnchecked();
        }
    }

    public final void dumpUnchecked() {
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("Hits=");
        outline25.append(this.hits);
        outline25.append(", misses=");
        outline25.append(this.misses);
        outline25.append(", puts=");
        outline25.append(this.puts);
        outline25.append(", evictions=");
        outline25.append(this.evictions);
        outline25.append(", currentSize=");
        outline25.append(this.currentSize);
        outline25.append(", maxSize=");
        outline25.append(this.maxSize);
        outline25.append("\nStrategy=");
        outline25.append(this.strategy);
        Log.v("LruBitmapPool", outline25.toString());
    }

    @Override // com.bumptech.glide.load.engine.bitmap_recycle.BitmapPool
    public Bitmap get(int i, int i2, Bitmap.Config config) {
        Bitmap dirtyOrNull = getDirtyOrNull(i, i2, config);
        if (dirtyOrNull != null) {
            dirtyOrNull.eraseColor(0);
            return dirtyOrNull;
        }
        if (config == null) {
            config = DEFAULT_CONFIG;
        }
        return Bitmap.createBitmap(i, i2, config);
    }

    @Override // com.bumptech.glide.load.engine.bitmap_recycle.BitmapPool
    public Bitmap getDirty(int i, int i2, Bitmap.Config config) {
        Bitmap dirtyOrNull = getDirtyOrNull(i, i2, config);
        if (dirtyOrNull != null) {
            return dirtyOrNull;
        }
        if (config == null) {
            config = DEFAULT_CONFIG;
        }
        return Bitmap.createBitmap(i, i2, config);
    }

    public final synchronized Bitmap getDirtyOrNull(int i, int i2, Bitmap.Config config) {
        Bitmap bitmap;
        if (Build.VERSION.SDK_INT >= 26) {
            if (config == Bitmap.Config.HARDWARE) {
                throw new IllegalArgumentException("Cannot create a mutable Bitmap with config: " + config + ". Consider setting Downsampler#ALLOW_HARDWARE_CONFIG to false in your RequestOptions and/or in GlideBuilder.setDefaultRequestOptions");
            }
        }
        bitmap = ((SizeConfigStrategy) this.strategy).get(i, i2, config != null ? config : DEFAULT_CONFIG);
        if (bitmap == null) {
            if (Log.isLoggable("LruBitmapPool", 3)) {
                StringBuilder sb = new StringBuilder();
                sb.append("Missing bitmap=");
                Objects.requireNonNull((SizeConfigStrategy) this.strategy);
                sb.append(SizeConfigStrategy.getBitmapString(Util.getBitmapByteSize(i, i2, config), config));
                Log.d("LruBitmapPool", sb.toString());
            }
            this.misses++;
        } else {
            this.hits++;
            long j = this.currentSize;
            Objects.requireNonNull((SizeConfigStrategy) this.strategy);
            this.currentSize = j - ((long) Util.getBitmapByteSize(bitmap));
            Objects.requireNonNull(this.tracker);
            bitmap.setHasAlpha(true);
            bitmap.setPremultiplied(true);
        }
        if (Log.isLoggable("LruBitmapPool", 2)) {
            StringBuilder sb2 = new StringBuilder();
            sb2.append("Get bitmap=");
            Objects.requireNonNull((SizeConfigStrategy) this.strategy);
            sb2.append(SizeConfigStrategy.getBitmapString(Util.getBitmapByteSize(i, i2, config), config));
            Log.v("LruBitmapPool", sb2.toString());
        }
        dump();
        return bitmap;
    }

    @Override // com.bumptech.glide.load.engine.bitmap_recycle.BitmapPool
    public synchronized void put(Bitmap bitmap) {
        if (bitmap == null) {
            throw new NullPointerException("Bitmap must not be null");
        } else if (!bitmap.isRecycled()) {
            if (bitmap.isMutable()) {
                Objects.requireNonNull((SizeConfigStrategy) this.strategy);
                if (((long) Util.getBitmapByteSize(bitmap)) <= this.maxSize) {
                    if (this.allowedConfigs.contains(bitmap.getConfig())) {
                        Objects.requireNonNull((SizeConfigStrategy) this.strategy);
                        int bitmapByteSize = Util.getBitmapByteSize(bitmap);
                        ((SizeConfigStrategy) this.strategy).put(bitmap);
                        Objects.requireNonNull(this.tracker);
                        this.puts++;
                        this.currentSize += (long) bitmapByteSize;
                        if (Log.isLoggable("LruBitmapPool", 2)) {
                            Log.v("LruBitmapPool", "Put bitmap in pool=" + ((SizeConfigStrategy) this.strategy).logBitmap(bitmap));
                        }
                        dump();
                        trimToSize(this.maxSize);
                        return;
                    }
                }
            }
            if (Log.isLoggable("LruBitmapPool", 2)) {
                Log.v("LruBitmapPool", "Reject bitmap from pool, bitmap: " + ((SizeConfigStrategy) this.strategy).logBitmap(bitmap) + ", is mutable: " + bitmap.isMutable() + ", is allowed config: " + this.allowedConfigs.contains(bitmap.getConfig()));
            }
            bitmap.recycle();
        } else {
            throw new IllegalStateException("Cannot pool recycled bitmap");
        }
    }

    @Override // com.bumptech.glide.load.engine.bitmap_recycle.BitmapPool
    @SuppressLint({"InlinedApi"})
    public void trimMemory(int i) {
        if (Log.isLoggable("LruBitmapPool", 3)) {
            Log.d("LruBitmapPool", "trimMemory, level=" + i);
        }
        if (i >= 40 || (Build.VERSION.SDK_INT >= 23 && i >= 20)) {
            if (Log.isLoggable("LruBitmapPool", 3)) {
                Log.d("LruBitmapPool", "clearMemory");
            }
            trimToSize(0);
        } else if (i >= 20 || i == 15) {
            trimToSize(this.maxSize / 2);
        }
    }

    public final synchronized void trimToSize(long j) {
        while (this.currentSize > j) {
            SizeConfigStrategy sizeConfigStrategy = (SizeConfigStrategy) this.strategy;
            Bitmap removeLast = sizeConfigStrategy.groupedMap.removeLast();
            if (removeLast != null) {
                sizeConfigStrategy.decrementBitmapOfSize(Integer.valueOf(Util.getBitmapByteSize(removeLast)), removeLast);
            }
            if (removeLast == null) {
                if (Log.isLoggable("LruBitmapPool", 5)) {
                    Log.w("LruBitmapPool", "Size mismatch, resetting");
                    dumpUnchecked();
                }
                this.currentSize = 0;
                return;
            }
            Objects.requireNonNull(this.tracker);
            long j2 = this.currentSize;
            Objects.requireNonNull((SizeConfigStrategy) this.strategy);
            this.currentSize = j2 - ((long) Util.getBitmapByteSize(removeLast));
            this.evictions++;
            if (Log.isLoggable("LruBitmapPool", 3)) {
                Log.d("LruBitmapPool", "Evicting bitmap=" + ((SizeConfigStrategy) this.strategy).logBitmap(removeLast));
            }
            dump();
            removeLast.recycle();
        }
    }
}
