package com.bumptech.glide.load.resource.bitmap;

import android.annotation.TargetApi;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.ColorSpace;
import android.graphics.Matrix;
import android.graphics.RectF;
import android.os.Build;
import android.os.SystemClock;
import android.util.DisplayMetrics;
import android.util.Log;
import com.android.tools.r8.GeneratedOutlineSupport;
import com.bumptech.glide.load.DecodeFormat;
import com.bumptech.glide.load.ImageHeaderParser;
import com.bumptech.glide.load.Option;
import com.bumptech.glide.load.Options;
import com.bumptech.glide.load.PreferredColorSpace;
import com.bumptech.glide.load.engine.Resource;
import com.bumptech.glide.load.engine.bitmap_recycle.BitmapPool;
import com.bumptech.glide.load.engine.bitmap_recycle.LruArrayPool;
import com.bumptech.glide.load.resource.bitmap.DownsampleStrategy;
import com.bumptech.glide.load.resource.bitmap.ImageReader;
import com.bumptech.glide.util.LogTime;
import com.bumptech.glide.util.Util;
import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayDeque;
import java.util.Arrays;
import java.util.Collections;
import java.util.EnumSet;
import java.util.HashSet;
import java.util.List;
import java.util.Objects;
import java.util.Queue;
import java.util.Set;
import java.util.concurrent.locks.Lock;

public final class Downsampler {
    public static final Option<Boolean> ALLOW_HARDWARE_CONFIG;
    public static final Option<DecodeFormat> DECODE_FORMAT = Option.memory("com.bumptech.glide.load.resource.bitmap.Downsampler.DecodeFormat", DecodeFormat.DEFAULT);
    public static final DecodeCallbacks EMPTY_CALLBACKS = new DecodeCallbacks() {
        /* class com.bumptech.glide.load.resource.bitmap.Downsampler.AnonymousClass1 */

        @Override // com.bumptech.glide.load.resource.bitmap.Downsampler.DecodeCallbacks
        public void onDecodeComplete(BitmapPool bitmapPool, Bitmap bitmap) {
        }

        @Override // com.bumptech.glide.load.resource.bitmap.Downsampler.DecodeCallbacks
        public void onObtainBounds() {
        }
    };
    public static final Option<Boolean> FIX_BITMAP_SIZE_TO_REQUESTED_DIMENSIONS;
    public static final Set<String> NO_DOWNSAMPLE_PRE_N_MIME_TYPES = Collections.unmodifiableSet(new HashSet(Arrays.asList("image/vnd.wap.wbmp", "image/x-ico")));
    public static final Queue<BitmapFactory.Options> OPTIONS_QUEUE = new ArrayDeque(0);
    public static final Option<PreferredColorSpace> PREFERRED_COLOR_SPACE = Option.memory("com.bumptech.glide.load.resource.bitmap.Downsampler.PreferredColorSpace", PreferredColorSpace.SRGB);
    public static final Set<ImageHeaderParser.ImageType> TYPES_THAT_USE_POOL_PRE_KITKAT = Collections.unmodifiableSet(EnumSet.of(ImageHeaderParser.ImageType.JPEG, ImageHeaderParser.ImageType.PNG_A, ImageHeaderParser.ImageType.PNG));
    public final BitmapPool bitmapPool;
    public final LruArrayPool byteArrayPool;
    public final DisplayMetrics displayMetrics;
    public final HardwareConfigState hardwareConfigState = HardwareConfigState.getInstance();
    public final List<ImageHeaderParser> parsers;

    public interface DecodeCallbacks {
        void onDecodeComplete(BitmapPool bitmapPool, Bitmap bitmap);

        void onObtainBounds();
    }

    static {
        Option<DownsampleStrategy> option = DownsampleStrategy.OPTION;
        Boolean bool = Boolean.FALSE;
        FIX_BITMAP_SIZE_TO_REQUESTED_DIMENSIONS = Option.memory("com.bumptech.glide.load.resource.bitmap.Downsampler.FixBitmapSize", bool);
        ALLOW_HARDWARE_CONFIG = Option.memory("com.bumptech.glide.load.resource.bitmap.Downsampler.AllowHardwareDecode", bool);
        char[] cArr = Util.HEX_CHAR_ARRAY;
    }

    public Downsampler(List<ImageHeaderParser> list, DisplayMetrics displayMetrics2, BitmapPool bitmapPool2, LruArrayPool lruArrayPool) {
        this.parsers = list;
        Objects.requireNonNull(displayMetrics2, "Argument must not be null");
        this.displayMetrics = displayMetrics2;
        Objects.requireNonNull(bitmapPool2, "Argument must not be null");
        this.bitmapPool = bitmapPool2;
        Objects.requireNonNull(lruArrayPool, "Argument must not be null");
        this.byteArrayPool = lruArrayPool;
    }

    public static Bitmap decodeStream(ImageReader imageReader, BitmapFactory.Options options, DecodeCallbacks decodeCallbacks, BitmapPool bitmapPool2) {
        if (!options.inJustDecodeBounds) {
            decodeCallbacks.onObtainBounds();
            imageReader.stopGrowingBuffers();
        }
        int i = options.outWidth;
        int i2 = options.outHeight;
        String str = options.outMimeType;
        Lock lock = TransformationUtils.BITMAP_DRAWABLE_LOCK;
        lock.lock();
        try {
            Bitmap decodeBitmap = imageReader.decodeBitmap(options);
            lock.unlock();
            return decodeBitmap;
        } catch (IllegalArgumentException e) {
            IOException newIoExceptionForInBitmapAssertion = newIoExceptionForInBitmapAssertion(e, i, i2, str, options);
            if (Log.isLoggable("Downsampler", 3)) {
                Log.d("Downsampler", "Failed to decode with inBitmap, trying again without Bitmap re-use", newIoExceptionForInBitmapAssertion);
            }
            Bitmap bitmap = options.inBitmap;
            if (bitmap != null) {
                try {
                    bitmapPool2.put(bitmap);
                    options.inBitmap = null;
                    Bitmap decodeStream = decodeStream(imageReader, options, decodeCallbacks, bitmapPool2);
                    TransformationUtils.BITMAP_DRAWABLE_LOCK.unlock();
                    return decodeStream;
                } catch (IOException unused) {
                    throw newIoExceptionForInBitmapAssertion;
                }
            } else {
                throw newIoExceptionForInBitmapAssertion;
            }
        } catch (Throwable th) {
            TransformationUtils.BITMAP_DRAWABLE_LOCK.unlock();
            throw th;
        }
    }

    @TargetApi(19)
    public static String getBitmapString(Bitmap bitmap) {
        if (bitmap == null) {
            return null;
        }
        StringBuilder outline25 = GeneratedOutlineSupport.outline25(" (");
        outline25.append(bitmap.getAllocationByteCount());
        outline25.append(")");
        String sb = outline25.toString();
        StringBuilder outline252 = GeneratedOutlineSupport.outline25("[");
        outline252.append(bitmap.getWidth());
        outline252.append("x");
        outline252.append(bitmap.getHeight());
        outline252.append("] ");
        outline252.append(bitmap.getConfig());
        outline252.append(sb);
        return outline252.toString();
    }

    public static int getDensityMultiplier(double d) {
        if (d > 1.0d) {
            d = 1.0d / d;
        }
        return (int) Math.round(d * 2.147483647E9d);
    }

    public static int[] getDimensions(ImageReader imageReader, BitmapFactory.Options options, DecodeCallbacks decodeCallbacks, BitmapPool bitmapPool2) {
        options.inJustDecodeBounds = true;
        decodeStream(imageReader, options, decodeCallbacks, bitmapPool2);
        options.inJustDecodeBounds = false;
        return new int[]{options.outWidth, options.outHeight};
    }

    public static boolean isRotationRequired(int i) {
        return i == 90 || i == 270;
    }

    public static IOException newIoExceptionForInBitmapAssertion(IllegalArgumentException illegalArgumentException, int i, int i2, String str, BitmapFactory.Options options) {
        StringBuilder outline27 = GeneratedOutlineSupport.outline27("Exception decoding bitmap, outWidth: ", i, ", outHeight: ", i2, ", outMimeType: ");
        outline27.append(str);
        outline27.append(", inBitmap: ");
        outline27.append(getBitmapString(options.inBitmap));
        return new IOException(outline27.toString(), illegalArgumentException);
    }

    public static void resetOptions(BitmapFactory.Options options) {
        options.inTempStorage = null;
        options.inDither = false;
        options.inScaled = false;
        options.inSampleSize = 1;
        options.inPreferredConfig = null;
        options.inJustDecodeBounds = false;
        options.inDensity = 0;
        options.inTargetDensity = 0;
        if (Build.VERSION.SDK_INT >= 26) {
            options.inPreferredColorSpace = null;
            options.outColorSpace = null;
            options.outConfig = null;
        }
        options.outWidth = 0;
        options.outHeight = 0;
        options.outMimeType = null;
        options.inBitmap = null;
        options.inMutable = true;
    }

    public static int round(double d) {
        return (int) (d + 0.5d);
    }

    public Resource<Bitmap> decode(InputStream inputStream, int i, int i2, Options options, DecodeCallbacks decodeCallbacks) {
        return decode(new ImageReader.InputStreamImageReader(inputStream, this.parsers, this.byteArrayPool), i, i2, options, decodeCallbacks);
    }

    /* JADX WARNING: Removed duplicated region for block: B:103:0x02de  */
    /* JADX WARNING: Removed duplicated region for block: B:105:0x02e7  */
    /* JADX WARNING: Removed duplicated region for block: B:106:0x02e9  */
    /* JADX WARNING: Removed duplicated region for block: B:124:0x0331 A[ADDED_TO_REGION] */
    /* JADX WARNING: Removed duplicated region for block: B:129:0x033d  */
    /* JADX WARNING: Removed duplicated region for block: B:135:0x0348  */
    /* JADX WARNING: Removed duplicated region for block: B:136:0x034e  */
    /* JADX WARNING: Removed duplicated region for block: B:139:0x0376  */
    /* JADX WARNING: Removed duplicated region for block: B:146:0x03bb  */
    /* JADX WARNING: Removed duplicated region for block: B:149:0x03c5  */
    /* JADX WARNING: Removed duplicated region for block: B:151:0x03c8  */
    /* JADX WARNING: Removed duplicated region for block: B:155:0x03d4  */
    /* JADX WARNING: Removed duplicated region for block: B:167:0x03f5  */
    /* JADX WARNING: Removed duplicated region for block: B:171:0x0413  */
    /* JADX WARNING: Removed duplicated region for block: B:173:0x0497  */
    /* JADX WARNING: Removed duplicated region for block: B:192:0x0532 A[ORIG_RETURN, RETURN, SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:56:0x0116  */
    /* JADX WARNING: Removed duplicated region for block: B:59:0x0132  */
    /* JADX WARNING: Removed duplicated region for block: B:82:0x01c1 A[ADDED_TO_REGION] */
    /* JADX WARNING: Removed duplicated region for block: B:87:0x01ca  */
    /* JADX WARNING: Removed duplicated region for block: B:88:0x01ce  */
    /* JADX WARNING: Removed duplicated region for block: B:91:0x01dc  */
    /* JADX WARNING: Removed duplicated region for block: B:92:0x0240  */
    public final Bitmap decodeFromWrappedStreams(ImageReader imageReader, BitmapFactory.Options options, DownsampleStrategy downsampleStrategy, DecodeFormat decodeFormat, PreferredColorSpace preferredColorSpace, boolean z, int i, int i2, boolean z2, DecodeCallbacks decodeCallbacks) {
        int i3;
        int i4;
        long j;
        boolean z3;
        String str;
        int i5;
        int i6;
        int i7;
        int i8;
        String str2;
        String str3;
        String str4;
        boolean isHardwareConfigAllowed;
        String str5;
        int i9;
        int i10;
        int i11;
        int i12;
        Bitmap decodeStream;
        boolean z4;
        Bitmap bitmap;
        ColorSpace colorSpace;
        Bitmap.Config config;
        int i13;
        boolean z5;
        String str6;
        int i14;
        String str7;
        String str8;
        int i15;
        int i16;
        int i17;
        String str9;
        int i18;
        DownsampleStrategy downsampleStrategy2;
        int i19;
        int i20;
        int densityMultiplier;
        int i21;
        int i22;
        double d;
        int i23 = LogTime.$r8$clinit;
        long elapsedRealtimeNanos = SystemClock.elapsedRealtimeNanos();
        int[] dimensions = getDimensions(imageReader, options, decodeCallbacks, this.bitmapPool);
        int i24 = dimensions[0];
        int i25 = dimensions[1];
        String str10 = options.outMimeType;
        boolean z6 = (i24 == -1 || i25 == -1) ? false : z;
        int imageOrientation = imageReader.getImageOrientation();
        switch (imageOrientation) {
            case 3:
            case 4:
                i3 = 180;
                break;
            case 5:
            case 6:
                i3 = 90;
                break;
            case 7:
            case 8:
                i3 = 270;
                break;
            default:
                i3 = 0;
                break;
        }
        switch (imageOrientation) {
            case 2:
            case 3:
            case 4:
            case 5:
            case 6:
            case 7:
            case 8:
                j = elapsedRealtimeNanos;
                i4 = imageOrientation;
                z3 = true;
                break;
            default:
                j = elapsedRealtimeNanos;
                i4 = imageOrientation;
                z3 = false;
                break;
        }
        int i26 = i == Integer.MIN_VALUE ? isRotationRequired(i3) ? i25 : i24 : i;
        int i27 = i2 == Integer.MIN_VALUE ? isRotationRequired(i3) ? i24 : i25 : i2;
        ImageHeaderParser.ImageType imageType = imageReader.getImageType();
        BitmapPool bitmapPool2 = this.bitmapPool;
        if (i24 <= 0) {
            str2 = "Downsampler";
            str4 = ", target density: ";
            str6 = "]";
            str3 = ", density: ";
            str = "x";
            i5 = i25;
            i6 = i24;
            i8 = i27;
            i7 = i26;
            i14 = 3;
        } else if (i25 <= 0) {
            i14 = 3;
            str2 = "Downsampler";
            str4 = ", target density: ";
            str6 = "]";
            str3 = ", density: ";
            str = "x";
            i5 = i25;
            i6 = i24;
            i8 = i27;
            i7 = i26;
        } else {
            if (isRotationRequired(i3)) {
                str8 = "]";
                str7 = ", density: ";
                i16 = i25;
                i15 = i24;
            } else {
                str8 = "]";
                str7 = ", density: ";
                i15 = i25;
                i16 = i24;
            }
            float scaleFactor = downsampleStrategy.getScaleFactor(i16, i15, i26, i27);
            if (scaleFactor > 0.0f) {
                DownsampleStrategy.SampleSizeRounding sampleSizeRounding = downsampleStrategy.getSampleSizeRounding(i16, i15, i26, i27);
                if (sampleSizeRounding != null) {
                    float f = (float) i16;
                    float f2 = (float) i15;
                    int round = i16 / round((double) (scaleFactor * f));
                    int round2 = i15 / round((double) (scaleFactor * f2));
                    DownsampleStrategy.SampleSizeRounding sampleSizeRounding2 = DownsampleStrategy.SampleSizeRounding.MEMORY;
                    if (sampleSizeRounding == sampleSizeRounding2) {
                        i17 = Math.max(round, round2);
                    } else {
                        i17 = Math.min(round, round2);
                    }
                    int i28 = Build.VERSION.SDK_INT;
                    if (i28 <= 23) {
                        str9 = "x";
                        if (NO_DOWNSAMPLE_PRE_N_MIME_TYPES.contains(options.outMimeType)) {
                            i18 = 1;
                            options.inSampleSize = i18;
                            if (imageType != ImageHeaderParser.ImageType.JPEG) {
                                float min = (float) Math.min(i18, 8);
                                i22 = (int) Math.ceil((double) (f / min));
                                i20 = (int) Math.ceil((double) (f2 / min));
                                int i29 = i18 / 8;
                                if (i29 > 0) {
                                    i22 /= i29;
                                    i20 /= i29;
                                }
                            } else {
                                if (imageType == ImageHeaderParser.ImageType.PNG || imageType == ImageHeaderParser.ImageType.PNG_A) {
                                    float f3 = (float) i18;
                                    i22 = (int) Math.floor((double) (f / f3));
                                    d = Math.floor((double) (f2 / f3));
                                } else if (imageType == ImageHeaderParser.ImageType.WEBP || imageType == ImageHeaderParser.ImageType.WEBP_A) {
                                    if (i28 >= 24) {
                                        float f4 = (float) i18;
                                        i22 = Math.round(f / f4);
                                        i20 = Math.round(f2 / f4);
                                    } else {
                                        float f5 = (float) i18;
                                        i22 = (int) Math.floor((double) (f / f5));
                                        d = Math.floor((double) (f2 / f5));
                                    }
                                } else if (i16 % i18 == 0 && i15 % i18 == 0) {
                                    i22 = i16 / i18;
                                    i20 = i15 / i18;
                                } else {
                                    int[] dimensions2 = getDimensions(imageReader, options, decodeCallbacks, bitmapPool2);
                                    i19 = dimensions2[0];
                                    i20 = dimensions2[1];
                                    downsampleStrategy2 = downsampleStrategy;
                                    i7 = i26;
                                    i8 = i27;
                                    double scaleFactor2 = (double) downsampleStrategy2.getScaleFactor(i19, i20, i7, i8);
                                    int densityMultiplier2 = getDensityMultiplier(scaleFactor2);
                                    int round3 = round(((double) densityMultiplier2) * scaleFactor2);
                                    options.inTargetDensity = round((scaleFactor2 / ((double) (((float) round3) / ((float) densityMultiplier2)))) * ((double) round3));
                                    densityMultiplier = getDensityMultiplier(scaleFactor2);
                                    options.inDensity = densityMultiplier;
                                    i21 = options.inTargetDensity;
                                    if (i21 <= 0 && densityMultiplier > 0 && i21 != densityMultiplier) {
                                        options.inScaled = true;
                                    } else {
                                        options.inTargetDensity = 0;
                                        options.inDensity = 0;
                                    }
                                    str2 = "Downsampler";
                                    if (Log.isLoggable(str2, 2)) {
                                        i5 = i25;
                                        i6 = i24;
                                        str = str9;
                                        StringBuilder outline27 = GeneratedOutlineSupport.outline27("Calculate scaling, source: [", i6, str, i5, "], degreesToRotate: ");
                                        outline27.append(i3);
                                        outline27.append(", target: [");
                                        outline27.append(i7);
                                        outline27.append(str);
                                        outline27.append(i8);
                                        outline27.append("], power of two scaled: [");
                                        outline27.append(i19);
                                        outline27.append(str);
                                        outline27.append(i20);
                                        outline27.append("], exact scale factor: ");
                                        outline27.append(scaleFactor);
                                        outline27.append(", power of 2 sample size: ");
                                        outline27.append(i18);
                                        outline27.append(", adjusted scale factor: ");
                                        outline27.append(scaleFactor2);
                                        str4 = ", target density: ";
                                        outline27.append(str4);
                                        outline27.append(options.inTargetDensity);
                                        str3 = str7;
                                        outline27.append(str3);
                                        outline27.append(options.inDensity);
                                        Log.v(str2, outline27.toString());
                                    } else {
                                        str3 = str7;
                                        str4 = ", target density: ";
                                        i5 = i25;
                                        i6 = i24;
                                        str = str9;
                                    }
                                    isHardwareConfigAllowed = this.hardwareConfigState.isHardwareConfigAllowed(i7, i8, z6, z3);
                                    if (isHardwareConfigAllowed) {
                                        options.inPreferredConfig = Bitmap.Config.HARDWARE;
                                        options.inMutable = false;
                                    }
                                    if (!isHardwareConfigAllowed) {
                                        str5 = str4;
                                    } else {
                                        str5 = str4;
                                        if (decodeFormat != DecodeFormat.PREFER_ARGB_8888) {
                                            try {
                                                z5 = imageReader.getImageType().hasAlpha();
                                            } catch (IOException e) {
                                                if (Log.isLoggable(str2, 3)) {
                                                    Log.d(str2, "Cannot determine whether the image has alpha or not from header, format " + decodeFormat, e);
                                                }
                                                z5 = false;
                                            }
                                            Bitmap.Config config2 = z5 ? Bitmap.Config.ARGB_8888 : Bitmap.Config.RGB_565;
                                            options.inPreferredConfig = config2;
                                            if (config2 == Bitmap.Config.RGB_565) {
                                                options.inDither = true;
                                            }
                                        } else {
                                            options.inPreferredConfig = Bitmap.Config.ARGB_8888;
                                        }
                                    }
                                    i9 = Build.VERSION.SDK_INT;
                                    i10 = options.inSampleSize;
                                    if (i6 >= 0 || i5 < 0 || !z2) {
                                        int i30 = options.inTargetDensity;
                                        float f6 = !(i30 <= 0 && (i13 = options.inDensity) > 0 && i30 != i13) ? ((float) i30) / ((float) options.inDensity) : 1.0f;
                                        float f7 = (float) i10;
                                        i11 = Math.round(((float) ((int) Math.ceil((double) (((float) i6) / f7)))) * f6);
                                        int round4 = Math.round(((float) ((int) Math.ceil((double) (((float) i5) / f7)))) * f6);
                                        if (Log.isLoggable(str2, 2)) {
                                            StringBuilder outline272 = GeneratedOutlineSupport.outline27("Calculated target [", i11, str, round4, "] for source [");
                                            outline272.append(i6);
                                            outline272.append(str);
                                            outline272.append(i5);
                                            outline272.append("], sampleSize: ");
                                            outline272.append(i10);
                                            outline272.append(", targetDensity: ");
                                            outline272.append(options.inTargetDensity);
                                            outline272.append(str3);
                                            outline272.append(options.inDensity);
                                            outline272.append(", density multiplier: ");
                                            outline272.append(f6);
                                            Log.v(str2, outline272.toString());
                                        }
                                        i12 = round4;
                                    } else {
                                        i12 = i8;
                                        i11 = i7;
                                    }
                                    if (i11 > 0 && i12 > 0) {
                                        BitmapPool bitmapPool3 = this.bitmapPool;
                                        if (i9 >= 26) {
                                            config = null;
                                        } else if (options.inPreferredConfig != Bitmap.Config.HARDWARE) {
                                            config = options.outConfig;
                                        }
                                        if (config == null) {
                                            config = options.inPreferredConfig;
                                        }
                                        options.inBitmap = bitmapPool3.getDirty(i11, i12, config);
                                    }
                                    if (i9 < 28) {
                                        options.inPreferredColorSpace = ColorSpace.get(preferredColorSpace == PreferredColorSpace.DISPLAY_P3 && (colorSpace = options.outColorSpace) != null && colorSpace.isWideGamut() ? ColorSpace.Named.DISPLAY_P3 : ColorSpace.Named.SRGB);
                                    } else if (i9 >= 26) {
                                        options.inPreferredColorSpace = ColorSpace.get(ColorSpace.Named.SRGB);
                                    }
                                    decodeStream = decodeStream(imageReader, options, decodeCallbacks, this.bitmapPool);
                                    decodeCallbacks.onDecodeComplete(this.bitmapPool, decodeStream);
                                    if (Log.isLoggable(str2, 2)) {
                                        StringBuilder outline25 = GeneratedOutlineSupport.outline25("Decoded ");
                                        outline25.append(getBitmapString(decodeStream));
                                        outline25.append(" from [");
                                        outline25.append(i6);
                                        outline25.append(str);
                                        outline25.append(i5);
                                        outline25.append("] ");
                                        outline25.append(str10);
                                        outline25.append(" with inBitmap ");
                                        outline25.append(getBitmapString(options.inBitmap));
                                        outline25.append(" for [");
                                        outline25.append(i);
                                        outline25.append(str);
                                        outline25.append(i2);
                                        outline25.append("], sample size: ");
                                        outline25.append(options.inSampleSize);
                                        outline25.append(str3);
                                        outline25.append(options.inDensity);
                                        outline25.append(str5);
                                        outline25.append(options.inTargetDensity);
                                        outline25.append(", thread: ");
                                        outline25.append(Thread.currentThread().getName());
                                        outline25.append(", duration: ");
                                        outline25.append(LogTime.getElapsedMillis(j));
                                        Log.v(str2, outline25.toString());
                                    }
                                    if (decodeStream != null) {
                                        return null;
                                    }
                                    decodeStream.setDensity(this.displayMetrics.densityDpi);
                                    BitmapPool bitmapPool4 = this.bitmapPool;
                                    switch (i4) {
                                        case 2:
                                        case 3:
                                        case 4:
                                        case 5:
                                        case 6:
                                        case 7:
                                        case 8:
                                            z4 = true;
                                            break;
                                        default:
                                            z4 = false;
                                            break;
                                    }
                                    if (!z4) {
                                        bitmap = decodeStream;
                                    } else {
                                        Matrix matrix = new Matrix();
                                        switch (i4) {
                                            case 2:
                                                matrix.setScale(-1.0f, 1.0f);
                                                break;
                                            case 3:
                                                matrix.setRotate(180.0f);
                                                break;
                                            case 4:
                                                matrix.setRotate(180.0f);
                                                matrix.postScale(-1.0f, 1.0f);
                                                break;
                                            case 5:
                                                matrix.setRotate(90.0f);
                                                matrix.postScale(-1.0f, 1.0f);
                                                break;
                                            case 6:
                                                matrix.setRotate(90.0f);
                                                break;
                                            case 7:
                                                matrix.setRotate(-90.0f);
                                                matrix.postScale(-1.0f, 1.0f);
                                                break;
                                            case 8:
                                                matrix.setRotate(-90.0f);
                                                break;
                                        }
                                        RectF rectF = new RectF(0.0f, 0.0f, (float) decodeStream.getWidth(), (float) decodeStream.getHeight());
                                        matrix.mapRect(rectF);
                                        bitmap = bitmapPool4.get(Math.round(rectF.width()), Math.round(rectF.height()), TransformationUtils.getNonNullConfig(decodeStream));
                                        matrix.postTranslate(-rectF.left, -rectF.top);
                                        bitmap.setHasAlpha(decodeStream.hasAlpha());
                                        TransformationUtils.applyMatrix(decodeStream, bitmap, matrix);
                                    }
                                    if (decodeStream.equals(bitmap)) {
                                        return bitmap;
                                    }
                                    this.bitmapPool.put(decodeStream);
                                    return bitmap;
                                }
                                i20 = (int) d;
                            }
                            i19 = i22;
                            i7 = i26;
                            i8 = i27;
                            downsampleStrategy2 = downsampleStrategy;
                            double scaleFactor22 = (double) downsampleStrategy2.getScaleFactor(i19, i20, i7, i8);
                            int densityMultiplier22 = getDensityMultiplier(scaleFactor22);
                            int round32 = round(((double) densityMultiplier22) * scaleFactor22);
                            options.inTargetDensity = round((scaleFactor22 / ((double) (((float) round32) / ((float) densityMultiplier22)))) * ((double) round32));
                            densityMultiplier = getDensityMultiplier(scaleFactor22);
                            options.inDensity = densityMultiplier;
                            i21 = options.inTargetDensity;
                            if (i21 <= 0 && densityMultiplier > 0 && i21 != densityMultiplier) {
                            }
                            str2 = "Downsampler";
                            if (Log.isLoggable(str2, 2)) {
                            }
                            isHardwareConfigAllowed = this.hardwareConfigState.isHardwareConfigAllowed(i7, i8, z6, z3);
                            if (isHardwareConfigAllowed) {
                            }
                            if (!isHardwareConfigAllowed) {
                            }
                            i9 = Build.VERSION.SDK_INT;
                            i10 = options.inSampleSize;
                            if (i6 >= 0) {
                            }
                            int i302 = options.inTargetDensity;
                            if (!(i302 <= 0 && (i13 = options.inDensity) > 0 && i302 != i13)) {
                            }
                            float f72 = (float) i10;
                            i11 = Math.round(((float) ((int) Math.ceil((double) (((float) i6) / f72)))) * f6);
                            int round42 = Math.round(((float) ((int) Math.ceil((double) (((float) i5) / f72)))) * f6);
                            if (Log.isLoggable(str2, 2)) {
                            }
                            i12 = round42;
                            BitmapPool bitmapPool32 = this.bitmapPool;
                            if (i9 >= 26) {
                            }
                            if (config == null) {
                            }
                            options.inBitmap = bitmapPool32.getDirty(i11, i12, config);
                            if (i9 < 28) {
                            }
                            decodeStream = decodeStream(imageReader, options, decodeCallbacks, this.bitmapPool);
                            decodeCallbacks.onDecodeComplete(this.bitmapPool, decodeStream);
                            if (Log.isLoggable(str2, 2)) {
                            }
                            if (decodeStream != null) {
                            }
                        }
                    } else {
                        str9 = "x";
                    }
                    i18 = Math.max(1, Integer.highestOneBit(i17));
                    if (sampleSizeRounding == sampleSizeRounding2 && ((float) i18) < 1.0f / scaleFactor) {
                        i18 <<= 1;
                    }
                    options.inSampleSize = i18;
                    if (imageType != ImageHeaderParser.ImageType.JPEG) {
                    }
                    i19 = i22;
                    i7 = i26;
                    i8 = i27;
                    downsampleStrategy2 = downsampleStrategy;
                    double scaleFactor222 = (double) downsampleStrategy2.getScaleFactor(i19, i20, i7, i8);
                    int densityMultiplier222 = getDensityMultiplier(scaleFactor222);
                    int round322 = round(((double) densityMultiplier222) * scaleFactor222);
                    options.inTargetDensity = round((scaleFactor222 / ((double) (((float) round322) / ((float) densityMultiplier222)))) * ((double) round322));
                    densityMultiplier = getDensityMultiplier(scaleFactor222);
                    options.inDensity = densityMultiplier;
                    i21 = options.inTargetDensity;
                    if (i21 <= 0 && densityMultiplier > 0 && i21 != densityMultiplier) {
                    }
                    str2 = "Downsampler";
                    if (Log.isLoggable(str2, 2)) {
                    }
                    isHardwareConfigAllowed = this.hardwareConfigState.isHardwareConfigAllowed(i7, i8, z6, z3);
                    if (isHardwareConfigAllowed) {
                    }
                    if (!isHardwareConfigAllowed) {
                    }
                    i9 = Build.VERSION.SDK_INT;
                    i10 = options.inSampleSize;
                    if (i6 >= 0) {
                    }
                    int i3022 = options.inTargetDensity;
                    if (!(i3022 <= 0 && (i13 = options.inDensity) > 0 && i3022 != i13)) {
                    }
                    float f722 = (float) i10;
                    i11 = Math.round(((float) ((int) Math.ceil((double) (((float) i6) / f722)))) * f6);
                    int round422 = Math.round(((float) ((int) Math.ceil((double) (((float) i5) / f722)))) * f6);
                    if (Log.isLoggable(str2, 2)) {
                    }
                    i12 = round422;
                    BitmapPool bitmapPool322 = this.bitmapPool;
                    if (i9 >= 26) {
                    }
                    if (config == null) {
                    }
                    options.inBitmap = bitmapPool322.getDirty(i11, i12, config);
                    if (i9 < 28) {
                    }
                    decodeStream = decodeStream(imageReader, options, decodeCallbacks, this.bitmapPool);
                    decodeCallbacks.onDecodeComplete(this.bitmapPool, decodeStream);
                    if (Log.isLoggable(str2, 2)) {
                    }
                    if (decodeStream != null) {
                    }
                } else {
                    throw new IllegalArgumentException("Cannot round with null rounding");
                }
            } else {
                throw new IllegalArgumentException("Cannot scale with factor: " + scaleFactor + " from: " + downsampleStrategy + ", source: [" + i24 + "x" + i25 + "], target: [" + i26 + "x" + i27 + str8);
            }
        }
        if (Log.isLoggable(str2, i14)) {
            Log.d(str2, "Unable to determine dimensions for: " + imageType + " with target [" + i7 + str + i8 + str6);
        }
        isHardwareConfigAllowed = this.hardwareConfigState.isHardwareConfigAllowed(i7, i8, z6, z3);
        if (isHardwareConfigAllowed) {
        }
        if (!isHardwareConfigAllowed) {
        }
        i9 = Build.VERSION.SDK_INT;
        i10 = options.inSampleSize;
        if (i6 >= 0) {
        }
        int i30222 = options.inTargetDensity;
        if (!(i30222 <= 0 && (i13 = options.inDensity) > 0 && i30222 != i13)) {
        }
        float f7222 = (float) i10;
        i11 = Math.round(((float) ((int) Math.ceil((double) (((float) i6) / f7222)))) * f6);
        int round4222 = Math.round(((float) ((int) Math.ceil((double) (((float) i5) / f7222)))) * f6);
        if (Log.isLoggable(str2, 2)) {
        }
        i12 = round4222;
        BitmapPool bitmapPool3222 = this.bitmapPool;
        if (i9 >= 26) {
        }
        if (config == null) {
        }
        options.inBitmap = bitmapPool3222.getDirty(i11, i12, config);
        if (i9 < 28) {
        }
        decodeStream = decodeStream(imageReader, options, decodeCallbacks, this.bitmapPool);
        decodeCallbacks.onDecodeComplete(this.bitmapPool, decodeStream);
        if (Log.isLoggable(str2, 2)) {
        }
        if (decodeStream != null) {
        }
    }

    public final Resource<Bitmap> decode(ImageReader imageReader, int i, int i2, Options options, DecodeCallbacks decodeCallbacks) {
        Queue<BitmapFactory.Options> queue;
        BitmapFactory.Options poll;
        byte[] bArr = (byte[]) this.byteArrayPool.get(65536, byte[].class);
        synchronized (Downsampler.class) {
            queue = OPTIONS_QUEUE;
            synchronized (queue) {
                poll = queue.poll();
            }
            if (poll == null) {
                poll = new BitmapFactory.Options();
                resetOptions(poll);
            }
        }
        poll.inTempStorage = bArr;
        DecodeFormat decodeFormat = (DecodeFormat) options.get(DECODE_FORMAT);
        PreferredColorSpace preferredColorSpace = (PreferredColorSpace) options.get(PREFERRED_COLOR_SPACE);
        DownsampleStrategy downsampleStrategy = (DownsampleStrategy) options.get(DownsampleStrategy.OPTION);
        boolean booleanValue = ((Boolean) options.get(FIX_BITMAP_SIZE_TO_REQUESTED_DIMENSIONS)).booleanValue();
        Option<Boolean> option = ALLOW_HARDWARE_CONFIG;
        try {
            BitmapResource obtain = BitmapResource.obtain(decodeFromWrappedStreams(imageReader, poll, downsampleStrategy, decodeFormat, preferredColorSpace, options.get(option) != null && ((Boolean) options.get(option)).booleanValue(), i, i2, booleanValue, decodeCallbacks), this.bitmapPool);
            resetOptions(poll);
            synchronized (queue) {
                queue.offer(poll);
            }
            this.byteArrayPool.put(bArr);
            return obtain;
        } catch (Throwable th) {
            resetOptions(poll);
            Queue<BitmapFactory.Options> queue2 = OPTIONS_QUEUE;
            synchronized (queue2) {
                queue2.offer(poll);
                this.byteArrayPool.put(bArr);
                throw th;
            }
        }
    }
}
