package com.faster.cheetah.sdk.shadowsocks.core;

import android.util.SparseArray;
import com.android.tools.r8.GeneratedOutlineSupport;
import com.faster.cheetah.sdk.shadowsocks.dns.DnsPacket;
import com.faster.cheetah.sdk.shadowsocks.dns.Question;
import com.faster.cheetah.sdk.shadowsocks.dns.Resource;
import com.faster.cheetah.sdk.shadowsocks.dns.ResourcePointer;
import com.faster.cheetah.sdk.shadowsocks.tcpip.CommonMethods;
import com.faster.cheetah.sdk.shadowsocks.tcpip.IPHeader;
import com.faster.cheetah.sdk.shadowsocks.tcpip.UDPHeader;
import java.io.IOException;
import java.io.PrintStream;
import java.net.DatagramPacket;
import java.net.DatagramSocket;
import java.net.InetSocketAddress;
import java.nio.ByteBuffer;
import java.util.concurrent.ConcurrentHashMap;

public class DnsProxy implements Runnable {
    private static final ConcurrentHashMap<String, Integer> DomainIPMaps = new ConcurrentHashMap<>();
    private static final ConcurrentHashMap<Integer, String> IPDomainMaps = new ConcurrentHashMap<>();
    private final long QUERY_TIMEOUT_NS = 10000000000L;
    public boolean Stopped;
    private DatagramSocket m_Client = new DatagramSocket(0);
    private SparseArray<QueryState> m_QueryArray = new SparseArray<>();
    private short m_QueryID;
    private Thread m_ReceivedThread;

    public class QueryState {
        public int ClientIP;
        public short ClientPort;
        public short ClientQueryID;
        public long QueryNanoTime;
        public int RemoteIP;
        public short RemotePort;

        private QueryState() {
        }
    }

    private void OnDnsResponseReceived(IPHeader iPHeader, UDPHeader uDPHeader, DnsPacket dnsPacket) {
        QueryState queryState;
        synchronized (this.m_QueryArray) {
            queryState = this.m_QueryArray.get(dnsPacket.Header.ID);
            if (queryState != null) {
                this.m_QueryArray.remove(dnsPacket.Header.ID);
            }
        }
        if (queryState != null) {
            dnsPollution(uDPHeader.m_Data, dnsPacket);
            dnsPacket.Header.setID(queryState.ClientQueryID);
            iPHeader.setSourceIP(queryState.RemoteIP);
            iPHeader.setDestinationIP(queryState.ClientIP);
            iPHeader.setProtocol(IPHeader.UDP);
            iPHeader.setTotalLength(dnsPacket.Size + 28);
            uDPHeader.setSourcePort(queryState.RemotePort);
            uDPHeader.setDestinationPort(queryState.ClientPort);
            uDPHeader.setTotalLength(dnsPacket.Size + 8);
            LocalVpnService.Instance.sendUDPPacket(iPHeader, uDPHeader);
        }
    }

    private void clearExpiredQueries() {
        long nanoTime = System.nanoTime();
        for (int size = this.m_QueryArray.size() - 1; size >= 0; size--) {
            if (nanoTime - this.m_QueryArray.valueAt(size).QueryNanoTime > 10000000000L) {
                this.m_QueryArray.removeAt(size);
            }
        }
    }

    private boolean dnsPollution(byte[] bArr, DnsPacket dnsPacket) {
        if (dnsPacket.Header.QuestionCount > 0) {
            Question question = dnsPacket.Questions[0];
            if (question.Type == 1) {
                if (ProxyConfig.Instance.needProxy(question.Domain, getFirstIP(dnsPacket))) {
                    tamperDnsResponse(bArr, dnsPacket, getOrCreateFakeIP(question.Domain));
                    return true;
                }
            }
        }
        return false;
    }

    private int getFirstIP(DnsPacket dnsPacket) {
        for (int i = 0; i < dnsPacket.Header.ResourceCount; i++) {
            Resource resource = dnsPacket.Resources[i];
            if (resource.Type == 1) {
                return CommonMethods.readInt(resource.Data, 0);
            }
        }
        return 0;
    }

    private int getIPFromCache(String str) {
        Integer num = DomainIPMaps.get(str);
        if (num == null) {
            return 0;
        }
        return num.intValue();
    }

    private int getOrCreateFakeIP(String str) {
        Integer valueOf;
        ConcurrentHashMap<Integer, String> concurrentHashMap;
        Integer num = DomainIPMaps.get(str);
        if (num == null) {
            int hashCode = str.hashCode();
            do {
                valueOf = Integer.valueOf(ProxyConfig.FAKE_NETWORK_IP | (65535 & hashCode));
                hashCode++;
                concurrentHashMap = IPDomainMaps;
            } while (concurrentHashMap.containsKey(valueOf));
            DomainIPMaps.put(str, valueOf);
            concurrentHashMap.put(valueOf, str);
            num = valueOf;
        }
        return num.intValue();
    }

    private boolean interceptDns(IPHeader iPHeader, UDPHeader uDPHeader, DnsPacket dnsPacket) {
        Question question = dnsPacket.Questions[0];
        PrintStream printStream = System.out;
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("DNS Qeury ");
        outline25.append(question.Domain);
        printStream.println(outline25.toString());
        if (question.Type == 1) {
            ProxyConfig proxyConfig = ProxyConfig.Instance;
            String str = question.Domain;
            if (proxyConfig.needProxy(str, getIPFromCache(str))) {
                tamperDnsResponse(iPHeader.m_Data, dnsPacket, getOrCreateFakeIP(question.Domain));
                int sourceIP = iPHeader.getSourceIP();
                short sourcePort = uDPHeader.getSourcePort();
                iPHeader.setSourceIP(iPHeader.getDestinationIP());
                iPHeader.setDestinationIP(sourceIP);
                iPHeader.setTotalLength(dnsPacket.Size + 28);
                uDPHeader.setSourcePort(uDPHeader.getDestinationPort());
                uDPHeader.setDestinationPort(sourcePort);
                uDPHeader.setTotalLength(dnsPacket.Size + 8);
                LocalVpnService.Instance.sendUDPPacket(iPHeader, uDPHeader);
                return true;
            }
        }
        return false;
    }

    public static String reverseLookup(int i) {
        return IPDomainMaps.get(Integer.valueOf(i));
    }

    private void tamperDnsResponse(byte[] bArr, DnsPacket dnsPacket, int i) {
        Question question = dnsPacket.Questions[0];
        dnsPacket.Header.setResourceCount(1);
        dnsPacket.Header.setAResourceCount(0);
        dnsPacket.Header.setEResourceCount(0);
        ResourcePointer resourcePointer = new ResourcePointer(bArr, question.Length() + question.Offset());
        resourcePointer.setDomain(-16372);
        resourcePointer.setType(question.Type);
        resourcePointer.setClass(question.Class);
        resourcePointer.setTTL(ProxyConfig.Instance.getDnsTTL());
        resourcePointer.setDataLength(4);
        resourcePointer.setIP(i);
        dnsPacket.Size = question.Length() + 12 + 16;
    }

    public void onDnsRequestReceived(IPHeader iPHeader, UDPHeader uDPHeader, DnsPacket dnsPacket) {
        if (!interceptDns(iPHeader, uDPHeader, dnsPacket)) {
            QueryState queryState = new QueryState();
            queryState.ClientQueryID = dnsPacket.Header.ID;
            queryState.QueryNanoTime = System.nanoTime();
            queryState.ClientIP = iPHeader.getSourceIP();
            queryState.ClientPort = uDPHeader.getSourcePort();
            queryState.RemoteIP = iPHeader.getDestinationIP();
            queryState.RemotePort = uDPHeader.getDestinationPort();
            short s = (short) (this.m_QueryID + 1);
            this.m_QueryID = s;
            dnsPacket.Header.setID(s);
            synchronized (this.m_QueryArray) {
                clearExpiredQueries();
                this.m_QueryArray.put(this.m_QueryID, queryState);
            }
            InetSocketAddress inetSocketAddress = new InetSocketAddress(CommonMethods.ipIntToInet4Address(queryState.RemoteIP), queryState.RemotePort);
            DatagramPacket datagramPacket = new DatagramPacket(uDPHeader.m_Data, uDPHeader.m_Offset + 8, dnsPacket.Size);
            datagramPacket.setSocketAddress(inetSocketAddress);
            try {
                if (LocalVpnService.Instance.protect(this.m_Client)) {
                    this.m_Client.send(datagramPacket);
                } else {
                    System.err.println("VPN protect udp socket failed.");
                }
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
    }

    public void run() {
        try {
            byte[] bArr = new byte[2000];
            IPHeader iPHeader = new IPHeader(bArr, 0);
            iPHeader.Default();
            UDPHeader uDPHeader = new UDPHeader(bArr, 20);
            ByteBuffer wrap = ByteBuffer.wrap(bArr);
            wrap.position(28);
            ByteBuffer slice = wrap.slice();
            DatagramPacket datagramPacket = new DatagramPacket(bArr, 28, 1972);
            while (true) {
                DatagramSocket datagramSocket = this.m_Client;
                if (datagramSocket == null || datagramSocket.isClosed()) {
                    break;
                }
                datagramPacket.setLength(1972);
                this.m_Client.receive(datagramPacket);
                slice.clear();
                slice.limit(datagramPacket.getLength());
                try {
                    DnsPacket FromBytes = DnsPacket.FromBytes(slice);
                    if (FromBytes != null) {
                        OnDnsResponseReceived(iPHeader, uDPHeader, FromBytes);
                    }
                } catch (Exception e) {
                    e.printStackTrace();
                    LocalVpnService.Instance.writeLog("Parse dns error: %s", e);
                }
            }
        } catch (Exception e2) {
            e2.printStackTrace();
        } catch (Throwable th) {
            System.out.println("DnsResolver Thread Exited.");
            stop();
            throw th;
        }
        System.out.println("DnsResolver Thread Exited.");
        stop();
    }

    public void start() {
        Thread thread = new Thread(this);
        this.m_ReceivedThread = thread;
        thread.setName("DnsProxyThread");
        this.m_ReceivedThread.start();
    }

    public void stop() {
        this.Stopped = true;
        DatagramSocket datagramSocket = this.m_Client;
        if (datagramSocket != null) {
            datagramSocket.close();
            this.m_Client = null;
        }
    }
}
