package com.squareup.okhttp;

import com.android.tools.r8.GeneratedOutlineSupport;
import com.squareup.okhttp.internal.http.HttpConnection;
import com.squareup.okhttp.internal.http.HttpEngine;
import com.squareup.okhttp.internal.http.HttpTransport;
import com.squareup.okhttp.internal.http.RouteException;
import com.squareup.okhttp.internal.http.SocketConnector;
import com.squareup.okhttp.internal.http.SpdyTransport;
import com.squareup.okhttp.internal.http.Transport;
import com.squareup.okhttp.internal.spdy.SpdyConnection;
import java.io.IOException;
import java.net.Socket;
import java.net.UnknownServiceException;
import java.util.List;
import okio.BufferedSink;
import okio.BufferedSource;

public final class Connection {
    private boolean connected = false;
    private Handshake handshake;
    private HttpConnection httpConnection;
    private long idleStartTimeNs;
    private Object owner;
    private final ConnectionPool pool;
    private Protocol protocol = Protocol.HTTP_1_1;
    private int recycleCount;
    private final Route route;
    private Socket socket;
    private SpdyConnection spdyConnection;

    public Connection(ConnectionPool connectionPool, Route route2) {
        this.pool = connectionPool;
        this.route = route2;
    }

    public boolean clearOwner() {
        synchronized (this.pool) {
            if (this.owner == null) {
                return false;
            }
            this.owner = null;
            return true;
        }
    }

    public void closeIfOwnedBy(Object obj) {
        if (!isSpdy()) {
            synchronized (this.pool) {
                if (this.owner == obj) {
                    this.owner = null;
                    this.socket.close();
                    return;
                }
                return;
            }
        }
        throw new IllegalStateException();
    }

    public void connect(int i, int i2, int i3, Request request, List<ConnectionSpec> list, boolean z) {
        SocketConnector.ConnectedSocket connectedSocket;
        if (!this.connected) {
            SocketConnector socketConnector = new SocketConnector(this, this.pool);
            if (this.route.address.getSslSocketFactory() != null) {
                connectedSocket = socketConnector.connectTls(i, i2, i3, request, this.route, list, z);
            } else if (list.contains(ConnectionSpec.CLEARTEXT)) {
                connectedSocket = socketConnector.connectCleartext(i, i2, this.route);
            } else {
                throw new RouteException(new UnknownServiceException("CLEARTEXT communication not supported: " + list));
            }
            Socket socket2 = connectedSocket.socket;
            this.socket = socket2;
            this.handshake = connectedSocket.handshake;
            Protocol protocol2 = connectedSocket.alpnProtocol;
            if (protocol2 == null) {
                protocol2 = Protocol.HTTP_1_1;
            }
            this.protocol = protocol2;
            try {
                if (protocol2 != Protocol.SPDY_3) {
                    if (protocol2 != Protocol.HTTP_2) {
                        this.httpConnection = new HttpConnection(this.pool, this, socket2);
                        this.connected = true;
                    }
                }
                socket2.setSoTimeout(0);
                SpdyConnection build = new SpdyConnection.Builder(this.route.address.uriHost, true, this.socket).protocol(this.protocol).build();
                this.spdyConnection = build;
                build.sendConnectionPreface();
                this.connected = true;
            } catch (IOException e) {
                throw new RouteException(e);
            }
        } else {
            throw new IllegalStateException("already connected");
        }
    }

    public void connectAndSetOwner(OkHttpClient okHttpClient, Object obj, Request request) {
        setOwner(obj);
        if (!isConnected()) {
            connect(okHttpClient.getConnectTimeout(), okHttpClient.getReadTimeout(), okHttpClient.getWriteTimeout(), request, this.route.address.getConnectionSpecs(), okHttpClient.getRetryOnConnectionFailure());
            if (isSpdy()) {
                okHttpClient.getConnectionPool().share(this);
            }
            okHttpClient.routeDatabase().connected(getRoute());
        }
        setTimeouts(okHttpClient.getReadTimeout(), okHttpClient.getWriteTimeout());
    }

    public Handshake getHandshake() {
        return this.handshake;
    }

    public long getIdleStartTimeNs() {
        SpdyConnection spdyConnection2 = this.spdyConnection;
        return spdyConnection2 == null ? this.idleStartTimeNs : spdyConnection2.getIdleStartTimeNs();
    }

    public Object getOwner() {
        Object obj;
        synchronized (this.pool) {
            obj = this.owner;
        }
        return obj;
    }

    public Protocol getProtocol() {
        return this.protocol;
    }

    public Route getRoute() {
        return this.route;
    }

    public Socket getSocket() {
        return this.socket;
    }

    public void incrementRecycleCount() {
        this.recycleCount++;
    }

    public boolean isAlive() {
        return !this.socket.isClosed() && !this.socket.isInputShutdown() && !this.socket.isOutputShutdown();
    }

    public boolean isConnected() {
        return this.connected;
    }

    public boolean isIdle() {
        SpdyConnection spdyConnection2 = this.spdyConnection;
        return spdyConnection2 == null || spdyConnection2.isIdle();
    }

    public boolean isReadable() {
        HttpConnection httpConnection2 = this.httpConnection;
        if (httpConnection2 != null) {
            return httpConnection2.isReadable();
        }
        return true;
    }

    public boolean isSpdy() {
        return this.spdyConnection != null;
    }

    public Transport newTransport(HttpEngine httpEngine) {
        return this.spdyConnection != null ? new SpdyTransport(httpEngine, this.spdyConnection) : new HttpTransport(httpEngine, this.httpConnection);
    }

    public BufferedSink rawSink() {
        HttpConnection httpConnection2 = this.httpConnection;
        if (httpConnection2 != null) {
            return httpConnection2.rawSink();
        }
        throw new UnsupportedOperationException();
    }

    public BufferedSource rawSource() {
        HttpConnection httpConnection2 = this.httpConnection;
        if (httpConnection2 != null) {
            return httpConnection2.rawSource();
        }
        throw new UnsupportedOperationException();
    }

    public int recycleCount() {
        return this.recycleCount;
    }

    public void resetIdleStartTime() {
        if (this.spdyConnection == null) {
            this.idleStartTimeNs = System.nanoTime();
            return;
        }
        throw new IllegalStateException("spdyConnection != null");
    }

    public void setOwner(Object obj) {
        if (!isSpdy()) {
            synchronized (this.pool) {
                if (this.owner == null) {
                    this.owner = obj;
                } else {
                    throw new IllegalStateException("Connection already has an owner!");
                }
            }
        }
    }

    public void setProtocol(Protocol protocol2) {
        if (protocol2 != null) {
            this.protocol = protocol2;
            return;
        }
        throw new IllegalArgumentException("protocol == null");
    }

    public void setTimeouts(int i, int i2) {
        if (!this.connected) {
            throw new IllegalStateException("setTimeouts - not connected");
        } else if (this.httpConnection != null) {
            try {
                this.socket.setSoTimeout(i);
                this.httpConnection.setTimeouts(i, i2);
            } catch (IOException e) {
                throw new RouteException(e);
            }
        }
    }

    public String toString() {
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("Connection{");
        outline25.append(this.route.address.uriHost);
        outline25.append(":");
        outline25.append(this.route.address.uriPort);
        outline25.append(", proxy=");
        outline25.append(this.route.proxy);
        outline25.append(" hostAddress=");
        outline25.append(this.route.inetSocketAddress.getAddress().getHostAddress());
        outline25.append(" cipherSuite=");
        Handshake handshake2 = this.handshake;
        outline25.append(handshake2 != null ? handshake2.cipherSuite() : "none");
        outline25.append(" protocol=");
        outline25.append(this.protocol);
        outline25.append('}');
        return outline25.toString();
    }
}
