package com.squareup.okhttp.internal.http;

import com.android.tools.r8.GeneratedOutlineSupport;
import com.squareup.okhttp.Connection;
import com.squareup.okhttp.ConnectionPool;
import com.squareup.okhttp.Headers;
import com.squareup.okhttp.Response;
import com.squareup.okhttp.internal.Internal;
import com.squareup.okhttp.internal.Util;
import java.io.EOFException;
import java.io.IOException;
import java.net.ProtocolException;
import java.net.Socket;
import java.net.SocketTimeoutException;
import java.util.concurrent.TimeUnit;
import kotlin.jvm.internal.Intrinsics;
import kotlinx.coroutines.internal.SystemPropsKt;
import okio.Buffer;
import okio.BufferedSink;
import okio.BufferedSource;
import okio.ForwardingTimeout;
import okio.Sink;
import okio.Source;
import okio.Timeout;

public final class HttpConnection {
    private static final int ON_IDLE_CLOSE = 2;
    private static final int ON_IDLE_HOLD = 0;
    private static final int ON_IDLE_POOL = 1;
    private static final int STATE_CLOSED = 6;
    private static final int STATE_IDLE = 0;
    private static final int STATE_OPEN_REQUEST_BODY = 1;
    private static final int STATE_OPEN_RESPONSE_BODY = 4;
    private static final int STATE_READING_RESPONSE_BODY = 5;
    private static final int STATE_READ_RESPONSE_HEADERS = 3;
    private static final int STATE_WRITING_REQUEST_BODY = 2;
    private final Connection connection;
    private int onIdle = 0;
    private final ConnectionPool pool;
    private final BufferedSink sink;
    private final Socket socket;
    private final BufferedSource source;
    private int state = 0;

    public abstract class AbstractSource implements Source {
        public boolean closed;
        public final ForwardingTimeout timeout;

        private AbstractSource() {
            this.timeout = new ForwardingTimeout(HttpConnection.this.source.timeout());
        }

        @Override // okio.Source, java.io.Closeable, java.lang.AutoCloseable
        public abstract /* synthetic */ void close();

        public final void endOfInput(boolean z) {
            if (HttpConnection.this.state == 5) {
                HttpConnection.this.detachTimeout(this.timeout);
                HttpConnection.this.state = 0;
                if (z && HttpConnection.this.onIdle == 1) {
                    HttpConnection.this.onIdle = 0;
                    Internal.instance.recycle(HttpConnection.this.pool, HttpConnection.this.connection);
                } else if (HttpConnection.this.onIdle == 2) {
                    HttpConnection.this.state = 6;
                    HttpConnection.this.connection.getSocket().close();
                }
            } else {
                StringBuilder outline25 = GeneratedOutlineSupport.outline25("state: ");
                outline25.append(HttpConnection.this.state);
                throw new IllegalStateException(outline25.toString());
            }
        }

        @Override // okio.Source
        public abstract /* synthetic */ long read(Buffer buffer, long j);

        @Override // okio.Source
        public Timeout timeout() {
            return this.timeout;
        }

        public final void unexpectedEndOfInput() {
            Util.closeQuietly(HttpConnection.this.connection.getSocket());
            HttpConnection.this.state = 6;
        }
    }

    public final class ChunkedSink implements Sink {
        private boolean closed;
        private final ForwardingTimeout timeout;

        private ChunkedSink() {
            this.timeout = new ForwardingTimeout(HttpConnection.this.sink.timeout());
        }

        @Override // java.io.Closeable, java.lang.AutoCloseable, okio.Sink
        public synchronized void close() {
            if (!this.closed) {
                this.closed = true;
                HttpConnection.this.sink.writeUtf8("0\r\n\r\n");
                HttpConnection.this.detachTimeout(this.timeout);
                HttpConnection.this.state = 3;
            }
        }

        @Override // okio.Sink, java.io.Flushable
        public synchronized void flush() {
            if (!this.closed) {
                HttpConnection.this.sink.flush();
            }
        }

        @Override // okio.Sink
        public Timeout timeout() {
            return this.timeout;
        }

        @Override // okio.Sink
        public void write(Buffer buffer, long j) {
            if (this.closed) {
                throw new IllegalStateException("closed");
            } else if (j != 0) {
                HttpConnection.this.sink.writeHexadecimalUnsignedLong(j);
                HttpConnection.this.sink.writeUtf8("\r\n");
                HttpConnection.this.sink.write(buffer, j);
                HttpConnection.this.sink.writeUtf8("\r\n");
            }
        }
    }

    public class ChunkedSource extends AbstractSource {
        private static final long NO_CHUNK_YET = -1;
        private long bytesRemainingInChunk = -1;
        private boolean hasMoreChunks = true;
        private final HttpEngine httpEngine;

        public ChunkedSource(HttpEngine httpEngine2) {
            super();
            this.httpEngine = httpEngine2;
        }

        private void readChunkSize() {
            if (this.bytesRemainingInChunk != -1) {
                HttpConnection.this.source.readUtf8LineStrict();
            }
            try {
                this.bytesRemainingInChunk = HttpConnection.this.source.readHexadecimalUnsignedLong();
                String trim = HttpConnection.this.source.readUtf8LineStrict().trim();
                if (this.bytesRemainingInChunk < 0 || (!trim.isEmpty() && !trim.startsWith(";"))) {
                    throw new ProtocolException("expected chunk size and optional extensions but was \"" + this.bytesRemainingInChunk + trim + "\"");
                } else if (this.bytesRemainingInChunk == 0) {
                    this.hasMoreChunks = false;
                    Headers.Builder builder = new Headers.Builder();
                    HttpConnection.this.readHeaders(builder);
                    this.httpEngine.receiveHeaders(builder.build());
                    endOfInput(true);
                }
            } catch (NumberFormatException e) {
                throw new ProtocolException(e.getMessage());
            }
        }

        @Override // okio.Source, java.io.Closeable, com.squareup.okhttp.internal.http.HttpConnection.AbstractSource, java.lang.AutoCloseable
        public void close() {
            if (!this.closed) {
                if (this.hasMoreChunks && !Util.discard(this, 100, TimeUnit.MILLISECONDS)) {
                    unexpectedEndOfInput();
                }
                this.closed = true;
            }
        }

        @Override // okio.Source, com.squareup.okhttp.internal.http.HttpConnection.AbstractSource
        public long read(Buffer buffer, long j) {
            if (j < 0) {
                throw new IllegalArgumentException(GeneratedOutlineSupport.outline14("byteCount < 0: ", j));
            } else if (this.closed) {
                throw new IllegalStateException("closed");
            } else if (!this.hasMoreChunks) {
                return -1;
            } else {
                long j2 = this.bytesRemainingInChunk;
                if (j2 == 0 || j2 == -1) {
                    readChunkSize();
                    if (!this.hasMoreChunks) {
                        return -1;
                    }
                }
                long read = HttpConnection.this.source.read(buffer, Math.min(j, this.bytesRemainingInChunk));
                if (read != -1) {
                    this.bytesRemainingInChunk -= read;
                    return read;
                }
                unexpectedEndOfInput();
                throw new IOException("unexpected end of stream");
            }
        }
    }

    public final class FixedLengthSink implements Sink {
        private long bytesRemaining;
        private boolean closed;
        private final ForwardingTimeout timeout;

        @Override // java.io.Closeable, java.lang.AutoCloseable, okio.Sink
        public void close() {
            if (!this.closed) {
                this.closed = true;
                if (this.bytesRemaining <= 0) {
                    HttpConnection.this.detachTimeout(this.timeout);
                    HttpConnection.this.state = 3;
                    return;
                }
                throw new ProtocolException("unexpected end of stream");
            }
        }

        @Override // okio.Sink, java.io.Flushable
        public void flush() {
            if (!this.closed) {
                HttpConnection.this.sink.flush();
            }
        }

        @Override // okio.Sink
        public Timeout timeout() {
            return this.timeout;
        }

        @Override // okio.Sink
        public void write(Buffer buffer, long j) {
            if (!this.closed) {
                Util.checkOffsetAndCount(buffer.size, 0, j);
                if (j <= this.bytesRemaining) {
                    HttpConnection.this.sink.write(buffer, j);
                    this.bytesRemaining -= j;
                    return;
                }
                StringBuilder outline25 = GeneratedOutlineSupport.outline25("expected ");
                outline25.append(this.bytesRemaining);
                outline25.append(" bytes but received ");
                outline25.append(j);
                throw new ProtocolException(outline25.toString());
            }
            throw new IllegalStateException("closed");
        }

        private FixedLengthSink(long j) {
            this.timeout = new ForwardingTimeout(HttpConnection.this.sink.timeout());
            this.bytesRemaining = j;
        }
    }

    public class FixedLengthSource extends AbstractSource {
        private long bytesRemaining;

        public FixedLengthSource(long j) {
            super();
            this.bytesRemaining = j;
            if (j == 0) {
                endOfInput(true);
            }
        }

        @Override // okio.Source, java.io.Closeable, com.squareup.okhttp.internal.http.HttpConnection.AbstractSource, java.lang.AutoCloseable
        public void close() {
            if (!this.closed) {
                if (this.bytesRemaining != 0 && !Util.discard(this, 100, TimeUnit.MILLISECONDS)) {
                    unexpectedEndOfInput();
                }
                this.closed = true;
            }
        }

        @Override // okio.Source, com.squareup.okhttp.internal.http.HttpConnection.AbstractSource
        public long read(Buffer buffer, long j) {
            if (j < 0) {
                throw new IllegalArgumentException(GeneratedOutlineSupport.outline14("byteCount < 0: ", j));
            } else if (this.closed) {
                throw new IllegalStateException("closed");
            } else if (this.bytesRemaining == 0) {
                return -1;
            } else {
                long read = HttpConnection.this.source.read(buffer, Math.min(this.bytesRemaining, j));
                if (read != -1) {
                    long j2 = this.bytesRemaining - read;
                    this.bytesRemaining = j2;
                    if (j2 == 0) {
                        endOfInput(true);
                    }
                    return read;
                }
                unexpectedEndOfInput();
                throw new ProtocolException("unexpected end of stream");
            }
        }
    }

    public class UnknownLengthSource extends AbstractSource {
        private boolean inputExhausted;

        private UnknownLengthSource() {
            super();
        }

        @Override // okio.Source, java.io.Closeable, com.squareup.okhttp.internal.http.HttpConnection.AbstractSource, java.lang.AutoCloseable
        public void close() {
            if (!this.closed) {
                if (!this.inputExhausted) {
                    unexpectedEndOfInput();
                }
                this.closed = true;
            }
        }

        @Override // okio.Source, com.squareup.okhttp.internal.http.HttpConnection.AbstractSource
        public long read(Buffer buffer, long j) {
            if (j < 0) {
                throw new IllegalArgumentException(GeneratedOutlineSupport.outline14("byteCount < 0: ", j));
            } else if (this.closed) {
                throw new IllegalStateException("closed");
            } else if (this.inputExhausted) {
                return -1;
            } else {
                long read = HttpConnection.this.source.read(buffer, j);
                if (read != -1) {
                    return read;
                }
                this.inputExhausted = true;
                endOfInput(false);
                return -1;
            }
        }
    }

    public HttpConnection(ConnectionPool connectionPool, Connection connection2, Socket socket2) {
        this.pool = connectionPool;
        this.connection = connection2;
        this.socket = socket2;
        this.source = SystemPropsKt.buffer(SystemPropsKt.source(socket2));
        this.sink = SystemPropsKt.buffer(SystemPropsKt.sink(socket2));
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void detachTimeout(ForwardingTimeout forwardingTimeout) {
        Timeout timeout = forwardingTimeout.delegate;
        Timeout timeout2 = Timeout.NONE;
        Intrinsics.checkNotNullParameter(timeout2, "delegate");
        forwardingTimeout.delegate = timeout2;
        timeout.clearDeadline();
        timeout.clearTimeout();
    }

    public long bufferSize() {
        return this.source.buffer().size;
    }

    public void closeIfOwnedBy(Object obj) {
        Internal.instance.closeIfOwnedBy(this.connection, obj);
    }

    public void closeOnIdle() {
        this.onIdle = 2;
        if (this.state == 0) {
            this.state = 6;
            this.connection.getSocket().close();
        }
    }

    public void flush() {
        this.sink.flush();
    }

    public boolean isClosed() {
        return this.state == 6;
    }

    /* JADX INFO: finally extract failed */
    public boolean isReadable() {
        try {
            int soTimeout = this.socket.getSoTimeout();
            try {
                this.socket.setSoTimeout(1);
                if (this.source.exhausted()) {
                    this.socket.setSoTimeout(soTimeout);
                    return false;
                }
                this.socket.setSoTimeout(soTimeout);
                return true;
            } catch (Throwable th) {
                this.socket.setSoTimeout(soTimeout);
                throw th;
            }
        } catch (SocketTimeoutException unused) {
            return true;
        } catch (IOException unused2) {
            return false;
        }
    }

    public Sink newChunkedSink() {
        if (this.state == 1) {
            this.state = 2;
            return new ChunkedSink();
        }
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("state: ");
        outline25.append(this.state);
        throw new IllegalStateException(outline25.toString());
    }

    public Source newChunkedSource(HttpEngine httpEngine) {
        if (this.state == 4) {
            this.state = 5;
            return new ChunkedSource(httpEngine);
        }
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("state: ");
        outline25.append(this.state);
        throw new IllegalStateException(outline25.toString());
    }

    public Sink newFixedLengthSink(long j) {
        if (this.state == 1) {
            this.state = 2;
            return new FixedLengthSink(j);
        }
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("state: ");
        outline25.append(this.state);
        throw new IllegalStateException(outline25.toString());
    }

    public Source newFixedLengthSource(long j) {
        if (this.state == 4) {
            this.state = 5;
            return new FixedLengthSource(j);
        }
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("state: ");
        outline25.append(this.state);
        throw new IllegalStateException(outline25.toString());
    }

    public Source newUnknownLengthSource() {
        if (this.state == 4) {
            this.state = 5;
            return new UnknownLengthSource();
        }
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("state: ");
        outline25.append(this.state);
        throw new IllegalStateException(outline25.toString());
    }

    public void poolOnIdle() {
        this.onIdle = 1;
        if (this.state == 0) {
            this.onIdle = 0;
            Internal.instance.recycle(this.pool, this.connection);
        }
    }

    public BufferedSink rawSink() {
        return this.sink;
    }

    public BufferedSource rawSource() {
        return this.source;
    }

    public void readHeaders(Headers.Builder builder) {
        while (true) {
            String readUtf8LineStrict = this.source.readUtf8LineStrict();
            if (readUtf8LineStrict.length() != 0) {
                Internal.instance.addLenient(builder, readUtf8LineStrict);
            } else {
                return;
            }
        }
    }

    public Response.Builder readResponse() {
        StatusLine parse;
        Response.Builder message;
        int i = this.state;
        if (i == 1 || i == 3) {
            do {
                try {
                    parse = StatusLine.parse(this.source.readUtf8LineStrict());
                    message = new Response.Builder().protocol(parse.protocol).code(parse.code).message(parse.message);
                    Headers.Builder builder = new Headers.Builder();
                    readHeaders(builder);
                    builder.add(OkHeaders.SELECTED_PROTOCOL, parse.protocol.toString());
                    message.headers(builder.build());
                } catch (EOFException e) {
                    StringBuilder outline25 = GeneratedOutlineSupport.outline25("unexpected end of stream on ");
                    outline25.append(this.connection);
                    outline25.append(" (recycle count=");
                    outline25.append(Internal.instance.recycleCount(this.connection));
                    outline25.append(")");
                    IOException iOException = new IOException(outline25.toString());
                    iOException.initCause(e);
                    throw iOException;
                }
            } while (parse.code == 100);
            this.state = 4;
            return message;
        }
        StringBuilder outline252 = GeneratedOutlineSupport.outline25("state: ");
        outline252.append(this.state);
        throw new IllegalStateException(outline252.toString());
    }

    public void setTimeouts(int i, int i2) {
        if (i != 0) {
            this.source.timeout().timeout((long) i, TimeUnit.MILLISECONDS);
        }
        if (i2 != 0) {
            this.sink.timeout().timeout((long) i2, TimeUnit.MILLISECONDS);
        }
    }

    public void writeRequest(Headers headers, String str) {
        if (this.state == 0) {
            this.sink.writeUtf8(str).writeUtf8("\r\n");
            int size = headers.size();
            for (int i = 0; i < size; i++) {
                this.sink.writeUtf8(headers.name(i)).writeUtf8(": ").writeUtf8(headers.value(i)).writeUtf8("\r\n");
            }
            this.sink.writeUtf8("\r\n");
            this.state = 1;
            return;
        }
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("state: ");
        outline25.append(this.state);
        throw new IllegalStateException(outline25.toString());
    }

    public void writeRequestBody(RetryableSink retryableSink) {
        if (this.state == 1) {
            this.state = 3;
            retryableSink.writeToSocket(this.sink);
            return;
        }
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("state: ");
        outline25.append(this.state);
        throw new IllegalStateException(outline25.toString());
    }
}
