package io.netty.channel;

import com.android.tools.r8.GeneratedOutlineSupport;
import io.netty.buffer.ByteBuf;
import io.netty.buffer.ByteBufAllocator;
import io.netty.buffer.CompositeByteBuf;
import io.netty.util.ReferenceCountUtil;
import io.netty.util.concurrent.Future;
import io.netty.util.concurrent.GenericFutureListener;
import io.netty.util.internal.ObjectUtil;
import io.netty.util.internal.PlatformDependent;
import io.netty.util.internal.logging.InternalLogger;
import io.netty.util.internal.logging.InternalLoggerFactory;
import java.util.ArrayDeque;

public abstract class AbstractCoalescingBufferQueue {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    private static final InternalLogger logger = InternalLoggerFactory.getInstance(AbstractCoalescingBufferQueue.class);
    private final ArrayDeque<Object> bufAndListenerPairs;
    private int readableBytes;
    private final PendingBytesTracker tracker;

    public AbstractCoalescingBufferQueue(Channel channel, int i) {
        PendingBytesTracker pendingBytesTracker;
        this.bufAndListenerPairs = new ArrayDeque<>(i);
        if (channel == null) {
            pendingBytesTracker = null;
        } else {
            pendingBytesTracker = PendingBytesTracker.newTracker(channel);
        }
        this.tracker = pendingBytesTracker;
    }

    private void decrementReadableBytes(int i) {
        this.readableBytes -= i;
        PendingBytesTracker pendingBytesTracker = this.tracker;
        if (pendingBytesTracker != null) {
            pendingBytesTracker.decrementPendingOutboundBytes((long) i);
        }
    }

    private void incrementReadableBytes(int i) {
        int i2 = this.readableBytes;
        int i3 = i2 + i;
        if (i3 >= i2) {
            this.readableBytes = i3;
            PendingBytesTracker pendingBytesTracker = this.tracker;
            if (pendingBytesTracker != null) {
                pendingBytesTracker.incrementPendingOutboundBytes((long) i);
                return;
            }
            return;
        }
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("buffer queue length overflow: ");
        outline25.append(this.readableBytes);
        outline25.append(" + ");
        outline25.append(i);
        throw new IllegalStateException(outline25.toString());
    }

    private void releaseAndCompleteAll(ChannelFuture channelFuture) {
        Throwable th = null;
        while (true) {
            Object poll = this.bufAndListenerPairs.poll();
            if (poll == null) {
                break;
            }
            try {
                if (poll instanceof ByteBuf) {
                    ByteBuf byteBuf = (ByteBuf) poll;
                    decrementReadableBytes(byteBuf.readableBytes());
                    ReferenceCountUtil.safeRelease(byteBuf);
                } else {
                    ((ChannelFutureListener) poll).operationComplete(channelFuture);
                }
            } catch (Throwable th2) {
                if (th == null) {
                    th = th2;
                } else {
                    logger.info("Throwable being suppressed because Throwable {} is already pending", th, th2);
                }
            }
        }
        if (th != null) {
            throw new IllegalStateException(th);
        }
    }

    private static ChannelFutureListener toChannelFutureListener(ChannelPromise channelPromise) {
        if (channelPromise.isVoid()) {
            return null;
        }
        return new DelegatingChannelPromiseNotifier(channelPromise);
    }

    public final void add(ByteBuf byteBuf) {
        add(byteBuf, (ChannelFutureListener) null);
    }

    public final void addFirst(ByteBuf byteBuf, ChannelPromise channelPromise) {
        addFirst(byteBuf, toChannelFutureListener(channelPromise));
    }

    public abstract ByteBuf compose(ByteBufAllocator byteBufAllocator, ByteBuf byteBuf, ByteBuf byteBuf2);

    public ByteBuf composeFirst(ByteBufAllocator byteBufAllocator, ByteBuf byteBuf) {
        return byteBuf;
    }

    public final ByteBuf composeIntoComposite(ByteBufAllocator byteBufAllocator, ByteBuf byteBuf, ByteBuf byteBuf2) {
        CompositeByteBuf compositeBuffer = byteBufAllocator.compositeBuffer(size() + 2);
        try {
            compositeBuffer.addComponent(true, byteBuf);
            compositeBuffer.addComponent(true, byteBuf2);
        } catch (Throwable th) {
            compositeBuffer.release();
            ReferenceCountUtil.safeRelease(byteBuf2);
            PlatformDependent.throwException(th);
        }
        return compositeBuffer;
    }

    public final ByteBuf copyAndCompose(ByteBufAllocator byteBufAllocator, ByteBuf byteBuf, ByteBuf byteBuf2) {
        ByteBuf ioBuffer = byteBufAllocator.ioBuffer(byteBuf2.readableBytes() + byteBuf.readableBytes());
        try {
            ioBuffer.writeBytes(byteBuf).writeBytes(byteBuf2);
        } catch (Throwable th) {
            ioBuffer.release();
            ReferenceCountUtil.safeRelease(byteBuf2);
            PlatformDependent.throwException(th);
        }
        byteBuf.release();
        byteBuf2.release();
        return ioBuffer;
    }

    public final void copyTo(AbstractCoalescingBufferQueue abstractCoalescingBufferQueue) {
        abstractCoalescingBufferQueue.bufAndListenerPairs.addAll(this.bufAndListenerPairs);
        abstractCoalescingBufferQueue.incrementReadableBytes(this.readableBytes);
    }

    public final boolean isEmpty() {
        return this.bufAndListenerPairs.isEmpty();
    }

    public final int readableBytes() {
        return this.readableBytes;
    }

    public final void releaseAndFailAll(ChannelOutboundInvoker channelOutboundInvoker, Throwable th) {
        releaseAndCompleteAll(channelOutboundInvoker.newFailedFuture(th));
    }

    public final ByteBuf remove(ByteBufAllocator byteBufAllocator, int i, ChannelPromise channelPromise) {
        Throwable th;
        ByteBuf byteBuf;
        ObjectUtil.checkPositiveOrZero(i, "bytes");
        ObjectUtil.checkNotNull(channelPromise, "aggregatePromise");
        if (this.bufAndListenerPairs.isEmpty()) {
            return removeEmptyValue();
        }
        int min = Math.min(i, this.readableBytes);
        ByteBuf byteBuf2 = null;
        int i2 = min;
        ByteBuf byteBuf3 = null;
        while (true) {
            try {
                Object poll = this.bufAndListenerPairs.poll();
                if (poll == null) {
                    break;
                } else if (poll instanceof ChannelFutureListener) {
                    channelPromise.addListener((GenericFutureListener<? extends Future<? super Void>>) ((ChannelFutureListener) poll));
                } else {
                    ByteBuf byteBuf4 = (ByteBuf) poll;
                    try {
                        if (byteBuf4.readableBytes() > i2) {
                            this.bufAndListenerPairs.addFirst(byteBuf4);
                            if (i2 > 0) {
                                ByteBuf readRetainedSlice = byteBuf4.readRetainedSlice(i2);
                                if (byteBuf3 == null) {
                                    byteBuf = composeFirst(byteBufAllocator, readRetainedSlice);
                                } else {
                                    byteBuf = compose(byteBufAllocator, byteBuf3, readRetainedSlice);
                                }
                                byteBuf3 = byteBuf;
                                i2 = 0;
                            }
                        } else {
                            i2 -= byteBuf4.readableBytes();
                            if (byteBuf3 == null) {
                                byteBuf3 = composeFirst(byteBufAllocator, byteBuf4);
                            } else {
                                byteBuf3 = compose(byteBufAllocator, byteBuf3, byteBuf4);
                            }
                        }
                    } catch (Throwable th2) {
                        th = th2;
                        byteBuf2 = byteBuf4;
                        ReferenceCountUtil.safeRelease(byteBuf2);
                        ReferenceCountUtil.safeRelease(byteBuf3);
                        channelPromise.setFailure(th);
                        PlatformDependent.throwException(th);
                        decrementReadableBytes(min - i2);
                        return byteBuf3;
                    }
                }
            } catch (Throwable th3) {
                th = th3;
                ReferenceCountUtil.safeRelease(byteBuf2);
                ReferenceCountUtil.safeRelease(byteBuf3);
                channelPromise.setFailure(th);
                PlatformDependent.throwException(th);
                decrementReadableBytes(min - i2);
                return byteBuf3;
            }
        }
        decrementReadableBytes(min - i2);
        return byteBuf3;
    }

    public abstract ByteBuf removeEmptyValue();

    public final ByteBuf removeFirst(ChannelPromise channelPromise) {
        Object poll = this.bufAndListenerPairs.poll();
        if (poll == null) {
            return null;
        }
        ByteBuf byteBuf = (ByteBuf) poll;
        decrementReadableBytes(byteBuf.readableBytes());
        Object peek = this.bufAndListenerPairs.peek();
        if (peek instanceof ChannelFutureListener) {
            channelPromise.addListener((GenericFutureListener<? extends Future<? super Void>>) ((ChannelFutureListener) peek));
            this.bufAndListenerPairs.poll();
        }
        return byteBuf;
    }

    public final int size() {
        return this.bufAndListenerPairs.size();
    }

    public String toString() {
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("bytes: ");
        outline25.append(this.readableBytes);
        outline25.append(" buffers: ");
        outline25.append(size() >> 1);
        return outline25.toString();
    }

    public final void writeAndRemoveAll(ChannelHandlerContext channelHandlerContext) {
        ByteBuf byteBuf = null;
        Throwable th = null;
        while (true) {
            Object poll = this.bufAndListenerPairs.poll();
            if (poll == null) {
                if (byteBuf == null) {
                    break;
                }
                try {
                    decrementReadableBytes(byteBuf.readableBytes());
                    channelHandlerContext.write(byteBuf, channelHandlerContext.voidPromise());
                    break;
                } catch (Throwable th2) {
                    if (th == null) {
                        th = th2;
                    } else {
                        logger.info("Throwable being suppressed because Throwable {} is already pending", th, th2);
                    }
                }
            } else if (poll instanceof ByteBuf) {
                if (byteBuf != null) {
                    decrementReadableBytes(byteBuf.readableBytes());
                    channelHandlerContext.write(byteBuf, channelHandlerContext.voidPromise());
                }
                byteBuf = (ByteBuf) poll;
            } else {
                if (poll instanceof ChannelPromise) {
                    decrementReadableBytes(byteBuf.readableBytes());
                    channelHandlerContext.write(byteBuf, (ChannelPromise) poll);
                } else {
                    decrementReadableBytes(byteBuf.readableBytes());
                    channelHandlerContext.write(byteBuf).addListener((ChannelFutureListener) poll);
                }
                byteBuf = null;
            }
        }
        if (th != null) {
            throw new IllegalStateException(th);
        }
    }

    private void addFirst(ByteBuf byteBuf, ChannelFutureListener channelFutureListener) {
        if (channelFutureListener != null) {
            this.bufAndListenerPairs.addFirst(channelFutureListener);
        }
        this.bufAndListenerPairs.addFirst(byteBuf);
        incrementReadableBytes(byteBuf.readableBytes());
    }

    public final void add(ByteBuf byteBuf, ChannelPromise channelPromise) {
        add(byteBuf, toChannelFutureListener(channelPromise));
    }

    public final void add(ByteBuf byteBuf, ChannelFutureListener channelFutureListener) {
        this.bufAndListenerPairs.add(byteBuf);
        if (channelFutureListener != null) {
            this.bufAndListenerPairs.add(channelFutureListener);
        }
        incrementReadableBytes(byteBuf.readableBytes());
    }
}
