package io.netty.channel;

import io.netty.util.concurrent.FastThreadLocal;
import io.netty.util.internal.PlatformDependent;
import io.netty.util.internal.logging.InternalLogger;
import io.netty.util.internal.logging.InternalLoggerFactory;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
import java.net.SocketAddress;
import java.security.AccessController;
import java.security.PrivilegedExceptionAction;
import java.util.Map;
import java.util.WeakHashMap;

public final class ChannelHandlerMask {
    private static final FastThreadLocal<Map<Class<? extends ChannelHandler>, Integer>> MASKS = new FastThreadLocal<Map<Class<? extends ChannelHandler>, Integer>>() {
        /* class io.netty.channel.ChannelHandlerMask.AnonymousClass1 */

        @Override // io.netty.util.concurrent.FastThreadLocal
        public Map<Class<? extends ChannelHandler>, Integer> initialValue() {
            return new WeakHashMap(32);
        }
    };
    private static final int MASK_ALL_INBOUND = 511;
    private static final int MASK_ALL_OUTBOUND = 130561;
    public static final int MASK_BIND = 512;
    public static final int MASK_CHANNEL_ACTIVE = 8;
    public static final int MASK_CHANNEL_INACTIVE = 16;
    public static final int MASK_CHANNEL_READ = 32;
    public static final int MASK_CHANNEL_READ_COMPLETE = 64;
    public static final int MASK_CHANNEL_REGISTERED = 2;
    public static final int MASK_CHANNEL_UNREGISTERED = 4;
    public static final int MASK_CHANNEL_WRITABILITY_CHANGED = 256;
    public static final int MASK_CLOSE = 4096;
    public static final int MASK_CONNECT = 1024;
    public static final int MASK_DEREGISTER = 8192;
    public static final int MASK_DISCONNECT = 2048;
    public static final int MASK_EXCEPTION_CAUGHT = 1;
    public static final int MASK_FLUSH = 65536;
    public static final int MASK_ONLY_INBOUND = 510;
    public static final int MASK_ONLY_OUTBOUND = 130560;
    public static final int MASK_READ = 16384;
    public static final int MASK_USER_EVENT_TRIGGERED = 128;
    public static final int MASK_WRITE = 32768;
    private static final InternalLogger logger = InternalLoggerFactory.getInstance(ChannelHandlerMask.class);

    @Target({ElementType.METHOD})
    @Retention(RetentionPolicy.RUNTIME)
    public @interface Skip {
    }

    private ChannelHandlerMask() {
    }

    private static boolean isSkippable(final Class<?> cls, final String str, final Class<?>... clsArr) {
        return ((Boolean) AccessController.doPrivileged(new PrivilegedExceptionAction<Boolean>() {
            /* class io.netty.channel.ChannelHandlerMask.AnonymousClass2 */

            @Override // java.security.PrivilegedExceptionAction
            public Boolean run() {
                try {
                    return Boolean.valueOf(cls.getMethod(str, clsArr).isAnnotationPresent(Skip.class));
                } catch (NoSuchMethodException e) {
                    if (ChannelHandlerMask.logger.isDebugEnabled()) {
                        ChannelHandlerMask.logger.debug("Class {} missing method {}, assume we can not skip execution", cls, str, e);
                    }
                    return Boolean.FALSE;
                }
            }
        })).booleanValue();
    }

    public static int mask(Class<? extends ChannelHandler> cls) {
        Map<Class<? extends ChannelHandler>, Integer> map = MASKS.get();
        Integer num = map.get(cls);
        if (num == null) {
            num = Integer.valueOf(mask0(cls));
            map.put(cls, num);
        }
        return num.intValue();
    }

    private static int mask0(Class<? extends ChannelHandler> cls) {
        Exception e;
        int i;
        int i2 = 1;
        try {
            if (ChannelInboundHandler.class.isAssignableFrom(cls)) {
                i = MASK_ALL_INBOUND;
                try {
                    if (isSkippable(cls, "channelRegistered", ChannelHandlerContext.class)) {
                        i = 509;
                    }
                } catch (Exception e2) {
                    e = e2;
                    i2 = MASK_ALL_INBOUND;
                    PlatformDependent.throwException(e);
                    return i2;
                }
                try {
                    if (isSkippable(cls, "channelUnregistered", ChannelHandlerContext.class)) {
                        i &= -5;
                    }
                    if (isSkippable(cls, "channelActive", ChannelHandlerContext.class)) {
                        i &= -9;
                    }
                    if (isSkippable(cls, "channelInactive", ChannelHandlerContext.class)) {
                        i &= -17;
                    }
                    if (isSkippable(cls, "channelRead", ChannelHandlerContext.class, Object.class)) {
                        i &= -33;
                    }
                    if (isSkippable(cls, "channelReadComplete", ChannelHandlerContext.class)) {
                        i &= -65;
                    }
                    if (isSkippable(cls, "channelWritabilityChanged", ChannelHandlerContext.class)) {
                        i &= -257;
                    }
                    if (isSkippable(cls, "userEventTriggered", ChannelHandlerContext.class, Object.class)) {
                        i &= -129;
                    }
                } catch (Exception e3) {
                    e = e3;
                    i2 = i;
                    PlatformDependent.throwException(e);
                    return i2;
                }
            } else {
                i = 1;
            }
            if (ChannelOutboundHandler.class.isAssignableFrom(cls)) {
                i |= MASK_ALL_OUTBOUND;
                if (isSkippable(cls, "bind", ChannelHandlerContext.class, SocketAddress.class, ChannelPromise.class)) {
                    i &= -513;
                }
                if (isSkippable(cls, "connect", ChannelHandlerContext.class, SocketAddress.class, SocketAddress.class, ChannelPromise.class)) {
                    i &= -1025;
                }
                if (isSkippable(cls, "disconnect", ChannelHandlerContext.class, ChannelPromise.class)) {
                    i &= -2049;
                }
                if (isSkippable(cls, "close", ChannelHandlerContext.class, ChannelPromise.class)) {
                    i &= -4097;
                }
                if (isSkippable(cls, "deregister", ChannelHandlerContext.class, ChannelPromise.class)) {
                    i &= -8193;
                }
                if (isSkippable(cls, "read", ChannelHandlerContext.class)) {
                    i &= -16385;
                }
                if (isSkippable(cls, "write", ChannelHandlerContext.class, Object.class, ChannelPromise.class)) {
                    i = -32769 & i;
                }
                if (isSkippable(cls, "flush", ChannelHandlerContext.class)) {
                    i &= -65537;
                }
            }
            if (isSkippable(cls, "exceptionCaught", ChannelHandlerContext.class, Throwable.class)) {
                return i & -2;
            }
            return i;
        } catch (Exception e4) {
            e = e4;
            PlatformDependent.throwException(e);
            return i2;
        }
    }
}
