package io.netty.channel;

import io.netty.util.concurrent.Future;
import io.netty.util.concurrent.GenericFutureListener;
import io.netty.util.concurrent.Promise;
import io.netty.util.internal.ObjectUtil;
import io.netty.util.internal.PromiseNotificationUtil;
import io.netty.util.internal.logging.InternalLogger;
import io.netty.util.internal.logging.InternalLoggerFactory;
import java.util.concurrent.TimeUnit;

public final class DelegatingChannelPromiseNotifier implements ChannelPromise, ChannelFutureListener {
    private static final InternalLogger logger = InternalLoggerFactory.getInstance(DelegatingChannelPromiseNotifier.class);
    private final ChannelPromise delegate;
    private final boolean logNotifyFailure;

    public DelegatingChannelPromiseNotifier(ChannelPromise channelPromise) {
        this(channelPromise, !(channelPromise instanceof VoidChannelPromise));
    }

    @Override // io.netty.util.concurrent.Future
    public boolean cancel(boolean z) {
        return this.delegate.cancel(z);
    }

    @Override // io.netty.util.concurrent.Future
    public Throwable cause() {
        return this.delegate.cause();
    }

    @Override // io.netty.channel.ChannelPromise, io.netty.channel.ChannelFuture
    public Channel channel() {
        return this.delegate.channel();
    }

    @Override // io.netty.util.concurrent.Future
    public boolean isCancellable() {
        return this.delegate.isCancellable();
    }

    public boolean isCancelled() {
        return this.delegate.isCancelled();
    }

    public boolean isDone() {
        return this.delegate.isDone();
    }

    @Override // io.netty.util.concurrent.Future
    public boolean isSuccess() {
        return this.delegate.isSuccess();
    }

    @Override // io.netty.channel.ChannelFuture
    public boolean isVoid() {
        return this.delegate.isVoid();
    }

    @Override // io.netty.util.concurrent.Promise
    public boolean setUncancellable() {
        return this.delegate.setUncancellable();
    }

    @Override // io.netty.util.concurrent.Promise
    public boolean tryFailure(Throwable th) {
        return this.delegate.tryFailure(th);
    }

    @Override // io.netty.channel.ChannelPromise
    public ChannelPromise unvoid() {
        return isVoid() ? new DelegatingChannelPromiseNotifier(this.delegate.unvoid()) : this;
    }

    public DelegatingChannelPromiseNotifier(ChannelPromise channelPromise, boolean z) {
        this.delegate = (ChannelPromise) ObjectUtil.checkNotNull(channelPromise, "delegate");
        this.logNotifyFailure = z;
    }

    @Override // io.netty.util.concurrent.Future
    public Void getNow() {
        return (Void) this.delegate.getNow();
    }

    public void operationComplete(ChannelFuture channelFuture) {
        InternalLogger internalLogger = this.logNotifyFailure ? logger : null;
        if (channelFuture.isSuccess()) {
            PromiseNotificationUtil.trySuccess(this.delegate, (Void) channelFuture.get(), internalLogger);
        } else if (channelFuture.isCancelled()) {
            PromiseNotificationUtil.tryCancel(this.delegate, internalLogger);
        } else {
            PromiseNotificationUtil.tryFailure(this.delegate, channelFuture.cause(), internalLogger);
        }
    }

    /* Return type fixed from 'io.netty.channel.ChannelPromise' to match base method */
    @Override // io.netty.channel.ChannelPromise, io.netty.util.concurrent.Promise
    public Promise<Void> setFailure(Throwable th) {
        this.delegate.setFailure(th);
        return this;
    }

    @Override // io.netty.channel.ChannelPromise
    public ChannelPromise setSuccess(Void r2) {
        this.delegate.setSuccess(r2);
        return this;
    }

    @Override // io.netty.channel.ChannelPromise
    public boolean trySuccess() {
        return this.delegate.trySuccess();
    }

    @Override // java.util.concurrent.Future
    public Void get() {
        return (Void) this.delegate.get();
    }

    @Override // io.netty.channel.ChannelPromise
    public ChannelPromise setSuccess() {
        this.delegate.setSuccess();
        return this;
    }

    public boolean trySuccess(Void r2) {
        return this.delegate.trySuccess(r2);
    }

    /* Return type fixed from 'io.netty.channel.ChannelPromise' to match base method */
    @Override // io.netty.channel.ChannelPromise, io.netty.util.concurrent.Promise, io.netty.util.concurrent.Future, io.netty.channel.ChannelFuture
    public Promise<Void> addListener(GenericFutureListener<? extends Future<? super Void>> genericFutureListener) {
        this.delegate.addListener(genericFutureListener);
        return this;
    }

    /* Return type fixed from 'io.netty.channel.ChannelPromise' to match base method */
    @Override // io.netty.channel.ChannelPromise, io.netty.util.concurrent.Promise, io.netty.util.concurrent.Future, io.netty.channel.ChannelFuture
    public Promise<Void> addListeners(GenericFutureListener<? extends Future<? super Void>>... genericFutureListenerArr) {
        this.delegate.addListeners(genericFutureListenerArr);
        return this;
    }

    /* Return type fixed from 'io.netty.channel.ChannelPromise' to match base method */
    @Override // io.netty.channel.ChannelPromise, io.netty.util.concurrent.Promise, io.netty.util.concurrent.Future, io.netty.channel.ChannelFuture
    public Promise<Void> await() {
        this.delegate.await();
        return this;
    }

    /* Return type fixed from 'io.netty.channel.ChannelPromise' to match base method */
    @Override // io.netty.channel.ChannelPromise, io.netty.util.concurrent.Promise, io.netty.util.concurrent.Future, io.netty.channel.ChannelFuture
    public Promise<Void> awaitUninterruptibly() {
        this.delegate.awaitUninterruptibly();
        return this;
    }

    @Override // java.util.concurrent.Future
    public Void get(long j, TimeUnit timeUnit) {
        return (Void) this.delegate.get(j, timeUnit);
    }

    /* Return type fixed from 'io.netty.channel.ChannelPromise' to match base method */
    @Override // io.netty.channel.ChannelPromise, io.netty.util.concurrent.Promise, io.netty.util.concurrent.Future, io.netty.channel.ChannelFuture
    public Promise<Void> removeListener(GenericFutureListener<? extends Future<? super Void>> genericFutureListener) {
        this.delegate.removeListener(genericFutureListener);
        return this;
    }

    /* Return type fixed from 'io.netty.channel.ChannelPromise' to match base method */
    @Override // io.netty.channel.ChannelPromise, io.netty.util.concurrent.Promise, io.netty.util.concurrent.Future, io.netty.channel.ChannelFuture
    public Promise<Void> removeListeners(GenericFutureListener<? extends Future<? super Void>>... genericFutureListenerArr) {
        this.delegate.removeListeners(genericFutureListenerArr);
        return this;
    }

    /* Return type fixed from 'io.netty.channel.ChannelPromise' to match base method */
    @Override // io.netty.channel.ChannelPromise, io.netty.util.concurrent.Promise, io.netty.util.concurrent.Future, io.netty.channel.ChannelFuture
    public Promise<Void> sync() {
        this.delegate.sync();
        return this;
    }

    /* Return type fixed from 'io.netty.channel.ChannelPromise' to match base method */
    @Override // io.netty.channel.ChannelPromise, io.netty.util.concurrent.Promise, io.netty.util.concurrent.Future, io.netty.channel.ChannelFuture
    public Promise<Void> syncUninterruptibly() {
        this.delegate.syncUninterruptibly();
        return this;
    }

    @Override // io.netty.util.concurrent.Future
    public boolean await(long j, TimeUnit timeUnit) {
        return this.delegate.await(j, timeUnit);
    }

    @Override // io.netty.util.concurrent.Future
    public boolean awaitUninterruptibly(long j, TimeUnit timeUnit) {
        return this.delegate.awaitUninterruptibly(j, timeUnit);
    }

    @Override // io.netty.util.concurrent.Future
    public boolean await(long j) {
        return this.delegate.await(j);
    }

    @Override // io.netty.util.concurrent.Future
    public boolean awaitUninterruptibly(long j) {
        return this.delegate.awaitUninterruptibly(j);
    }
}
