package io.netty.channel.nio;

import com.android.tools.r8.GeneratedOutlineSupport;
import io.netty.channel.ChannelException;
import io.netty.channel.EventLoopException;
import io.netty.channel.EventLoopTaskQueueFactory;
import io.netty.channel.SelectStrategy;
import io.netty.channel.SingleThreadEventLoop;
import io.netty.channel.nio.AbstractNioChannel;
import io.netty.util.IntSupplier;
import io.netty.util.concurrent.AbstractScheduledEventExecutor;
import io.netty.util.concurrent.RejectedExecutionHandler;
import io.netty.util.internal.ObjectUtil;
import io.netty.util.internal.PlatformDependent;
import io.netty.util.internal.ReflectionUtil;
import io.netty.util.internal.SystemPropertyUtil;
import io.netty.util.internal.logging.InternalLogger;
import io.netty.util.internal.logging.InternalLoggerFactory;
import java.io.IOException;
import java.lang.reflect.Field;
import java.nio.channels.CancelledKeyException;
import java.nio.channels.SelectableChannel;
import java.nio.channels.SelectionKey;
import java.nio.channels.Selector;
import java.nio.channels.spi.AbstractSelector;
import java.nio.channels.spi.SelectorProvider;
import java.security.AccessController;
import java.security.PrivilegedAction;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.Queue;
import java.util.Set;
import java.util.concurrent.Executor;
import java.util.concurrent.atomic.AtomicLong;

public final class NioEventLoop extends SingleThreadEventLoop {
    private static final long AWAKE = -1;
    private static final int CLEANUP_INTERVAL = 256;
    private static final boolean DISABLE_KEY_SET_OPTIMIZATION = SystemPropertyUtil.getBoolean("io.netty.noKeySetOptimization", false);
    private static final int MIN_PREMATURE_SELECTOR_RETURNS = 3;
    private static final long NONE = Long.MAX_VALUE;
    private static final int SELECTOR_AUTO_REBUILD_THRESHOLD;
    private static final InternalLogger logger = InternalLoggerFactory.getInstance(NioEventLoop.class);
    private int cancelledKeys;
    private volatile int ioRatio = 50;
    private boolean needsToSelectAgain;
    private final AtomicLong nextWakeupNanos = new AtomicLong(-1);
    private final SelectorProvider provider;
    private final IntSupplier selectNowSupplier = new IntSupplier() {
        /* class io.netty.channel.nio.NioEventLoop.AnonymousClass1 */

        @Override // io.netty.util.IntSupplier
        public int get() {
            return NioEventLoop.this.selectNow();
        }
    };
    private final SelectStrategy selectStrategy;
    private SelectedSelectionKeySet selectedKeys;
    private Selector selector;
    private Selector unwrappedSelector;

    static {
        int i = 0;
        if (PlatformDependent.javaVersion() < 7 && SystemPropertyUtil.get("sun.nio.ch.bugLevel") == null) {
            try {
                AccessController.doPrivileged(new PrivilegedAction<Void>() {
                    /* class io.netty.channel.nio.NioEventLoop.AnonymousClass2 */

                    @Override // java.security.PrivilegedAction
                    public Void run() {
                        System.setProperty("sun.nio.ch.bugLevel", "");
                        return null;
                    }
                });
            } catch (SecurityException e) {
                logger.debug("Unable to get/set System Property: sun.nio.ch.bugLevel", (Throwable) e);
            }
        }
        int i2 = SystemPropertyUtil.getInt("io.netty.selectorAutoRebuildThreshold", 512);
        if (i2 >= 3) {
            i = i2;
        }
        SELECTOR_AUTO_REBUILD_THRESHOLD = i;
        InternalLogger internalLogger = logger;
        if (internalLogger.isDebugEnabled()) {
            internalLogger.debug("-Dio.netty.noKeySetOptimization: {}", Boolean.valueOf(DISABLE_KEY_SET_OPTIMIZATION));
            internalLogger.debug("-Dio.netty.selectorAutoRebuildThreshold: {}", Integer.valueOf(i));
        }
    }

    public NioEventLoop(NioEventLoopGroup nioEventLoopGroup, Executor executor, SelectorProvider selectorProvider, SelectStrategy selectStrategy2, RejectedExecutionHandler rejectedExecutionHandler, EventLoopTaskQueueFactory eventLoopTaskQueueFactory, EventLoopTaskQueueFactory eventLoopTaskQueueFactory2) {
        super(nioEventLoopGroup, executor, false, newTaskQueue(eventLoopTaskQueueFactory), newTaskQueue(eventLoopTaskQueueFactory2), rejectedExecutionHandler);
        this.provider = (SelectorProvider) ObjectUtil.checkNotNull(selectorProvider, "selectorProvider");
        this.selectStrategy = (SelectStrategy) ObjectUtil.checkNotNull(selectStrategy2, "selectStrategy");
        SelectorTuple openSelector = openSelector();
        this.selector = openSelector.selector;
        this.unwrappedSelector = openSelector.unwrappedSelector;
    }

    private void closeAll() {
        selectAgain();
        Set<SelectionKey> keys = this.selector.keys();
        ArrayList arrayList = new ArrayList(keys.size());
        for (SelectionKey selectionKey : keys) {
            Object attachment = selectionKey.attachment();
            if (attachment instanceof AbstractNioChannel) {
                arrayList.add((AbstractNioChannel) attachment);
            } else {
                selectionKey.cancel();
                invokeChannelUnregistered((NioTask) attachment, selectionKey, null);
            }
        }
        Iterator it = arrayList.iterator();
        while (it.hasNext()) {
            AbstractNioChannel abstractNioChannel = (AbstractNioChannel) it.next();
            abstractNioChannel.unsafe().close(abstractNioChannel.unsafe().voidPromise());
        }
    }

    private static void handleLoopException(Throwable th) {
        logger.warn("Unexpected exception in the selector loop.", th);
        try {
            Thread.sleep(1000);
        } catch (InterruptedException unused) {
        }
    }

    private static void invokeChannelUnregistered(NioTask<SelectableChannel> nioTask, SelectionKey selectionKey, Throwable th) {
        try {
            nioTask.channelUnregistered(selectionKey.channel(), th);
        } catch (Exception e) {
            logger.warn("Unexpected exception while running NioTask.channelUnregistered()", (Throwable) e);
        }
    }

    private static Queue<Runnable> newTaskQueue(EventLoopTaskQueueFactory eventLoopTaskQueueFactory) {
        if (eventLoopTaskQueueFactory == null) {
            return newTaskQueue0(SingleThreadEventLoop.DEFAULT_MAX_PENDING_TASKS);
        }
        return eventLoopTaskQueueFactory.newTaskQueue(SingleThreadEventLoop.DEFAULT_MAX_PENDING_TASKS);
    }

    private static Queue<Runnable> newTaskQueue0(int i) {
        if (i == Integer.MAX_VALUE) {
            return PlatformDependent.newMpscQueue();
        }
        return PlatformDependent.newMpscQueue(i);
    }

    private SelectorTuple openSelector() {
        try {
            final AbstractSelector openSelector = this.provider.openSelector();
            if (DISABLE_KEY_SET_OPTIMIZATION) {
                return new SelectorTuple(openSelector);
            }
            Object doPrivileged = AccessController.doPrivileged(new PrivilegedAction<Object>() {
                /* class io.netty.channel.nio.NioEventLoop.AnonymousClass3 */

                @Override // java.security.PrivilegedAction
                public Object run() {
                    try {
                        return Class.forName("sun.nio.ch.SelectorImpl", false, PlatformDependent.getSystemClassLoader());
                    } catch (Throwable th) {
                        return th;
                    }
                }
            });
            if (doPrivileged instanceof Class) {
                final Class cls = (Class) doPrivileged;
                if (cls.isAssignableFrom(openSelector.getClass())) {
                    final SelectedSelectionKeySet selectedSelectionKeySet = new SelectedSelectionKeySet();
                    Object doPrivileged2 = AccessController.doPrivileged(new PrivilegedAction<Object>() {
                        /* class io.netty.channel.nio.NioEventLoop.AnonymousClass4 */

                        @Override // java.security.PrivilegedAction
                        public Object run() {
                            try {
                                Field declaredField = cls.getDeclaredField("selectedKeys");
                                Field declaredField2 = cls.getDeclaredField("publicSelectedKeys");
                                if (PlatformDependent.javaVersion() >= 9 && PlatformDependent.hasUnsafe()) {
                                    long objectFieldOffset = PlatformDependent.objectFieldOffset(declaredField);
                                    long objectFieldOffset2 = PlatformDependent.objectFieldOffset(declaredField2);
                                    if (!(objectFieldOffset == -1 || objectFieldOffset2 == -1)) {
                                        PlatformDependent.putObject(openSelector, objectFieldOffset, selectedSelectionKeySet);
                                        PlatformDependent.putObject(openSelector, objectFieldOffset2, selectedSelectionKeySet);
                                        return null;
                                    }
                                }
                                Throwable trySetAccessible = ReflectionUtil.trySetAccessible(declaredField, true);
                                if (trySetAccessible != null) {
                                    return trySetAccessible;
                                }
                                Throwable trySetAccessible2 = ReflectionUtil.trySetAccessible(declaredField2, true);
                                if (trySetAccessible2 != null) {
                                    return trySetAccessible2;
                                }
                                declaredField.set(openSelector, selectedSelectionKeySet);
                                declaredField2.set(openSelector, selectedSelectionKeySet);
                                return null;
                            } catch (NoSuchFieldException e) {
                                return e;
                            } catch (IllegalAccessException e2) {
                                return e2;
                            }
                        }
                    });
                    if (doPrivileged2 instanceof Exception) {
                        this.selectedKeys = null;
                        logger.trace("failed to instrument a special java.util.Set into: {}", openSelector, (Exception) doPrivileged2);
                        return new SelectorTuple(openSelector);
                    }
                    this.selectedKeys = selectedSelectionKeySet;
                    logger.trace("instrumented a special java.util.Set into: {}", openSelector);
                    return new SelectorTuple(openSelector, new SelectedSelectionKeySetSelector(openSelector, selectedSelectionKeySet));
                }
            }
            if (doPrivileged instanceof Throwable) {
                logger.trace("failed to instrument a special java.util.Set into: {}", openSelector, (Throwable) doPrivileged);
            }
            return new SelectorTuple(openSelector);
        } catch (IOException e) {
            throw new ChannelException("failed to open a new selector", e);
        }
    }

    private void processSelectedKey(SelectionKey selectionKey, AbstractNioChannel abstractNioChannel) {
        AbstractNioChannel.NioUnsafe unsafe = abstractNioChannel.unsafe();
        if (!selectionKey.isValid()) {
            try {
                if (abstractNioChannel.eventLoop() == this) {
                    unsafe.close(unsafe.voidPromise());
                }
            } catch (Throwable unused) {
            }
        } else {
            try {
                int readyOps = selectionKey.readyOps();
                if ((readyOps & 8) != 0) {
                    selectionKey.interestOps(selectionKey.interestOps() & -9);
                    unsafe.finishConnect();
                }
                if ((readyOps & 4) != 0) {
                    abstractNioChannel.unsafe().forceFlush();
                }
                if ((readyOps & 17) != 0 || readyOps == 0) {
                    unsafe.read();
                }
            } catch (CancelledKeyException unused2) {
                unsafe.close(unsafe.voidPromise());
            }
        }
    }

    private void processSelectedKeys() {
        if (this.selectedKeys != null) {
            processSelectedKeysOptimized();
        } else {
            processSelectedKeysPlain(this.selector.selectedKeys());
        }
    }

    private void processSelectedKeysOptimized() {
        int i = 0;
        while (true) {
            SelectedSelectionKeySet selectedSelectionKeySet = this.selectedKeys;
            if (i < selectedSelectionKeySet.size) {
                SelectionKey[] selectionKeyArr = selectedSelectionKeySet.keys;
                SelectionKey selectionKey = selectionKeyArr[i];
                selectionKeyArr[i] = null;
                Object attachment = selectionKey.attachment();
                if (attachment instanceof AbstractNioChannel) {
                    processSelectedKey(selectionKey, (AbstractNioChannel) attachment);
                } else {
                    processSelectedKey(selectionKey, (NioTask) attachment);
                }
                if (this.needsToSelectAgain) {
                    this.selectedKeys.reset(i + 1);
                    selectAgain();
                    i = -1;
                }
                i++;
            } else {
                return;
            }
        }
    }

    private void processSelectedKeysPlain(Set<SelectionKey> set) {
        if (!set.isEmpty()) {
            Iterator<SelectionKey> it = set.iterator();
            while (true) {
                SelectionKey next = it.next();
                Object attachment = next.attachment();
                it.remove();
                if (attachment instanceof AbstractNioChannel) {
                    processSelectedKey(next, (AbstractNioChannel) attachment);
                } else {
                    processSelectedKey(next, (NioTask) attachment);
                }
                if (it.hasNext()) {
                    if (this.needsToSelectAgain) {
                        selectAgain();
                        Set<SelectionKey> selectedKeys2 = this.selector.selectedKeys();
                        if (!selectedKeys2.isEmpty()) {
                            it = selectedKeys2.iterator();
                        } else {
                            return;
                        }
                    }
                } else {
                    return;
                }
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void rebuildSelector0() {
        Selector selector2 = this.selector;
        if (selector2 != null) {
            try {
                SelectorTuple openSelector = openSelector();
                int i = 0;
                for (SelectionKey selectionKey : selector2.keys()) {
                    Object attachment = selectionKey.attachment();
                    try {
                        if (selectionKey.isValid()) {
                            if (selectionKey.channel().keyFor(openSelector.unwrappedSelector) == null) {
                                int interestOps = selectionKey.interestOps();
                                selectionKey.cancel();
                                SelectionKey register = selectionKey.channel().register(openSelector.unwrappedSelector, interestOps, attachment);
                                if (attachment instanceof AbstractNioChannel) {
                                    ((AbstractNioChannel) attachment).selectionKey = register;
                                }
                                i++;
                            }
                        }
                    } catch (Exception e) {
                        logger.warn("Failed to re-register a Channel to the new Selector.", (Throwable) e);
                        if (attachment instanceof AbstractNioChannel) {
                            AbstractNioChannel abstractNioChannel = (AbstractNioChannel) attachment;
                            abstractNioChannel.unsafe().close(abstractNioChannel.unsafe().voidPromise());
                        } else {
                            invokeChannelUnregistered((NioTask) attachment, selectionKey, e);
                        }
                    }
                }
                this.selector = openSelector.selector;
                this.unwrappedSelector = openSelector.unwrappedSelector;
                try {
                    selector2.close();
                } catch (Throwable th) {
                    if (logger.isWarnEnabled()) {
                        logger.warn("Failed to close the old Selector.", th);
                    }
                }
                InternalLogger internalLogger = logger;
                if (internalLogger.isInfoEnabled()) {
                    internalLogger.info("Migrated " + i + " channel(s) to the new Selector.");
                }
            } catch (Exception e2) {
                logger.warn("Failed to create a new Selector.", (Throwable) e2);
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void register0(SelectableChannel selectableChannel, int i, NioTask<?> nioTask) {
        try {
            selectableChannel.register(this.unwrappedSelector, i, nioTask);
        } catch (Exception e) {
            throw new EventLoopException("failed to register a channel", e);
        }
    }

    private int select(long j) {
        if (j == NONE) {
            return this.selector.select();
        }
        long deadlineToDelayNanos = AbstractScheduledEventExecutor.deadlineToDelayNanos(j + 995000) / 1000000;
        return deadlineToDelayNanos <= 0 ? this.selector.selectNow() : this.selector.select(deadlineToDelayNanos);
    }

    private void selectAgain() {
        this.needsToSelectAgain = false;
        try {
            this.selector.selectNow();
        } catch (Throwable th) {
            logger.warn("Failed to update SelectionKeys.", th);
        }
    }

    private boolean unexpectedSelectorWakeup(int i) {
        if (Thread.interrupted()) {
            InternalLogger internalLogger = logger;
            if (internalLogger.isDebugEnabled()) {
                internalLogger.debug("Selector.select() returned prematurely because Thread.currentThread().interrupt() was called. Use NioEventLoop.shutdownGracefully() to shutdown the NioEventLoop.");
            }
            return true;
        }
        int i2 = SELECTOR_AUTO_REBUILD_THRESHOLD;
        if (i2 <= 0 || i < i2) {
            return false;
        }
        logger.warn("Selector.select() returned prematurely {} times in a row; rebuilding Selector {}.", Integer.valueOf(i), this.selector);
        rebuildSelector();
        return true;
    }

    @Override // io.netty.util.concurrent.AbstractScheduledEventExecutor
    public boolean afterScheduledTaskSubmitted(long j) {
        return j < this.nextWakeupNanos.get();
    }

    @Override // io.netty.util.concurrent.AbstractScheduledEventExecutor
    public boolean beforeScheduledTaskSubmitted(long j) {
        return j < this.nextWakeupNanos.get();
    }

    public void cancel(SelectionKey selectionKey) {
        selectionKey.cancel();
        int i = this.cancelledKeys + 1;
        this.cancelledKeys = i;
        if (i >= 256) {
            this.cancelledKeys = 0;
            this.needsToSelectAgain = true;
        }
    }

    @Override // io.netty.util.concurrent.SingleThreadEventExecutor
    public void cleanup() {
        try {
            this.selector.close();
        } catch (IOException e) {
            logger.warn("Failed to close a selector.", (Throwable) e);
        }
    }

    public int getIoRatio() {
        return this.ioRatio;
    }

    public void rebuildSelector() {
        if (!inEventLoop()) {
            execute(new Runnable() {
                /* class io.netty.channel.nio.NioEventLoop.AnonymousClass6 */

                public void run() {
                    NioEventLoop.this.rebuildSelector0();
                }
            });
        } else {
            rebuildSelector0();
        }
    }

    public void register(final SelectableChannel selectableChannel, final int i, final NioTask<?> nioTask) {
        ObjectUtil.checkNotNull(selectableChannel, "ch");
        if (i == 0) {
            throw new IllegalArgumentException("interestOps must be non-zero.");
        } else if (((~selectableChannel.validOps()) & i) == 0) {
            ObjectUtil.checkNotNull(nioTask, "task");
            if (isShutdown()) {
                throw new IllegalStateException("event loop shut down");
            } else if (inEventLoop()) {
                register0(selectableChannel, i, nioTask);
            } else {
                try {
                    submit((Runnable) new Runnable() {
                        /* class io.netty.channel.nio.NioEventLoop.AnonymousClass5 */

                        public void run() {
                            NioEventLoop.this.register0(selectableChannel, i, nioTask);
                        }
                    }).sync();
                } catch (InterruptedException unused) {
                    Thread.currentThread().interrupt();
                }
            }
        } else {
            StringBuilder outline26 = GeneratedOutlineSupport.outline26("invalid interestOps: ", i, "(validOps: ");
            outline26.append(selectableChannel.validOps());
            outline26.append(')');
            throw new IllegalArgumentException(outline26.toString());
        }
    }

    @Override // io.netty.channel.SingleThreadEventLoop
    public int registeredChannels() {
        return this.selector.keys().size() - this.cancelledKeys;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:102:0x011d, code lost:
        throw r0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:105:0x0126, code lost:
        r3.debug(java.nio.channels.CancelledKeyException.class.getSimpleName() + " raised by a Selector {} - JDK bug?", r8.selector, r2);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:109:0x0148, code lost:
        closeAll();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:110:0x014f, code lost:
        if (confirmShutdown() != false) goto L_0x0151;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:111:0x0151, code lost:
        return;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:141:0x0002, code lost:
        continue;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:143:0x0002, code lost:
        continue;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:16:0x0028, code lost:
        r2 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:17:0x0029, code lost:
        handleLoopException(r2);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:53:0x00a8, code lost:
        if (unexpectedSelectorWakeup(r1) != false) goto L_0x00c3;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:71:0x00dd, code lost:
        r2 = th;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:72:0x00df, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:73:0x00e1, code lost:
        r2 = e;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:97:0x0111, code lost:
        closeAll();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:98:0x0118, code lost:
        if (confirmShutdown() != false) goto L_0x011a;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:99:0x011a, code lost:
        return;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:9:0x0015, code lost:
        if (r2 != -1) goto L_0x0052;
     */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Removed duplicated region for block: B:105:0x0126  */
    /* JADX WARNING: Removed duplicated region for block: B:109:0x0148 A[Catch:{ Error -> 0x0152, all -> 0x0028 }] */
    /* JADX WARNING: Removed duplicated region for block: B:141:0x0002 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:143:0x0002 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:16:0x0028 A[ExcHandler: all (r2v9 'th' java.lang.Throwable A[CUSTOM_DECLARE]), PHI: r1 
      PHI: (r1v13 int) = (r1v3 int), (r1v4 int), (r1v15 int), (r1v1 int) binds: [B:106:0x0142, B:94:0x010b, B:60:0x00c4, B:10:0x0018] A[DONT_GENERATE, DONT_INLINE], Splitter:B:106:0x0142] */
    /* JADX WARNING: Removed duplicated region for block: B:72:0x00df A[ExcHandler: Error (r0v6 'e' java.lang.Error A[CUSTOM_DECLARE]), Splitter:B:30:0x0054] */
    /* JADX WARNING: Removed duplicated region for block: B:97:0x0111 A[Catch:{ Error -> 0x011b, all -> 0x0028 }] */
    @Override // io.netty.util.concurrent.SingleThreadEventExecutor
    public void run() {
        boolean z;
        while (true) {
            int i = 0;
            while (true) {
                try {
                    int calculateStrategy = this.selectStrategy.calculateStrategy(this.selectNowSupplier, hasTasks());
                    if (calculateStrategy != -3) {
                        if (calculateStrategy == -2) {
                            try {
                                if (isShuttingDown()) {
                                    closeAll();
                                    if (confirmShutdown()) {
                                        return;
                                    }
                                } else {
                                    continue;
                                }
                            } catch (Error e) {
                                throw e;
                            } catch (Throwable th) {
                            }
                        }
                    }
                    long nextScheduledTaskDeadlineNanos = nextScheduledTaskDeadlineNanos();
                    if (nextScheduledTaskDeadlineNanos == -1) {
                        nextScheduledTaskDeadlineNanos = NONE;
                    }
                    this.nextWakeupNanos.set(nextScheduledTaskDeadlineNanos);
                    try {
                        if (!hasTasks()) {
                            calculateStrategy = select(nextScheduledTaskDeadlineNanos);
                        }
                        i++;
                        try {
                            this.cancelledKeys = 0;
                            this.needsToSelectAgain = false;
                            int i2 = this.ioRatio;
                            if (i2 == 100) {
                                if (calculateStrategy > 0) {
                                    try {
                                        processSelectedKeys();
                                    } catch (Throwable th2) {
                                        runAllTasks();
                                        throw th2;
                                    }
                                }
                                z = runAllTasks();
                            } else if (calculateStrategy > 0) {
                                long nanoTime = System.nanoTime();
                                try {
                                    processSelectedKeys();
                                } finally {
                                    runAllTasks(((System.nanoTime() - nanoTime) * ((long) (100 - i2))) / ((long) i2));
                                }
                            } else {
                                z = runAllTasks(0);
                            }
                            if (z || calculateStrategy > 0) {
                                if (i > 3) {
                                    InternalLogger internalLogger = logger;
                                    if (internalLogger.isDebugEnabled()) {
                                        internalLogger.debug("Selector.select() returned prematurely {} times in a row for Selector {}.", Integer.valueOf(i - 1), this.selector);
                                    }
                                }
                            }
                            i = 0;
                            try {
                                if (isShuttingDown()) {
                                    closeAll();
                                    if (confirmShutdown()) {
                                        return;
                                    }
                                } else {
                                    continue;
                                }
                            } catch (Error e2) {
                                throw e2;
                            } catch (Throwable th3) {
                            }
                        } catch (CancelledKeyException e3) {
                            CancelledKeyException e4 = e3;
                            i = 0;
                            InternalLogger internalLogger2 = logger;
                            if (internalLogger2.isDebugEnabled()) {
                            }
                            try {
                                if (!isShuttingDown()) {
                                }
                            } catch (Error e5) {
                                throw e5;
                            } catch (Throwable th32) {
                            }
                        } catch (Error e6) {
                        } catch (Throwable th4) {
                            Throwable th5 = th4;
                            i = 0;
                            try {
                                handleLoopException(th5);
                                try {
                                    if (!isShuttingDown()) {
                                    }
                                } catch (Error e7) {
                                    throw e7;
                                } catch (Throwable th322) {
                                }
                            } catch (Throwable th6) {
                                try {
                                    if (isShuttingDown()) {
                                        closeAll();
                                        if (confirmShutdown()) {
                                            return;
                                        }
                                    }
                                } catch (Error e8) {
                                    throw e8;
                                } catch (Throwable th7) {
                                    handleLoopException(th7);
                                }
                                throw th6;
                            }
                        }
                    } finally {
                        this.nextWakeupNanos.lazySet(-1);
                    }
                } catch (IOException e9) {
                    rebuildSelector0();
                    handleLoopException(e9);
                    try {
                        if (isShuttingDown()) {
                            closeAll();
                            if (confirmShutdown()) {
                                return;
                            }
                        } else {
                            continue;
                        }
                    } catch (Error e10) {
                        throw e10;
                    } catch (Throwable th8) {
                        handleLoopException(th8);
                    }
                }
            }
        }
    }

    public int selectNow() {
        return this.selector.selectNow();
    }

    public SelectorProvider selectorProvider() {
        return this.provider;
    }

    public void setIoRatio(int i) {
        if (i <= 0 || i > 100) {
            throw new IllegalArgumentException(GeneratedOutlineSupport.outline12("ioRatio: ", i, " (expected: 0 < ioRatio <= 100)"));
        }
        this.ioRatio = i;
    }

    public Selector unwrappedSelector() {
        return this.unwrappedSelector;
    }

    @Override // io.netty.util.concurrent.SingleThreadEventExecutor
    public void wakeup(boolean z) {
        if (!z && this.nextWakeupNanos.getAndSet(-1) != -1) {
            this.selector.wakeup();
        }
    }

    public static final class SelectorTuple {
        public final Selector selector;
        public final Selector unwrappedSelector;

        public SelectorTuple(Selector selector2) {
            this.unwrappedSelector = selector2;
            this.selector = selector2;
        }

        public SelectorTuple(Selector selector2, Selector selector3) {
            this.unwrappedSelector = selector2;
            this.selector = selector3;
        }
    }

    @Override // io.netty.util.concurrent.SingleThreadEventExecutor
    public Queue<Runnable> newTaskQueue(int i) {
        return newTaskQueue0(i);
    }

    private static void processSelectedKey(SelectionKey selectionKey, NioTask<SelectableChannel> nioTask) {
        try {
            nioTask.channelReady(selectionKey.channel(), selectionKey);
            if (!selectionKey.isValid()) {
                invokeChannelUnregistered(nioTask, selectionKey, null);
            }
        } catch (Exception e) {
            selectionKey.cancel();
            invokeChannelUnregistered(nioTask, selectionKey, e);
        } catch (Throwable th) {
            selectionKey.cancel();
            invokeChannelUnregistered(nioTask, selectionKey, null);
            throw th;
        }
    }
}
