package io.netty.handler.codec.compression;

import io.netty.buffer.ByteBuf;
import io.netty.util.ByteProcessor;
import io.netty.util.internal.ObjectUtil;
import io.netty.util.internal.PlatformDependent;
import java.lang.reflect.Method;
import java.nio.ByteBuffer;
import java.util.zip.Adler32;
import java.util.zip.CRC32;
import java.util.zip.Checksum;

public abstract class ByteBufChecksum implements Checksum {
    private static final Method ADLER32_UPDATE_METHOD = updateByteBuffer(new Adler32());
    private static final Method CRC32_UPDATE_METHOD = updateByteBuffer(new CRC32());
    private final ByteProcessor updateProcessor = new ByteProcessor() {
        /* class io.netty.handler.codec.compression.ByteBufChecksum.AnonymousClass1 */

        @Override // io.netty.util.ByteProcessor
        public boolean process(byte b) {
            ByteBufChecksum.this.update(b);
            return true;
        }
    };

    public static final class ReflectiveByteBufChecksum extends SlowByteBufChecksum {
        private final Method method;

        public ReflectiveByteBufChecksum(Checksum checksum, Method method2) {
            super(checksum);
            this.method = method2;
        }

        @Override // io.netty.handler.codec.compression.ByteBufChecksum
        public void update(ByteBuf byteBuf, int i, int i2) {
            if (byteBuf.hasArray()) {
                update(byteBuf.array(), byteBuf.arrayOffset() + i, i2);
                return;
            }
            try {
                this.method.invoke(this.checksum, CompressionUtil.safeNioBuffer(byteBuf, i, i2));
            } catch (Throwable unused) {
                throw new Error();
            }
        }
    }

    public static class SlowByteBufChecksum extends ByteBufChecksum {
        public final Checksum checksum;

        public SlowByteBufChecksum(Checksum checksum2) {
            this.checksum = checksum2;
        }

        public long getValue() {
            return this.checksum.getValue();
        }

        public void reset() {
            this.checksum.reset();
        }

        public void update(int i) {
            this.checksum.update(i);
        }

        public void update(byte[] bArr, int i, int i2) {
            this.checksum.update(bArr, i, i2);
        }
    }

    private static Method updateByteBuffer(Checksum checksum) {
        if (PlatformDependent.javaVersion() >= 8) {
            try {
                Method declaredMethod = checksum.getClass().getDeclaredMethod("update", ByteBuffer.class);
                declaredMethod.invoke(checksum, ByteBuffer.allocate(1));
                return declaredMethod;
            } catch (Throwable unused) {
            }
        }
        return null;
    }

    public static ByteBufChecksum wrapChecksum(Checksum checksum) {
        Method method;
        Method method2;
        ObjectUtil.checkNotNull(checksum, "checksum");
        if (checksum instanceof ByteBufChecksum) {
            return (ByteBufChecksum) checksum;
        }
        if ((checksum instanceof Adler32) && (method2 = ADLER32_UPDATE_METHOD) != null) {
            return new ReflectiveByteBufChecksum(checksum, method2);
        }
        if (!(checksum instanceof CRC32) || (method = CRC32_UPDATE_METHOD) == null) {
            return new SlowByteBufChecksum(checksum);
        }
        return new ReflectiveByteBufChecksum(checksum, method);
    }

    public void update(ByteBuf byteBuf, int i, int i2) {
        if (byteBuf.hasArray()) {
            update(byteBuf.array(), byteBuf.arrayOffset() + i, i2);
        } else {
            byteBuf.forEachByte(i, i2, this.updateProcessor);
        }
    }
}
