package io.netty.util;

import io.netty.util.concurrent.FastThreadLocal;
import io.netty.util.internal.ObjectPool;
import io.netty.util.internal.PlatformDependent;
import io.netty.util.internal.SystemPropertyUtil;
import io.netty.util.internal.logging.InternalLogger;
import io.netty.util.internal.logging.InternalLoggerFactory;
import java.util.Queue;
import java.util.concurrent.atomic.AtomicIntegerFieldUpdater;

public abstract class Recycler<T> {
    private static final int DEFAULT_INITIAL_MAX_CAPACITY_PER_THREAD = 4096;
    private static final int DEFAULT_MAX_CAPACITY_PER_THREAD;
    private static final int DEFAULT_QUEUE_CHUNK_SIZE_PER_THREAD;
    private static final Handle<?> NOOP_HANDLE = new Handle<Object>() {
        /* class io.netty.util.Recycler.AnonymousClass1 */

        @Override // io.netty.util.internal.ObjectPool.Handle
        public void recycle(Object obj) {
        }

        public String toString() {
            return "NOOP_HANDLE";
        }
    };
    private static final int RATIO;
    private static final InternalLogger logger;
    private final int chunkSize;
    private final int interval;
    private final int maxCapacityPerThread;
    private final FastThreadLocal<LocalPool<T>> threadLocal;

    public static final class DefaultHandle<T> implements Handle<T> {
        private static final int STATE_AVAILABLE = 1;
        private static final int STATE_CLAIMED = 0;
        private static final AtomicIntegerFieldUpdater<DefaultHandle<?>> STATE_UPDATER = AtomicIntegerFieldUpdater.newUpdater(DefaultHandle.class, "state");
        private final LocalPool<T> localPool;
        private volatile int state;
        private T value;

        public DefaultHandle(LocalPool<T> localPool2) {
            this.localPool = localPool2;
        }

        public boolean availableToClaim() {
            if (this.state != 1) {
                return false;
            }
            return STATE_UPDATER.compareAndSet(this, 1, 0);
        }

        public T get() {
            return this.value;
        }

        @Override // io.netty.util.internal.ObjectPool.Handle
        public void recycle(Object obj) {
            if (obj == this.value) {
                this.localPool.release(this);
                return;
            }
            throw new IllegalArgumentException("object does not belong to handle");
        }

        public void set(T t) {
            this.value = t;
        }

        public void toAvailable() {
            if (STATE_UPDATER.getAndSet(this, 1) == 1) {
                throw new IllegalStateException("Object has been recycled already.");
            }
        }
    }

    public interface Handle<T> extends ObjectPool.Handle<T> {
    }

    public static final class LocalPool<T> {
        private final Queue<DefaultHandle<T>> pooledHandles;
        private int ratioCounter;
        private final int ratioInterval;

        public LocalPool(int i, int i2, int i3) {
            this.ratioInterval = i2;
            this.pooledHandles = PlatformDependent.newMpscQueue(i3, i);
            this.ratioCounter = i2;
        }

        public DefaultHandle<T> claim() {
            DefaultHandle<T> poll;
            Queue<DefaultHandle<T>> queue = this.pooledHandles;
            do {
                poll = queue.poll();
                if (poll == null) {
                    break;
                }
            } while (!poll.availableToClaim());
            return poll;
        }

        public DefaultHandle<T> newHandle() {
            int i = this.ratioCounter + 1;
            this.ratioCounter = i;
            if (i < this.ratioInterval) {
                return null;
            }
            this.ratioCounter = 0;
            return new DefaultHandle<>(this);
        }

        public void release(DefaultHandle<T> defaultHandle) {
            defaultHandle.toAvailable();
            this.pooledHandles.offer(defaultHandle);
        }
    }

    static {
        InternalLogger instance = InternalLoggerFactory.getInstance(Recycler.class);
        logger = instance;
        int i = 4096;
        int i2 = SystemPropertyUtil.getInt("io.netty.recycler.maxCapacityPerThread", SystemPropertyUtil.getInt("io.netty.recycler.maxCapacity", 4096));
        if (i2 >= 0) {
            i = i2;
        }
        DEFAULT_MAX_CAPACITY_PER_THREAD = i;
        int i3 = SystemPropertyUtil.getInt("io.netty.recycler.chunkSize", 32);
        DEFAULT_QUEUE_CHUNK_SIZE_PER_THREAD = i3;
        int max = Math.max(0, SystemPropertyUtil.getInt("io.netty.recycler.ratio", 8));
        RATIO = max;
        if (!instance.isDebugEnabled()) {
            return;
        }
        if (i == 0) {
            instance.debug("-Dio.netty.recycler.maxCapacityPerThread: disabled");
            instance.debug("-Dio.netty.recycler.ratio: disabled");
            instance.debug("-Dio.netty.recycler.chunkSize: disabled");
            return;
        }
        instance.debug("-Dio.netty.recycler.maxCapacityPerThread: {}", Integer.valueOf(i));
        instance.debug("-Dio.netty.recycler.ratio: {}", Integer.valueOf(max));
        instance.debug("-Dio.netty.recycler.chunkSize: {}", Integer.valueOf(i3));
    }

    public Recycler() {
        this(DEFAULT_MAX_CAPACITY_PER_THREAD);
    }

    public final T get() {
        if (this.maxCapacityPerThread == 0) {
            return newObject(NOOP_HANDLE);
        }
        LocalPool<T> localPool = this.threadLocal.get();
        DefaultHandle<T> claim = localPool.claim();
        if (claim != null) {
            return claim.get();
        }
        DefaultHandle<T> newHandle = localPool.newHandle();
        if (newHandle == null) {
            return newObject(NOOP_HANDLE);
        }
        T newObject = newObject(newHandle);
        newHandle.set(newObject);
        return newObject;
    }

    public abstract T newObject(Handle<T> handle);

    @Deprecated
    public final boolean recycle(T t, Handle<T> handle) {
        if (handle == NOOP_HANDLE) {
            return false;
        }
        handle.recycle(t);
        return true;
    }

    public final int threadLocalSize() {
        return ((LocalPool) this.threadLocal.get()).pooledHandles.size();
    }

    public Recycler(int i) {
        this(i, RATIO, DEFAULT_QUEUE_CHUNK_SIZE_PER_THREAD);
    }

    @Deprecated
    public Recycler(int i, int i2) {
        this(i, RATIO, DEFAULT_QUEUE_CHUNK_SIZE_PER_THREAD);
    }

    @Deprecated
    public Recycler(int i, int i2, int i3, int i4) {
        this(i, i3, DEFAULT_QUEUE_CHUNK_SIZE_PER_THREAD);
    }

    @Deprecated
    public Recycler(int i, int i2, int i3, int i4, int i5) {
        this(i, i3, DEFAULT_QUEUE_CHUNK_SIZE_PER_THREAD);
    }

    public Recycler(int i, int i2, int i3) {
        this.threadLocal = new FastThreadLocal<LocalPool<T>>() {
            /* class io.netty.util.Recycler.AnonymousClass2 */

            @Override // io.netty.util.concurrent.FastThreadLocal
            public /* bridge */ /* synthetic */ void onRemoval(Object obj) {
                onRemoval((LocalPool) ((LocalPool) obj));
            }

            @Override // io.netty.util.concurrent.FastThreadLocal
            public LocalPool<T> initialValue() {
                return new LocalPool<>(Recycler.this.maxCapacityPerThread, Recycler.this.interval, Recycler.this.chunkSize);
            }

            public void onRemoval(LocalPool<T> localPool) {
                super.onRemoval((Object) localPool);
                ((LocalPool) localPool).pooledHandles.clear();
            }
        };
        this.interval = Math.max(0, i2);
        if (i <= 0) {
            this.maxCapacityPerThread = 0;
            this.chunkSize = 0;
            return;
        }
        int max = Math.max(4, i);
        this.maxCapacityPerThread = max;
        this.chunkSize = Math.max(2, Math.min(i3, max >> 1));
    }
}
