package io.netty.util.internal;

import com.android.tools.r8.GeneratedOutlineSupport;
import io.netty.util.CharsetUtil;
import io.netty.util.internal.logging.InternalLogger;
import io.netty.util.internal.logging.InternalLoggerFactory;
import java.io.ByteArrayOutputStream;
import java.io.Closeable;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.lang.reflect.Method;
import java.net.URL;
import java.nio.file.Files;
import java.nio.file.LinkOption;
import java.nio.file.attribute.PosixFilePermission;
import java.security.AccessController;
import java.security.PrivilegedAction;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.EnumSet;
import java.util.Enumeration;
import java.util.Set;

public final class NativeLibraryLoader {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    private static final boolean DELETE_NATIVE_LIB_AFTER_LOADING;
    private static final String NATIVE_RESOURCE_HOME = "META-INF/native/";
    private static final boolean TRY_TO_PATCH_SHADED_ID;
    private static final byte[] UNIQUE_ID_BYTES = "0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ".getBytes(CharsetUtil.US_ASCII);
    private static final File WORKDIR;
    private static final InternalLogger logger;

    public static final class NoexecVolumeDetector {
        private NoexecVolumeDetector() {
        }

        /* access modifiers changed from: private */
        @SuppressJava6Requirement(reason = "Usage guarded by java version check")
        public static boolean canExecuteExecutable(File file) {
            if (PlatformDependent.javaVersion() < 7 || file.canExecute()) {
                return true;
            }
            Set<PosixFilePermission> posixFilePermissions = Files.getPosixFilePermissions(file.toPath(), new LinkOption[0]);
            EnumSet of = EnumSet.of(PosixFilePermission.OWNER_EXECUTE, PosixFilePermission.GROUP_EXECUTE, PosixFilePermission.OTHERS_EXECUTE);
            if (posixFilePermissions.containsAll(of)) {
                return false;
            }
            EnumSet copyOf = EnumSet.copyOf(posixFilePermissions);
            copyOf.addAll(of);
            Files.setPosixFilePermissions(file.toPath(), copyOf);
            return file.canExecute();
        }
    }

    static {
        InternalLogger instance = InternalLoggerFactory.getInstance(NativeLibraryLoader.class);
        logger = instance;
        String str = SystemPropertyUtil.get("io.netty.native.workdir");
        if (str != null) {
            File file = new File(str);
            file.mkdirs();
            try {
                file = file.getAbsoluteFile();
            } catch (Exception unused) {
            }
            WORKDIR = file;
            InternalLogger internalLogger = logger;
            internalLogger.debug("-Dio.netty.native.workdir: " + file);
        } else {
            File tmpdir = PlatformDependent.tmpdir();
            WORKDIR = tmpdir;
            instance.debug("-Dio.netty.native.workdir: " + tmpdir + " (io.netty.tmpdir)");
        }
        boolean z = SystemPropertyUtil.getBoolean("io.netty.native.deleteLibAfterLoading", true);
        DELETE_NATIVE_LIB_AFTER_LOADING = z;
        InternalLogger internalLogger2 = logger;
        internalLogger2.debug("-Dio.netty.native.deleteLibAfterLoading: {}", Boolean.valueOf(z));
        boolean z2 = SystemPropertyUtil.getBoolean("io.netty.native.tryPatchShadedId", true);
        TRY_TO_PATCH_SHADED_ID = z2;
        internalLogger2.debug("-Dio.netty.native.tryPatchShadedId: {}", Boolean.valueOf(z2));
    }

    private NativeLibraryLoader() {
    }

    private static String calculatePackagePrefix() {
        String name = NativeLibraryLoader.class.getName();
        String replace = "io!netty!util!internal!NativeLibraryLoader".replace('!', '.');
        if (name.endsWith(replace)) {
            return name.substring(0, name.length() - replace.length());
        }
        throw new UnsatisfiedLinkError(String.format("Could not find prefix added to %s to get %s. When shading, only adding a package prefix is supported", replace, name));
    }

    private static byte[] classToByteArray(Class<?> cls) {
        String name = cls.getName();
        int lastIndexOf = name.lastIndexOf(46);
        if (lastIndexOf > 0) {
            name = name.substring(lastIndexOf + 1);
        }
        URL resource = cls.getResource(name + ".class");
        if (resource != null) {
            byte[] bArr = new byte[1024];
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream(4096);
            try {
                InputStream openStream = resource.openStream();
                while (true) {
                    int read = openStream.read(bArr);
                    if (read != -1) {
                        byteArrayOutputStream.write(bArr, 0, read);
                    } else {
                        byte[] byteArray = byteArrayOutputStream.toByteArray();
                        closeQuietly(openStream);
                        closeQuietly(byteArrayOutputStream);
                        return byteArray;
                    }
                }
            } catch (IOException e) {
                throw new ClassNotFoundException(cls.getName(), e);
            } catch (Throwable th) {
                closeQuietly(null);
                closeQuietly(byteArrayOutputStream);
                throw th;
            }
        } else {
            throw new ClassNotFoundException(cls.getName());
        }
    }

    private static void closeQuietly(Closeable closeable) {
        if (closeable != null) {
            try {
                closeable.close();
            } catch (IOException unused) {
            }
        }
    }

    private static byte[] generateUniqueId(int i) {
        byte[] bArr = new byte[i];
        for (int i2 = 0; i2 < i; i2++) {
            byte[] bArr2 = UNIQUE_ID_BYTES;
            bArr[i2] = bArr2[PlatformDependent.threadLocalRandom().nextInt(bArr2.length)];
        }
        return bArr;
    }

    private static URL getResource(String str, ClassLoader classLoader) {
        Enumeration<URL> enumeration;
        if (classLoader == null) {
            try {
                enumeration = ClassLoader.getSystemResources(str);
            } catch (IOException e) {
                throw new RuntimeException(GeneratedOutlineSupport.outline18("An error occurred while getting the resources for ", str), e);
            }
        } else {
            enumeration = classLoader.getResources(str);
        }
        ArrayList list = Collections.list(enumeration);
        int size = list.size();
        if (size == 0) {
            return null;
        }
        if (size == 1) {
            return (URL) list.get(0);
        }
        throw new IllegalStateException("Multiple resources found for '" + str + "': " + list);
    }

    /* JADX WARNING: Removed duplicated region for block: B:73:0x0121 A[SYNTHETIC, Splitter:B:73:0x0121] */
    public static void load(String str, ClassLoader classLoader) {
        FileOutputStream fileOutputStream;
        Throwable th;
        File file;
        FileOutputStream fileOutputStream2;
        InputStream inputStream;
        UnsatisfiedLinkError e;
        Exception e2;
        InputStream inputStream2;
        String str2;
        String replace = calculatePackagePrefix().replace('.', '_');
        String outline18 = GeneratedOutlineSupport.outline18(replace, str);
        ArrayList arrayList = new ArrayList();
        try {
            loadLibrary(classLoader, outline18, false);
        } catch (Throwable th2) {
            arrayList.add(th2 == 1 ? 1 : 0);
            String mapLibraryName = System.mapLibraryName(outline18);
            String outline182 = GeneratedOutlineSupport.outline18(NATIVE_RESOURCE_HOME, mapLibraryName);
            URL resource = getResource(outline182, classLoader);
            InputStream inputStream3 = null;
            r9 = null;
            File file2 = null;
            File file3 = null;
            FileOutputStream fileOutputStream3 = null;
            InputStream inputStream4 = null;
            if (resource == null) {
                try {
                    if (PlatformDependent.isOsx()) {
                        if (outline182.endsWith(".jnilib")) {
                            str2 = "META-INF/native/lib" + outline18 + ".dynlib";
                        } else {
                            str2 = "META-INF/native/lib" + outline18 + ".jnilib";
                        }
                        resource = getResource(str2, classLoader);
                        if (resource == null) {
                            FileNotFoundException fileNotFoundException = new FileNotFoundException(str2);
                            ThrowableUtil.addSuppressedAndClear(fileNotFoundException, arrayList);
                            throw fileNotFoundException;
                        }
                    } else {
                        FileNotFoundException fileNotFoundException2 = new FileNotFoundException(outline182);
                        ThrowableUtil.addSuppressedAndClear(fileNotFoundException2, arrayList);
                        throw fileNotFoundException2;
                    }
                } catch (UnsatisfiedLinkError e3) {
                    e = e3;
                    inputStream = null;
                    fileOutputStream2 = null;
                    if (file3 != null) {
                        try {
                            if (file3.isFile() && file3.canRead() && !NoexecVolumeDetector.canExecuteExecutable(file3)) {
                                logger.info("{} exists but cannot be executed even when execute permissions set; check volume for \"noexec\" flag; use -D{}=[path] to set native working directory separately.", file3.getPath(), "io.netty.native.workdir");
                            }
                        } catch (Throwable th3) {
                            th = th3;
                            file = file3;
                            inputStream4 = inputStream;
                            fileOutputStream = fileOutputStream2;
                            closeQuietly(inputStream4);
                            closeQuietly(fileOutputStream);
                            if (file != null && (!DELETE_NATIVE_LIB_AFTER_LOADING || !file.delete())) {
                                file.deleteOnExit();
                            }
                            throw th;
                        }
                    }
                    ThrowableUtil.addSuppressedAndClear(e, arrayList);
                    throw e;
                } catch (Exception e4) {
                    e2 = e4;
                    fileOutputStream = null;
                    inputStream2 = null;
                    try {
                        UnsatisfiedLinkError unsatisfiedLinkError = new UnsatisfiedLinkError("could not load a native library: " + outline18);
                        unsatisfiedLinkError.initCause(e2);
                        ThrowableUtil.addSuppressedAndClear(unsatisfiedLinkError, arrayList);
                        throw unsatisfiedLinkError;
                    } catch (Throwable th4) {
                        th = th4;
                        file = file2;
                        inputStream4 = inputStream2;
                        closeQuietly(inputStream4);
                        closeQuietly(fileOutputStream);
                        file.deleteOnExit();
                        throw th;
                    }
                } catch (Throwable th5) {
                    th = th5;
                    fileOutputStream = null;
                    file = null;
                    closeQuietly(inputStream4);
                    closeQuietly(fileOutputStream);
                    file.deleteOnExit();
                    throw th;
                }
            }
            int lastIndexOf = mapLibraryName.lastIndexOf(46);
            file = PlatformDependent.createTempFile(mapLibraryName.substring(0, lastIndexOf), mapLibraryName.substring(lastIndexOf), WORKDIR);
            try {
                inputStream2 = resource.openStream();
                try {
                    fileOutputStream2 = new FileOutputStream(file);
                    try {
                        byte[] bArr = new byte[8192];
                        while (true) {
                            int read = inputStream2.read(bArr);
                            if (read <= 0) {
                                break;
                            }
                            fileOutputStream2.write(bArr, 0, read);
                        }
                        fileOutputStream2.flush();
                        if (shouldShadedLibraryIdBePatched(replace)) {
                            tryPatchShadedLibraryIdAndSign(file, str);
                        }
                        closeQuietly(fileOutputStream2);
                        loadLibrary(classLoader, file.getPath(), true);
                        closeQuietly(inputStream2);
                        closeQuietly(null);
                        if (!DELETE_NATIVE_LIB_AFTER_LOADING || !file.delete()) {
                            file.deleteOnExit();
                        }
                    } catch (UnsatisfiedLinkError e5) {
                        e = e5;
                        inputStream3 = inputStream2;
                        inputStream = inputStream3;
                        file3 = file;
                        if (file3 != null) {
                        }
                        ThrowableUtil.addSuppressedAndClear(e, arrayList);
                        throw e;
                    } catch (Exception e6) {
                        e2 = e6;
                        fileOutputStream3 = fileOutputStream2;
                        fileOutputStream = fileOutputStream3;
                        file2 = file;
                        UnsatisfiedLinkError unsatisfiedLinkError2 = new UnsatisfiedLinkError("could not load a native library: " + outline18);
                        unsatisfiedLinkError2.initCause(e2);
                        ThrowableUtil.addSuppressedAndClear(unsatisfiedLinkError2, arrayList);
                        throw unsatisfiedLinkError2;
                    } catch (Throwable th6) {
                        th = th6;
                        inputStream4 = inputStream2;
                        fileOutputStream = fileOutputStream2;
                        closeQuietly(inputStream4);
                        closeQuietly(fileOutputStream);
                        file.deleteOnExit();
                        throw th;
                    }
                } catch (UnsatisfiedLinkError e7) {
                    e = e7;
                    fileOutputStream2 = null;
                    inputStream3 = inputStream2;
                    inputStream = inputStream3;
                    file3 = file;
                    if (file3 != null) {
                    }
                    ThrowableUtil.addSuppressedAndClear(e, arrayList);
                    throw e;
                } catch (Exception e8) {
                    e2 = e8;
                    fileOutputStream = fileOutputStream3;
                    file2 = file;
                    UnsatisfiedLinkError unsatisfiedLinkError22 = new UnsatisfiedLinkError("could not load a native library: " + outline18);
                    unsatisfiedLinkError22.initCause(e2);
                    ThrowableUtil.addSuppressedAndClear(unsatisfiedLinkError22, arrayList);
                    throw unsatisfiedLinkError22;
                } catch (Throwable th7) {
                    th = th7;
                    fileOutputStream2 = null;
                    inputStream4 = inputStream2;
                    fileOutputStream = fileOutputStream2;
                    closeQuietly(inputStream4);
                    closeQuietly(fileOutputStream);
                    file.deleteOnExit();
                    throw th;
                }
            } catch (UnsatisfiedLinkError e9) {
                e = e9;
                fileOutputStream2 = null;
                inputStream = inputStream3;
                file3 = file;
                if (file3 != null) {
                }
                ThrowableUtil.addSuppressedAndClear(e, arrayList);
                throw e;
            } catch (Exception e10) {
                e2 = e10;
                fileOutputStream = null;
                inputStream2 = null;
                file2 = file;
                UnsatisfiedLinkError unsatisfiedLinkError222 = new UnsatisfiedLinkError("could not load a native library: " + outline18);
                unsatisfiedLinkError222.initCause(e2);
                ThrowableUtil.addSuppressedAndClear(unsatisfiedLinkError222, arrayList);
                throw unsatisfiedLinkError222;
            } catch (Throwable th8) {
                th = th8;
                fileOutputStream = null;
                closeQuietly(inputStream4);
                closeQuietly(fileOutputStream);
                file.deleteOnExit();
                throw th;
            }
        }
    }

    public static void loadFirstAvailable(ClassLoader classLoader, String... strArr) {
        ArrayList arrayList = new ArrayList();
        for (String str : strArr) {
            try {
                load(str, classLoader);
                logger.debug("Loaded library with name '{}'", str);
                return;
            } catch (Throwable th) {
                arrayList.add(th);
            }
        }
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("Failed to load any of the given libraries: ");
        outline25.append(Arrays.toString(strArr));
        IllegalArgumentException illegalArgumentException = new IllegalArgumentException(outline25.toString());
        ThrowableUtil.addSuppressedAndClear(illegalArgumentException, arrayList);
        throw illegalArgumentException;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:12:0x0026, code lost:
        if (r1 != null) goto L_0x0028;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:13:0x0028, code lost:
        io.netty.util.internal.ThrowableUtil.addSuppressed(r3, r1);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:14:0x002b, code lost:
        rethrowWithMoreDetailsIfPossible(r4, r3);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:15:?, code lost:
        return;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:16:?, code lost:
        return;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:4:0x0012, code lost:
        r3 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:5:0x0014, code lost:
        r3 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:6:0x0017, code lost:
        r1 = r3;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:8:?, code lost:
        io.netty.util.internal.NativeLibraryUtil.loadLibrary(r4, r5);
        io.netty.util.internal.NativeLibraryLoader.logger.debug("Successfully loaded the library {}", r4);
     */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Removed duplicated region for block: B:4:0x0012 A[ExcHandler: NoSuchMethodError (r3v4 'e' java.lang.NoSuchMethodError A[CUSTOM_DECLARE]), PHI: r1 
      PHI: (r1v2 java.lang.Throwable) = (r1v0 java.lang.Throwable), (r1v1 java.lang.Throwable), (r1v1 java.lang.Throwable), (r1v0 java.lang.Throwable) binds: [B:1:0x0005, B:7:0x0018, B:8:?, B:2:?] A[DONT_GENERATE, DONT_INLINE], Splitter:B:1:0x0005] */
    private static void loadLibrary(ClassLoader classLoader, String str, boolean z) {
        Throwable th = null;
        try {
            loadLibraryByHelper(tryToLoadClass(classLoader, NativeLibraryUtil.class), str, z);
            logger.debug("Successfully loaded the library {}", str);
        } catch (NoSuchMethodError e) {
        } catch (UnsatisfiedLinkError e2) {
            ThrowableUtil.addSuppressed(e2, th);
            throw e2;
        }
    }

    private static void loadLibraryByHelper(final Class<?> cls, final String str, final boolean z) {
        Object doPrivileged = AccessController.doPrivileged(new PrivilegedAction<Object>() {
            /* class io.netty.util.internal.NativeLibraryLoader.AnonymousClass1 */

            @Override // java.security.PrivilegedAction
            public Object run() {
                try {
                    Method method = cls.getMethod("loadLibrary", String.class, Boolean.TYPE);
                    method.setAccessible(true);
                    return method.invoke(null, str, Boolean.valueOf(z));
                } catch (Exception e) {
                    return e;
                }
            }
        });
        if (doPrivileged instanceof Throwable) {
            Throwable th = (Throwable) doPrivileged;
            Throwable cause = th.getCause();
            if (cause instanceof UnsatisfiedLinkError) {
                throw ((UnsatisfiedLinkError) cause);
            }
            UnsatisfiedLinkError unsatisfiedLinkError = new UnsatisfiedLinkError(th.getMessage());
            unsatisfiedLinkError.initCause(th);
            throw unsatisfiedLinkError;
        }
    }

    @SuppressJava6Requirement(reason = "Guarded by version check")
    private static void rethrowWithMoreDetailsIfPossible(String str, NoSuchMethodError noSuchMethodError) {
        if (PlatformDependent.javaVersion() >= 7) {
            throw new LinkageError(GeneratedOutlineSupport.outline19("Possible multiple incompatible native libraries on the classpath for '", str, "'?"), noSuchMethodError);
        }
        throw noSuchMethodError;
    }

    private static boolean shouldShadedLibraryIdBePatched(String str) {
        return TRY_TO_PATCH_SHADED_ID && PlatformDependent.isOsx() && !str.isEmpty();
    }

    private static boolean tryExec(String str) {
        try {
            int waitFor = Runtime.getRuntime().exec(str).waitFor();
            if (waitFor != 0) {
                logger.debug("Execution of '{}' failed: {}", str, Integer.valueOf(waitFor));
                return false;
            }
            logger.debug("Execution of '{}' succeed: {}", str, Integer.valueOf(waitFor));
            return true;
        } catch (InterruptedException unused) {
            Thread.currentThread().interrupt();
            return false;
        } catch (IOException e) {
            logger.info("Execution of '{}' failed.", str, e);
            return false;
        } catch (SecurityException e2) {
            logger.error("Execution of '{}' failed.", str, e2);
            return false;
        }
    }

    public static void tryPatchShadedLibraryIdAndSign(File file, String str) {
        StringBuilder outline29 = GeneratedOutlineSupport.outline29("install_name_tool -id ", new String(generateUniqueId(str.length()), CharsetUtil.UTF_8), " ");
        outline29.append(file.getAbsolutePath());
        if (tryExec(outline29.toString())) {
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("codesign -s - ");
            outline25.append(file.getAbsolutePath());
            tryExec(outline25.toString());
        }
    }

    private static Class<?> tryToLoadClass(final ClassLoader classLoader, final Class<?> cls) {
        try {
            return Class.forName(cls.getName(), false, classLoader);
        } catch (ClassNotFoundException e) {
            if (classLoader != null) {
                try {
                    final byte[] classToByteArray = classToByteArray(cls);
                    return (Class) AccessController.doPrivileged(new PrivilegedAction<Class<?>>() {
                        /* class io.netty.util.internal.NativeLibraryLoader.AnonymousClass2 */

                        @Override // java.security.PrivilegedAction
                        public Class<?> run() {
                            try {
                                Class cls = Integer.TYPE;
                                Method declaredMethod = ClassLoader.class.getDeclaredMethod("defineClass", String.class, byte[].class, cls, cls);
                                declaredMethod.setAccessible(true);
                                return (Class) declaredMethod.invoke(classLoader, cls.getName(), classToByteArray, 0, Integer.valueOf(classToByteArray.length));
                            } catch (Exception e) {
                                throw new IllegalStateException("Define class failed!", e);
                            }
                        }
                    });
                } catch (ClassNotFoundException e2) {
                    ThrowableUtil.addSuppressed(e2, e);
                    throw e2;
                } catch (RuntimeException e3) {
                    ThrowableUtil.addSuppressed(e3, e);
                    throw e3;
                } catch (Error e4) {
                    ThrowableUtil.addSuppressed(e4, e);
                    throw e4;
                }
            } else {
                throw e;
            }
        }
    }
}
