package org.xbill.DNS;

import com.android.tools.r8.GeneratedOutlineSupport;
import com.squareup.okhttp.internal.DiskLruCache;
import java.math.BigInteger;
import java.nio.ByteBuffer;
import java.security.KeyFactory;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.security.PublicKey;
import java.security.interfaces.DSAPublicKey;
import java.security.interfaces.ECPublicKey;
import java.security.interfaces.RSAPublicKey;
import java.security.spec.DSAPublicKeySpec;
import java.security.spec.ECFieldFp;
import java.security.spec.ECParameterSpec;
import java.security.spec.ECPoint;
import java.security.spec.ECPublicKeySpec;
import java.security.spec.EllipticCurve;
import java.security.spec.RSAPublicKeySpec;

public abstract class DNSSEC {
    public static final ECKeyInfo ECDSA_P256 = new ECKeyInfo(32, "FFFFFFFF00000001000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF", "FFFFFFFF00000001000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFC", "5AC635D8AA3A93E7B3EBBD55769886BC651D06B0CC53B0F63BCE3C3E27D2604B", "6B17D1F2E12C4247F8BCE6E563A440F277037D812DEB33A0F4A13945D898C296", "4FE342E2FE1A7F9B8EE7EB4A7C0F9E162BCE33576B315ECECBB6406837BF51F5", "FFFFFFFF00000000FFFFFFFFFFFFFFFFBCE6FAADA7179E84F3B9CAC2FC632551");
    public static final ECKeyInfo ECDSA_P384 = new ECKeyInfo(48, "FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFF0000000000000000FFFFFFFF", "FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFF0000000000000000FFFFFFFC", "B3312FA7E23EE7E4988E056BE3F82D19181D9C6EFE8141120314088F5013875AC656398D8A2ED19D2A85C8EDD3EC2AEF", "AA87CA22BE8B05378EB1C71EF320AD746E1D3B628BA79B9859F741E082542A385502F25DBF55296C3A545E3872760AB7", "3617DE4A96262C6F5D9E98BF9292DC29F8F41DBD289A147CE9DA3113B5F0B8C00A60B1CE1D7E819D7A431D7C90EA0E5F", "FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7634D81F4372DDF581A0DB248B0A77AECEC196ACCC52973");
    public static final ECKeyInfo GOST = new ECKeyInfo(32, "FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD97", "FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD94", "A6", DiskLruCache.VERSION_1, "8D91E471E0989CDA27DF505A453F2B7635294F2DDF23E3B122ACC99C9E9F1E14", "FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6C611070995AD10045841B09B761B893");

    public abstract class Algorithm {
        public static Mnemonic algs;

        static {
            Mnemonic mnemonic = new Mnemonic("DNSSEC algorithm", 2);
            algs = mnemonic;
            mnemonic.max = KEYRecord.PROTOCOL_ANY;
            mnemonic.numericok = true;
            mnemonic.add(1, "RSAMD5");
            algs.add(2, "DH");
            algs.add(3, "DSA");
            algs.add(5, "RSASHA1");
            algs.add(6, "DSA-NSEC3-SHA1");
            algs.add(7, "RSA-NSEC3-SHA1");
            algs.add(8, "RSASHA256");
            algs.add(10, "RSASHA512");
            algs.add(12, "ECC-GOST");
            algs.add(13, "ECDSAP256SHA256");
            algs.add(14, "ECDSAP384SHA384");
            algs.add(252, "INDIRECT");
            algs.add(CERTRecord.URI, "PRIVATEDNS");
            algs.add(CERTRecord.OID, "PRIVATEOID");
        }

        public static int value(String str) {
            return algs.getValue(str);
        }
    }

    public class DNSSECException extends Exception {
        public DNSSECException(String str) {
            super(str);
        }
    }

    public class ECKeyInfo {
        public BigInteger a;
        public BigInteger b;
        public EllipticCurve curve = new EllipticCurve(new ECFieldFp(this.p), this.a, this.b);
        public BigInteger gx;
        public BigInteger gy;
        public int length;
        public BigInteger n;
        public BigInteger p;
        public ECParameterSpec spec = new ECParameterSpec(this.curve, new ECPoint(this.gx, this.gy), this.n, 1);

        public ECKeyInfo(int i, String str, String str2, String str3, String str4, String str5, String str6) {
            this.length = i;
            this.p = new BigInteger(str, 16);
            this.a = new BigInteger(str2, 16);
            this.b = new BigInteger(str3, 16);
            this.gx = new BigInteger(str4, 16);
            this.gy = new BigInteger(str5, 16);
            this.n = new BigInteger(str6, 16);
        }
    }

    public class IncompatibleKeyException extends IllegalArgumentException {
        public IncompatibleKeyException() {
            super("incompatible keys");
        }
    }

    public class MalformedKeyException extends DNSSECException {
        /* JADX WARNING: Illegal instructions before constructor call */
        public MalformedKeyException(KEYBase kEYBase) {
            super(r0.toString());
            StringBuffer outline24 = GeneratedOutlineSupport.outline24("Invalid key data: ");
            outline24.append(kEYBase.rdataToString());
        }
    }

    public class UnsupportedAlgorithmException extends DNSSECException {
        /* JADX WARNING: Illegal instructions before constructor call */
        public UnsupportedAlgorithmException(int i) {
            super(r0.toString());
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("Unsupported algorithm: ");
            stringBuffer.append(i);
        }
    }

    public static byte[] fromECDSAPublicKey(ECPublicKey eCPublicKey, ECKeyInfo eCKeyInfo) {
        DNSOutput dNSOutput = new DNSOutput();
        BigInteger affineX = eCPublicKey.getW().getAffineX();
        BigInteger affineY = eCPublicKey.getW().getAffineY();
        writePaddedBigInteger(dNSOutput, affineX, eCKeyInfo.length);
        writePaddedBigInteger(dNSOutput, affineY, eCKeyInfo.length);
        return dNSOutput.toByteArray();
    }

    public static byte[] fromPublicKey(PublicKey publicKey, int i) {
        switch (i) {
            case 1:
            case 5:
            case 7:
            case 8:
            case 10:
                if (publicKey instanceof RSAPublicKey) {
                    RSAPublicKey rSAPublicKey = (RSAPublicKey) publicKey;
                    DNSOutput dNSOutput = new DNSOutput();
                    BigInteger publicExponent = rSAPublicKey.getPublicExponent();
                    BigInteger modulus = rSAPublicKey.getModulus();
                    int bitLength = (publicExponent.bitLength() + 7) / 8;
                    if (bitLength < 256) {
                        dNSOutput.writeU8(bitLength);
                    } else {
                        dNSOutput.writeU8(0);
                        dNSOutput.writeU16(bitLength);
                    }
                    dNSOutput.writeByteArray(trimByteArray(publicExponent.toByteArray()));
                    writeBigInteger(dNSOutput, modulus);
                    return dNSOutput.toByteArray();
                }
                throw new IncompatibleKeyException();
            case 2:
            case 4:
            case 9:
            case 11:
            default:
                throw new UnsupportedAlgorithmException(i);
            case 3:
            case 6:
                if (publicKey instanceof DSAPublicKey) {
                    DSAPublicKey dSAPublicKey = (DSAPublicKey) publicKey;
                    DNSOutput dNSOutput2 = new DNSOutput();
                    BigInteger q = dSAPublicKey.getParams().getQ();
                    BigInteger p = dSAPublicKey.getParams().getP();
                    BigInteger g = dSAPublicKey.getParams().getG();
                    BigInteger y = dSAPublicKey.getY();
                    int length = (p.toByteArray().length - 64) / 8;
                    dNSOutput2.writeU8(length);
                    writeBigInteger(dNSOutput2, q);
                    dNSOutput2.writeByteArray(trimByteArray(p.toByteArray()));
                    int i2 = (length * 8) + 64;
                    writePaddedBigInteger(dNSOutput2, g, i2);
                    writePaddedBigInteger(dNSOutput2, y, i2);
                    return dNSOutput2.toByteArray();
                }
                throw new IncompatibleKeyException();
            case 12:
                if (publicKey instanceof ECPublicKey) {
                    ECPublicKey eCPublicKey = (ECPublicKey) publicKey;
                    ECKeyInfo eCKeyInfo = GOST;
                    DNSOutput dNSOutput3 = new DNSOutput();
                    BigInteger affineX = eCPublicKey.getW().getAffineX();
                    BigInteger affineY = eCPublicKey.getW().getAffineY();
                    writePaddedBigIntegerLittleEndian(dNSOutput3, affineX, eCKeyInfo.length);
                    writePaddedBigIntegerLittleEndian(dNSOutput3, affineY, eCKeyInfo.length);
                    return dNSOutput3.toByteArray();
                }
                throw new IncompatibleKeyException();
            case 13:
                if (publicKey instanceof ECPublicKey) {
                    return fromECDSAPublicKey((ECPublicKey) publicKey, ECDSA_P256);
                }
                throw new IncompatibleKeyException();
            case 14:
                if (publicKey instanceof ECPublicKey) {
                    return fromECDSAPublicKey((ECPublicKey) publicKey, ECDSA_P384);
                }
                throw new IncompatibleKeyException();
        }
    }

    public static byte[] generateDSDigest(DNSKEYRecord dNSKEYRecord, int i) {
        MessageDigest messageDigest;
        if (i == 1) {
            messageDigest = MessageDigest.getInstance("sha-1");
        } else if (i == 2) {
            messageDigest = MessageDigest.getInstance("sha-256");
        } else if (i == 3) {
            messageDigest = MessageDigest.getInstance("GOST3411");
        } else if (i == 4) {
            try {
                messageDigest = MessageDigest.getInstance("sha-384");
            } catch (NoSuchAlgorithmException unused) {
                throw new IllegalStateException("no message digest support");
            }
        } else {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("unknown DS digest type ");
            stringBuffer.append(i);
            throw new IllegalArgumentException(stringBuffer.toString());
        }
        messageDigest.update(dNSKEYRecord.getName().toWireCanonical());
        messageDigest.update(dNSKEYRecord.rdataToWireCanonical());
        return messageDigest.digest();
    }

    public static BigInteger readBigInteger(DNSInput dNSInput, int i) {
        dNSInput.require(i);
        byte[] bArr = new byte[i];
        dNSInput.byteBuffer.get(bArr, 0, i);
        return new BigInteger(1, bArr);
    }

    public static void reverseByteArray(byte[] bArr) {
        for (int i = 0; i < bArr.length / 2; i++) {
            int length = (bArr.length - i) - 1;
            byte b = bArr[i];
            bArr[i] = bArr[length];
            bArr[length] = b;
        }
    }

    public static PublicKey toDSAPublicKey(KEYBase kEYBase) {
        DNSInput dNSInput = new DNSInput(kEYBase.getKey());
        int readU8 = dNSInput.readU8();
        if (readU8 <= 8) {
            BigInteger readBigInteger = readBigInteger(dNSInput, 20);
            int i = (readU8 * 8) + 64;
            BigInteger readBigInteger2 = readBigInteger(dNSInput, i);
            BigInteger readBigInteger3 = readBigInteger(dNSInput, i);
            return KeyFactory.getInstance("DSA").generatePublic(new DSAPublicKeySpec(readBigInteger(dNSInput, i), readBigInteger2, readBigInteger, readBigInteger3));
        }
        throw new MalformedKeyException(kEYBase);
    }

    public static PublicKey toECDSAPublicKey(KEYBase kEYBase, ECKeyInfo eCKeyInfo) {
        DNSInput dNSInput = new DNSInput(kEYBase.getKey());
        return KeyFactory.getInstance("EC").generatePublic(new ECPublicKeySpec(new ECPoint(readBigInteger(dNSInput, eCKeyInfo.length), readBigInteger(dNSInput, eCKeyInfo.length)), eCKeyInfo.spec));
    }

    public static PublicKey toECGOSTPublicKey(KEYBase kEYBase, ECKeyInfo eCKeyInfo) {
        ByteBuffer wrap = ByteBuffer.wrap(kEYBase.getKey());
        int i = eCKeyInfo.length;
        if (i <= wrap.remaining()) {
            byte[] bArr = new byte[i];
            wrap.get(bArr, 0, i);
            reverseByteArray(bArr);
            BigInteger bigInteger = new BigInteger(1, bArr);
            int i2 = eCKeyInfo.length;
            if (i2 <= wrap.remaining()) {
                byte[] bArr2 = new byte[i2];
                wrap.get(bArr2, 0, i2);
                reverseByteArray(bArr2);
                return KeyFactory.getInstance("ECGOST3410").generatePublic(new ECPublicKeySpec(new ECPoint(bigInteger, new BigInteger(1, bArr2)), eCKeyInfo.spec));
            }
            throw new WireParseException("end of input");
        }
        throw new WireParseException("end of input");
    }

    public static PublicKey toRSAPublicKey(KEYBase kEYBase) {
        DNSInput dNSInput = new DNSInput(kEYBase.getKey());
        int readU8 = dNSInput.readU8();
        if (readU8 == 0) {
            readU8 = dNSInput.readU16();
        }
        BigInteger readBigInteger = readBigInteger(dNSInput, readU8);
        return KeyFactory.getInstance("RSA").generatePublic(new RSAPublicKeySpec(new BigInteger(1, dNSInput.readByteArray()), readBigInteger));
    }

    public static byte[] trimByteArray(byte[] bArr) {
        if (bArr[0] != 0) {
            return bArr;
        }
        byte[] bArr2 = new byte[(bArr.length - 1)];
        System.arraycopy(bArr, 1, bArr2, 0, bArr.length - 1);
        return bArr2;
    }

    public static void writeBigInteger(DNSOutput dNSOutput, BigInteger bigInteger) {
        dNSOutput.writeByteArray(trimByteArray(bigInteger.toByteArray()));
    }

    public static void writePaddedBigInteger(DNSOutput dNSOutput, BigInteger bigInteger, int i) {
        byte[] trimByteArray = trimByteArray(bigInteger.toByteArray());
        if (trimByteArray.length <= i) {
            if (trimByteArray.length < i) {
                dNSOutput.writeByteArray(new byte[(i - trimByteArray.length)]);
            }
            dNSOutput.writeByteArray(trimByteArray);
            return;
        }
        throw new IllegalArgumentException();
    }

    public static void writePaddedBigIntegerLittleEndian(DNSOutput dNSOutput, BigInteger bigInteger, int i) {
        byte[] trimByteArray = trimByteArray(bigInteger.toByteArray());
        if (trimByteArray.length <= i) {
            reverseByteArray(trimByteArray);
            dNSOutput.writeByteArray(trimByteArray);
            if (trimByteArray.length < i) {
                dNSOutput.writeByteArray(new byte[(i - trimByteArray.length)]);
                return;
            }
            return;
        }
        throw new IllegalArgumentException();
    }
}
