package com.bumptech.glide;

import androidx.core.util.Pools$Pool;
import androidx.core.util.Pools$SynchronizedPool;
import com.android.tools.r8.GeneratedOutlineSupport;
import com.bumptech.glide.load.Encoder;
import com.bumptech.glide.load.ImageHeaderParser;
import com.bumptech.glide.load.ResourceDecoder;
import com.bumptech.glide.load.ResourceEncoder;
import com.bumptech.glide.load.data.DataRewinder;
import com.bumptech.glide.load.data.DataRewinderRegistry;
import com.bumptech.glide.load.model.ModelLoader;
import com.bumptech.glide.load.model.ModelLoaderFactory;
import com.bumptech.glide.load.model.ModelLoaderRegistry;
import com.bumptech.glide.load.model.MultiModelLoaderFactory;
import com.bumptech.glide.load.resource.transcode.ResourceTranscoder;
import com.bumptech.glide.load.resource.transcode.TranscoderRegistry;
import com.bumptech.glide.provider.EncoderRegistry;
import com.bumptech.glide.provider.ImageHeaderParserRegistry;
import com.bumptech.glide.provider.LoadPathCache;
import com.bumptech.glide.provider.ModelToResourceClassCache;
import com.bumptech.glide.provider.ResourceDecoderRegistry;
import com.bumptech.glide.provider.ResourceEncoderRegistry;
import com.bumptech.glide.util.pool.FactoryPools;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import java.util.Objects;

public class Registry {
    public final DataRewinderRegistry dataRewinderRegistry;
    public final ResourceDecoderRegistry decoderRegistry;
    public final EncoderRegistry encoderRegistry;
    public final ImageHeaderParserRegistry imageHeaderParserRegistry;
    public final LoadPathCache loadPathCache = new LoadPathCache();
    public final ModelLoaderRegistry modelLoaderRegistry;
    public final ModelToResourceClassCache modelToResourceClassCache = new ModelToResourceClassCache();
    public final ResourceEncoderRegistry resourceEncoderRegistry;
    public final Pools$Pool<List<Throwable>> throwableListPool;
    public final TranscoderRegistry transcoderRegistry;

    public class MissingComponentException extends RuntimeException {
        public MissingComponentException(String str) {
            super(str);
        }
    }

    public final class NoImageHeaderParserException extends MissingComponentException {
        public NoImageHeaderParserException() {
            super("Failed to find image header parser.");
        }
    }

    public class NoModelLoaderAvailableException extends MissingComponentException {
        /* JADX WARNING: Illegal instructions before constructor call */
        public NoModelLoaderAvailableException(Object obj) {
            super(r0.toString());
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("Failed to find any ModelLoaders registered for model class: ");
            outline25.append(obj.getClass());
        }

        public <M> NoModelLoaderAvailableException(M m, List<ModelLoader<M, ?>> list) {
            super("Found ModelLoaders for model class: " + list + ", but none that handle this specific model instance: " + ((Object) m));
        }

        public NoModelLoaderAvailableException(Class<?> cls, Class<?> cls2) {
            super("Failed to find any ModelLoaders for model: " + cls + " and data: " + cls2);
        }
    }

    public class NoResultEncoderAvailableException extends MissingComponentException {
        public NoResultEncoderAvailableException(Class<?> cls) {
            super("Failed to find result encoder for resource class: " + cls + ", you may need to consider registering a new Encoder for the requested type or DiskCacheStrategy.DATA/DiskCacheStrategy.NONE if caching your transformed resource is unnecessary.");
        }
    }

    public class NoSourceEncoderAvailableException extends MissingComponentException {
        public NoSourceEncoderAvailableException(Class<?> cls) {
            super("Failed to find source encoder for data class: " + cls);
        }
    }

    public Registry() {
        FactoryPools.FactoryPool factoryPool = new FactoryPools.FactoryPool(new Pools$SynchronizedPool(20), new FactoryPools.Factory<List<T>>() {
            /* class com.bumptech.glide.util.pool.FactoryPools.AnonymousClass2 */

            @Override // com.bumptech.glide.util.pool.FactoryPools.Factory
            public Object create() {
                return new ArrayList();
            }
        }, new FactoryPools.Resetter<List<T>>() {
            /* class com.bumptech.glide.util.pool.FactoryPools.AnonymousClass3 */

            @Override // com.bumptech.glide.util.pool.FactoryPools.Resetter
            public void reset(Object obj) {
                ((List) obj).clear();
            }
        });
        this.throwableListPool = factoryPool;
        this.modelLoaderRegistry = new ModelLoaderRegistry(factoryPool);
        this.encoderRegistry = new EncoderRegistry();
        this.decoderRegistry = new ResourceDecoderRegistry();
        this.resourceEncoderRegistry = new ResourceEncoderRegistry();
        this.dataRewinderRegistry = new DataRewinderRegistry();
        this.transcoderRegistry = new TranscoderRegistry();
        this.imageHeaderParserRegistry = new ImageHeaderParserRegistry();
        List<String> asList = Arrays.asList("Gif", "Bitmap", "BitmapDrawable");
        ArrayList arrayList = new ArrayList(asList.size());
        arrayList.add("legacy_prepend_all");
        for (String str : asList) {
            arrayList.add(str);
        }
        arrayList.add("legacy_append");
        ResourceDecoderRegistry resourceDecoderRegistry = this.decoderRegistry;
        synchronized (resourceDecoderRegistry) {
            ArrayList arrayList2 = new ArrayList(resourceDecoderRegistry.bucketPriorityList);
            resourceDecoderRegistry.bucketPriorityList.clear();
            Iterator it = arrayList.iterator();
            while (it.hasNext()) {
                resourceDecoderRegistry.bucketPriorityList.add((String) it.next());
            }
            Iterator it2 = arrayList2.iterator();
            while (it2.hasNext()) {
                String str2 = (String) it2.next();
                if (!arrayList.contains(str2)) {
                    resourceDecoderRegistry.bucketPriorityList.add(str2);
                }
            }
        }
    }

    public <Data> Registry append(Class<Data> cls, Encoder<Data> encoder) {
        EncoderRegistry encoderRegistry2 = this.encoderRegistry;
        synchronized (encoderRegistry2) {
            encoderRegistry2.encoders.add(new EncoderRegistry.Entry<>(cls, encoder));
        }
        return this;
    }

    public List<ImageHeaderParser> getImageHeaderParsers() {
        List<ImageHeaderParser> list;
        ImageHeaderParserRegistry imageHeaderParserRegistry2 = this.imageHeaderParserRegistry;
        synchronized (imageHeaderParserRegistry2) {
            list = imageHeaderParserRegistry2.parsers;
        }
        if (!list.isEmpty()) {
            return list;
        }
        throw new NoImageHeaderParserException();
    }

    public <Model> List<ModelLoader<Model, ?>> getModelLoaders(Model model) {
        List<ModelLoader<Model, ?>> list;
        ModelLoaderRegistry modelLoaderRegistry2 = this.modelLoaderRegistry;
        Objects.requireNonNull(modelLoaderRegistry2);
        Class<?> cls = model.getClass();
        synchronized (modelLoaderRegistry2) {
            ModelLoaderRegistry.ModelLoaderCache.Entry<?> entry = modelLoaderRegistry2.cache.cachedModelLoaders.get(cls);
            if (entry == null) {
                list = null;
            } else {
                list = entry.loaders;
            }
            if (list == null) {
                list = Collections.unmodifiableList(modelLoaderRegistry2.multiModelLoaderFactory.build(cls));
                if (modelLoaderRegistry2.cache.cachedModelLoaders.put(cls, new ModelLoaderRegistry.ModelLoaderCache.Entry<>(list)) != null) {
                    throw new IllegalStateException("Already cached loaders for model: " + cls);
                }
            }
        }
        if (!list.isEmpty()) {
            int size = list.size();
            List<ModelLoader<Model, ?>> emptyList = Collections.emptyList();
            boolean z = true;
            for (int i = 0; i < size; i++) {
                ModelLoader<Model, ?> modelLoader = list.get(i);
                if (modelLoader.handles(model)) {
                    if (z) {
                        emptyList = new ArrayList<>(size - i);
                        z = false;
                    }
                    emptyList.add(modelLoader);
                }
            }
            if (!emptyList.isEmpty()) {
                return emptyList;
            }
            throw new NoModelLoaderAvailableException(model, list);
        }
        throw new NoModelLoaderAvailableException(model);
    }

    public Registry register(DataRewinder.Factory<?> factory) {
        DataRewinderRegistry dataRewinderRegistry2 = this.dataRewinderRegistry;
        synchronized (dataRewinderRegistry2) {
            dataRewinderRegistry2.rewinders.put(factory.getDataClass(), factory);
        }
        return this;
    }

    public <Data, TResource> Registry append(String str, Class<Data> cls, Class<TResource> cls2, ResourceDecoder<Data, TResource> resourceDecoder) {
        ResourceDecoderRegistry resourceDecoderRegistry = this.decoderRegistry;
        synchronized (resourceDecoderRegistry) {
            resourceDecoderRegistry.getOrAddEntryList(str).add(new ResourceDecoderRegistry.Entry<>(cls, cls2, resourceDecoder));
        }
        return this;
    }

    public <TResource, Transcode> Registry register(Class<TResource> cls, Class<Transcode> cls2, ResourceTranscoder<TResource, Transcode> resourceTranscoder) {
        TranscoderRegistry transcoderRegistry2 = this.transcoderRegistry;
        synchronized (transcoderRegistry2) {
            transcoderRegistry2.transcoders.add(new TranscoderRegistry.Entry<>(cls, cls2, resourceTranscoder));
        }
        return this;
    }

    public <TResource> Registry append(Class<TResource> cls, ResourceEncoder<TResource> resourceEncoder) {
        ResourceEncoderRegistry resourceEncoderRegistry2 = this.resourceEncoderRegistry;
        synchronized (resourceEncoderRegistry2) {
            resourceEncoderRegistry2.encoders.add(new ResourceEncoderRegistry.Entry<>(cls, resourceEncoder));
        }
        return this;
    }

    public <Model, Data> Registry append(Class<Model> cls, Class<Data> cls2, ModelLoaderFactory<Model, Data> modelLoaderFactory) {
        ModelLoaderRegistry modelLoaderRegistry2 = this.modelLoaderRegistry;
        synchronized (modelLoaderRegistry2) {
            MultiModelLoaderFactory multiModelLoaderFactory = modelLoaderRegistry2.multiModelLoaderFactory;
            synchronized (multiModelLoaderFactory) {
                MultiModelLoaderFactory.Entry<?, ?> entry = new MultiModelLoaderFactory.Entry<>(cls, cls2, modelLoaderFactory);
                List<MultiModelLoaderFactory.Entry<?, ?>> list = multiModelLoaderFactory.entries;
                list.add(list.size(), entry);
            }
            modelLoaderRegistry2.cache.cachedModelLoaders.clear();
        }
        return this;
    }
}
