package com.google.protobuf;

import java.lang.reflect.Field;
import java.nio.Buffer;
import java.nio.ByteBuffer;
import java.nio.ByteOrder;
import java.security.AccessController;
import java.security.PrivilegedExceptionAction;
import java.util.logging.Level;
import java.util.logging.Logger;
import org.xbill.DNS.KEYRecord;
import sun.misc.Unsafe;

public abstract class UnsafeUtil {
    public static final long BUFFER_ADDRESS_OFFSET;
    public static final long BYTE_ARRAY_BASE_OFFSET = ((long) arrayBaseOffset(byte[].class));
    public static final boolean HAS_UNSAFE_ARRAY_OPERATIONS;
    public static final boolean HAS_UNSAFE_BYTEBUFFER_OPERATIONS;
    public static final boolean IS_ANDROID_32;
    public static final boolean IS_ANDROID_64;
    public static final boolean IS_BIG_ENDIAN = (ByteOrder.nativeOrder() == ByteOrder.BIG_ENDIAN);
    public static final MemoryAccessor MEMORY_ACCESSOR;
    public static final Class<?> MEMORY_CLASS = Android.MEMORY_CLASS;
    public static final Unsafe UNSAFE;
    public static final Logger logger = Logger.getLogger(UnsafeUtil.class.getName());

    public final class Android32MemoryAccessor extends MemoryAccessor {
        public Android32MemoryAccessor(Unsafe unsafe) {
            super(unsafe);
        }

        @Override // com.google.protobuf.UnsafeUtil.MemoryAccessor
        public void copyMemory(long j, byte[] bArr, long j2, long j3) {
            throw new UnsupportedOperationException();
        }

        @Override // com.google.protobuf.UnsafeUtil.MemoryAccessor
        public boolean getBoolean(Object obj, long j) {
            if (UnsafeUtil.IS_BIG_ENDIAN) {
                if (UnsafeUtil.getByteBigEndian(obj, j) != 0) {
                    return true;
                }
                return false;
            } else if (UnsafeUtil.getByteLittleEndian(obj, j) != 0) {
                return true;
            } else {
                return false;
            }
        }

        @Override // com.google.protobuf.UnsafeUtil.MemoryAccessor
        public byte getByte(long j) {
            throw new UnsupportedOperationException();
        }

        @Override // com.google.protobuf.UnsafeUtil.MemoryAccessor
        public double getDouble(Object obj, long j) {
            return Double.longBitsToDouble(getLong(obj, j));
        }

        @Override // com.google.protobuf.UnsafeUtil.MemoryAccessor
        public float getFloat(Object obj, long j) {
            return Float.intBitsToFloat(getInt(obj, j));
        }

        @Override // com.google.protobuf.UnsafeUtil.MemoryAccessor
        public long getLong(long j) {
            throw new UnsupportedOperationException();
        }

        @Override // com.google.protobuf.UnsafeUtil.MemoryAccessor
        public Object getStaticObject(Field field) {
            try {
                return field.get(null);
            } catch (IllegalAccessException unused) {
                return null;
            }
        }

        /* JADX DEBUG: Multi-variable search result rejected for r5v0, resolved type: boolean */
        /* JADX WARN: Multi-variable type inference failed */
        @Override // com.google.protobuf.UnsafeUtil.MemoryAccessor
        public void putBoolean(Object obj, long j, boolean z) {
            if (UnsafeUtil.IS_BIG_ENDIAN) {
                UnsafeUtil.putByteBigEndian(obj, j, z ? (byte) 1 : 0);
            } else {
                UnsafeUtil.putByteLittleEndian(obj, j, z ? (byte) 1 : 0);
            }
        }

        @Override // com.google.protobuf.UnsafeUtil.MemoryAccessor
        public void putByte(Object obj, long j, byte b) {
            if (UnsafeUtil.IS_BIG_ENDIAN) {
                UnsafeUtil.putByteBigEndian(obj, j, b);
            } else {
                UnsafeUtil.putByteLittleEndian(obj, j, b);
            }
        }

        @Override // com.google.protobuf.UnsafeUtil.MemoryAccessor
        public void putDouble(Object obj, long j, double d) {
            putLong(obj, j, Double.doubleToLongBits(d));
        }

        @Override // com.google.protobuf.UnsafeUtil.MemoryAccessor
        public void putFloat(Object obj, long j, float f) {
            putInt(obj, j, Float.floatToIntBits(f));
        }

        @Override // com.google.protobuf.UnsafeUtil.MemoryAccessor
        public byte getByte(Object obj, long j) {
            if (UnsafeUtil.IS_BIG_ENDIAN) {
                return UnsafeUtil.getByteBigEndian(obj, j);
            }
            return UnsafeUtil.getByteLittleEndian(obj, j);
        }
    }

    public final class Android64MemoryAccessor extends MemoryAccessor {
        public Android64MemoryAccessor(Unsafe unsafe) {
            super(unsafe);
        }

        @Override // com.google.protobuf.UnsafeUtil.MemoryAccessor
        public void copyMemory(long j, byte[] bArr, long j2, long j3) {
            throw new UnsupportedOperationException();
        }

        @Override // com.google.protobuf.UnsafeUtil.MemoryAccessor
        public boolean getBoolean(Object obj, long j) {
            if (UnsafeUtil.IS_BIG_ENDIAN) {
                if (UnsafeUtil.getByteBigEndian(obj, j) != 0) {
                    return true;
                }
                return false;
            } else if (UnsafeUtil.getByteLittleEndian(obj, j) != 0) {
                return true;
            } else {
                return false;
            }
        }

        @Override // com.google.protobuf.UnsafeUtil.MemoryAccessor
        public byte getByte(long j) {
            throw new UnsupportedOperationException();
        }

        @Override // com.google.protobuf.UnsafeUtil.MemoryAccessor
        public double getDouble(Object obj, long j) {
            return Double.longBitsToDouble(getLong(obj, j));
        }

        @Override // com.google.protobuf.UnsafeUtil.MemoryAccessor
        public float getFloat(Object obj, long j) {
            return Float.intBitsToFloat(getInt(obj, j));
        }

        @Override // com.google.protobuf.UnsafeUtil.MemoryAccessor
        public long getLong(long j) {
            throw new UnsupportedOperationException();
        }

        @Override // com.google.protobuf.UnsafeUtil.MemoryAccessor
        public Object getStaticObject(Field field) {
            try {
                return field.get(null);
            } catch (IllegalAccessException unused) {
                return null;
            }
        }

        /* JADX DEBUG: Multi-variable search result rejected for r5v0, resolved type: boolean */
        /* JADX WARN: Multi-variable type inference failed */
        @Override // com.google.protobuf.UnsafeUtil.MemoryAccessor
        public void putBoolean(Object obj, long j, boolean z) {
            if (UnsafeUtil.IS_BIG_ENDIAN) {
                UnsafeUtil.putByteBigEndian(obj, j, z ? (byte) 1 : 0);
            } else {
                UnsafeUtil.putByteLittleEndian(obj, j, z ? (byte) 1 : 0);
            }
        }

        @Override // com.google.protobuf.UnsafeUtil.MemoryAccessor
        public void putByte(Object obj, long j, byte b) {
            if (UnsafeUtil.IS_BIG_ENDIAN) {
                UnsafeUtil.putByteBigEndian(obj, j, b);
            } else {
                UnsafeUtil.putByteLittleEndian(obj, j, b);
            }
        }

        @Override // com.google.protobuf.UnsafeUtil.MemoryAccessor
        public void putDouble(Object obj, long j, double d) {
            putLong(obj, j, Double.doubleToLongBits(d));
        }

        @Override // com.google.protobuf.UnsafeUtil.MemoryAccessor
        public void putFloat(Object obj, long j, float f) {
            putInt(obj, j, Float.floatToIntBits(f));
        }

        @Override // com.google.protobuf.UnsafeUtil.MemoryAccessor
        public byte getByte(Object obj, long j) {
            if (UnsafeUtil.IS_BIG_ENDIAN) {
                return UnsafeUtil.getByteBigEndian(obj, j);
            }
            return UnsafeUtil.getByteLittleEndian(obj, j);
        }
    }

    public final class JvmMemoryAccessor extends MemoryAccessor {
        public JvmMemoryAccessor(Unsafe unsafe) {
            super(unsafe);
        }

        @Override // com.google.protobuf.UnsafeUtil.MemoryAccessor
        public void copyMemory(long j, byte[] bArr, long j2, long j3) {
            this.unsafe.copyMemory((Object) null, j, bArr, UnsafeUtil.BYTE_ARRAY_BASE_OFFSET + j2, j3);
        }

        @Override // com.google.protobuf.UnsafeUtil.MemoryAccessor
        public boolean getBoolean(Object obj, long j) {
            return this.unsafe.getBoolean(obj, j);
        }

        @Override // com.google.protobuf.UnsafeUtil.MemoryAccessor
        public byte getByte(long j) {
            return this.unsafe.getByte(j);
        }

        @Override // com.google.protobuf.UnsafeUtil.MemoryAccessor
        public double getDouble(Object obj, long j) {
            return this.unsafe.getDouble(obj, j);
        }

        @Override // com.google.protobuf.UnsafeUtil.MemoryAccessor
        public float getFloat(Object obj, long j) {
            return this.unsafe.getFloat(obj, j);
        }

        @Override // com.google.protobuf.UnsafeUtil.MemoryAccessor
        public long getLong(long j) {
            return this.unsafe.getLong(j);
        }

        @Override // com.google.protobuf.UnsafeUtil.MemoryAccessor
        public Object getStaticObject(Field field) {
            return getObject(this.unsafe.staticFieldBase(field), this.unsafe.staticFieldOffset(field));
        }

        @Override // com.google.protobuf.UnsafeUtil.MemoryAccessor
        public void putBoolean(Object obj, long j, boolean z) {
            this.unsafe.putBoolean(obj, j, z);
        }

        @Override // com.google.protobuf.UnsafeUtil.MemoryAccessor
        public void putByte(Object obj, long j, byte b) {
            this.unsafe.putByte(obj, j, b);
        }

        @Override // com.google.protobuf.UnsafeUtil.MemoryAccessor
        public void putDouble(Object obj, long j, double d) {
            this.unsafe.putDouble(obj, j, d);
        }

        @Override // com.google.protobuf.UnsafeUtil.MemoryAccessor
        public void putFloat(Object obj, long j, float f) {
            this.unsafe.putFloat(obj, j, f);
        }

        @Override // com.google.protobuf.UnsafeUtil.MemoryAccessor
        public byte getByte(Object obj, long j) {
            return this.unsafe.getByte(obj, j);
        }
    }

    public abstract class MemoryAccessor {
        public Unsafe unsafe;

        public MemoryAccessor(Unsafe unsafe2) {
            this.unsafe = unsafe2;
        }

        public final int arrayBaseOffset(Class<?> cls) {
            return this.unsafe.arrayBaseOffset(cls);
        }

        public final int arrayIndexScale(Class<?> cls) {
            return this.unsafe.arrayIndexScale(cls);
        }

        public abstract void copyMemory(long j, byte[] bArr, long j2, long j3);

        public abstract boolean getBoolean(Object obj, long j);

        public abstract byte getByte(long j);

        public abstract byte getByte(Object obj, long j);

        public abstract double getDouble(Object obj, long j);

        public abstract float getFloat(Object obj, long j);

        public final int getInt(Object obj, long j) {
            return this.unsafe.getInt(obj, j);
        }

        public abstract long getLong(long j);

        public final long getLong(Object obj, long j) {
            return this.unsafe.getLong(obj, j);
        }

        public final Object getObject(Object obj, long j) {
            return this.unsafe.getObject(obj, j);
        }

        public abstract Object getStaticObject(Field field);

        public final long objectFieldOffset(Field field) {
            return this.unsafe.objectFieldOffset(field);
        }

        public abstract void putBoolean(Object obj, long j, boolean z);

        public abstract void putByte(Object obj, long j, byte b);

        public abstract void putDouble(Object obj, long j, double d);

        public abstract void putFloat(Object obj, long j, float f);

        public final void putInt(Object obj, long j, int i) {
            this.unsafe.putInt(obj, j, i);
        }

        public final void putLong(Object obj, long j, long j2) {
            this.unsafe.putLong(obj, j, j2);
        }

        public final void putObject(Object obj, long j, Object obj2) {
            this.unsafe.putObject(obj, j, obj2);
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:37:0x0135  */
    /* JADX WARNING: Removed duplicated region for block: B:39:0x013a A[SYNTHETIC, Splitter:B:39:0x013a] */
    /* JADX WARNING: Removed duplicated region for block: B:55:0x0283  */
    /* JADX WARNING: Removed duplicated region for block: B:61:0x0299  */
    /* JADX WARNING: Removed duplicated region for block: B:62:0x029b  */
    static {
        Class cls;
        Class cls2;
        boolean z;
        Unsafe unsafe;
        boolean z2;
        MemoryAccessor memoryAccessor;
        Object th;
        Object th2;
        Unsafe unsafe2 = getUnsafe();
        UNSAFE = unsafe2;
        Class<?> cls3 = Long.TYPE;
        boolean determineAndroidSupportByAddressSize = determineAndroidSupportByAddressSize(cls3);
        IS_ANDROID_64 = determineAndroidSupportByAddressSize;
        Class<?> cls4 = Integer.TYPE;
        boolean determineAndroidSupportByAddressSize2 = determineAndroidSupportByAddressSize(cls4);
        IS_ANDROID_32 = determineAndroidSupportByAddressSize2;
        MemoryAccessor memoryAccessor2 = null;
        if (unsafe2 != null) {
            if (!Android.isOnAndroidDevice()) {
                memoryAccessor2 = new JvmMemoryAccessor(unsafe2);
            } else if (determineAndroidSupportByAddressSize) {
                memoryAccessor2 = new Android64MemoryAccessor(unsafe2);
            } else if (determineAndroidSupportByAddressSize2) {
                memoryAccessor2 = new Android32MemoryAccessor(unsafe2);
            }
        }
        MEMORY_ACCESSOR = memoryAccessor2;
        if (unsafe2 == null) {
            cls2 = int[].class;
        } else {
            try {
                Class<?> cls5 = unsafe2.getClass();
                cls2 = int[].class;
                try {
                    cls5.getMethod("objectFieldOffset", Field.class);
                    cls5.getMethod("getLong", Object.class, cls3);
                    if (bufferAddressField() != null) {
                        if (Android.isOnAndroidDevice()) {
                            cls = boolean[].class;
                        } else {
                            cls5.getMethod("getByte", cls3);
                            Class<?>[] clsArr = new Class[2];
                            clsArr[0] = cls3;
                            cls = boolean[].class;
                            try {
                                clsArr[1] = Byte.TYPE;
                                cls5.getMethod("putByte", clsArr);
                                cls5.getMethod("getInt", cls3);
                                cls5.getMethod("putInt", cls3, cls4);
                                cls5.getMethod("getLong", cls3);
                                cls5.getMethod("putLong", cls3, cls3);
                                cls5.getMethod("copyMemory", cls3, cls3, cls3);
                                cls5.getMethod("copyMemory", Object.class, cls3, Object.class, cls3, cls3);
                            } catch (Throwable th3) {
                                th2 = th3;
                            }
                        }
                        z = true;
                        HAS_UNSAFE_BYTEBUFFER_OPERATIONS = z;
                        unsafe = UNSAFE;
                        if (unsafe == null) {
                            try {
                                Class<?> cls6 = unsafe.getClass();
                                cls6.getMethod("objectFieldOffset", Field.class);
                                cls6.getMethod("arrayBaseOffset", Class.class);
                                cls6.getMethod("arrayIndexScale", Class.class);
                                Class<?>[] clsArr2 = new Class[2];
                                clsArr2[0] = Object.class;
                                Class<?> cls7 = Long.TYPE;
                                try {
                                    clsArr2[1] = cls7;
                                    cls6.getMethod("getInt", clsArr2);
                                    Class<?>[] clsArr3 = new Class[3];
                                    clsArr3[0] = Object.class;
                                    clsArr3[1] = cls7;
                                    clsArr3[2] = Integer.TYPE;
                                    cls6.getMethod("putInt", clsArr3);
                                    cls6.getMethod("getLong", Object.class, cls7);
                                    cls6.getMethod("putLong", Object.class, cls7, cls7);
                                    cls6.getMethod("getObject", Object.class, cls7);
                                    cls6.getMethod("putObject", Object.class, cls7, Object.class);
                                    if (!Android.isOnAndroidDevice()) {
                                        cls6.getMethod("getByte", Object.class, cls7);
                                        cls6.getMethod("putByte", Object.class, cls7, Byte.TYPE);
                                        cls6.getMethod("getBoolean", Object.class, cls7);
                                        cls6.getMethod("putBoolean", Object.class, cls7, Boolean.TYPE);
                                        cls6.getMethod("getFloat", Object.class, cls7);
                                        cls6.getMethod("putFloat", Object.class, cls7, Float.TYPE);
                                        cls6.getMethod("getDouble", Object.class, cls7);
                                        cls6.getMethod("putDouble", Object.class, cls7, Double.TYPE);
                                    }
                                    z2 = true;
                                } catch (Throwable th4) {
                                    th = th4;
                                    Logger logger2 = logger;
                                    Level level = Level.WARNING;
                                    String valueOf = String.valueOf(th);
                                    StringBuilder sb = new StringBuilder(valueOf.length() + 71);
                                    sb.append("platform method missing - proto runtime falling back to safer methods: ");
                                    sb.append(valueOf);
                                    logger2.log(level, sb.toString());
                                    z2 = false;
                                    HAS_UNSAFE_ARRAY_OPERATIONS = z2;
                                    arrayBaseOffset(cls);
                                    arrayIndexScale(cls);
                                    arrayBaseOffset(cls2);
                                    arrayIndexScale(cls2);
                                    arrayBaseOffset(long[].class);
                                    arrayIndexScale(long[].class);
                                    arrayBaseOffset(float[].class);
                                    arrayIndexScale(float[].class);
                                    arrayBaseOffset(double[].class);
                                    arrayIndexScale(double[].class);
                                    arrayBaseOffset(Object[].class);
                                    arrayIndexScale(Object[].class);
                                    Field bufferAddressField = bufferAddressField();
                                    BUFFER_ADDRESS_OFFSET = (bufferAddressField != null || (memoryAccessor = MEMORY_ACCESSOR) == null) ? -1 : memoryAccessor.objectFieldOffset(bufferAddressField);
                                }
                            } catch (Throwable th5) {
                                th = th5;
                                Logger logger22 = logger;
                                Level level2 = Level.WARNING;
                                String valueOf2 = String.valueOf(th);
                                StringBuilder sb2 = new StringBuilder(valueOf2.length() + 71);
                                sb2.append("platform method missing - proto runtime falling back to safer methods: ");
                                sb2.append(valueOf2);
                                logger22.log(level2, sb2.toString());
                                z2 = false;
                                HAS_UNSAFE_ARRAY_OPERATIONS = z2;
                                arrayBaseOffset(cls);
                                arrayIndexScale(cls);
                                arrayBaseOffset(cls2);
                                arrayIndexScale(cls2);
                                arrayBaseOffset(long[].class);
                                arrayIndexScale(long[].class);
                                arrayBaseOffset(float[].class);
                                arrayIndexScale(float[].class);
                                arrayBaseOffset(double[].class);
                                arrayIndexScale(double[].class);
                                arrayBaseOffset(Object[].class);
                                arrayIndexScale(Object[].class);
                                Field bufferAddressField2 = bufferAddressField();
                                BUFFER_ADDRESS_OFFSET = (bufferAddressField2 != null || (memoryAccessor = MEMORY_ACCESSOR) == null) ? -1 : memoryAccessor.objectFieldOffset(bufferAddressField2);
                            }
                            HAS_UNSAFE_ARRAY_OPERATIONS = z2;
                            arrayBaseOffset(cls);
                            arrayIndexScale(cls);
                            arrayBaseOffset(cls2);
                            arrayIndexScale(cls2);
                            arrayBaseOffset(long[].class);
                            arrayIndexScale(long[].class);
                            arrayBaseOffset(float[].class);
                            arrayIndexScale(float[].class);
                            arrayBaseOffset(double[].class);
                            arrayIndexScale(double[].class);
                            arrayBaseOffset(Object[].class);
                            arrayIndexScale(Object[].class);
                            Field bufferAddressField22 = bufferAddressField();
                            BUFFER_ADDRESS_OFFSET = (bufferAddressField22 != null || (memoryAccessor = MEMORY_ACCESSOR) == null) ? -1 : memoryAccessor.objectFieldOffset(bufferAddressField22);
                        }
                        z2 = false;
                        HAS_UNSAFE_ARRAY_OPERATIONS = z2;
                        arrayBaseOffset(cls);
                        arrayIndexScale(cls);
                        arrayBaseOffset(cls2);
                        arrayIndexScale(cls2);
                        arrayBaseOffset(long[].class);
                        arrayIndexScale(long[].class);
                        arrayBaseOffset(float[].class);
                        arrayIndexScale(float[].class);
                        arrayBaseOffset(double[].class);
                        arrayIndexScale(double[].class);
                        arrayBaseOffset(Object[].class);
                        arrayIndexScale(Object[].class);
                        Field bufferAddressField222 = bufferAddressField();
                        BUFFER_ADDRESS_OFFSET = (bufferAddressField222 != null || (memoryAccessor = MEMORY_ACCESSOR) == null) ? -1 : memoryAccessor.objectFieldOffset(bufferAddressField222);
                    }
                } catch (Throwable th6) {
                    th2 = th6;
                    cls = boolean[].class;
                    Logger logger3 = logger;
                    Level level3 = Level.WARNING;
                    String valueOf3 = String.valueOf(th2);
                    StringBuilder sb3 = new StringBuilder(valueOf3.length() + 71);
                    sb3.append("platform method missing - proto runtime falling back to safer methods: ");
                    sb3.append(valueOf3);
                    logger3.log(level3, sb3.toString());
                    z = false;
                    HAS_UNSAFE_BYTEBUFFER_OPERATIONS = z;
                    unsafe = UNSAFE;
                    if (unsafe == null) {
                    }
                    z2 = false;
                    HAS_UNSAFE_ARRAY_OPERATIONS = z2;
                    arrayBaseOffset(cls);
                    arrayIndexScale(cls);
                    arrayBaseOffset(cls2);
                    arrayIndexScale(cls2);
                    arrayBaseOffset(long[].class);
                    arrayIndexScale(long[].class);
                    arrayBaseOffset(float[].class);
                    arrayIndexScale(float[].class);
                    arrayBaseOffset(double[].class);
                    arrayIndexScale(double[].class);
                    arrayBaseOffset(Object[].class);
                    arrayIndexScale(Object[].class);
                    Field bufferAddressField2222 = bufferAddressField();
                    BUFFER_ADDRESS_OFFSET = (bufferAddressField2222 != null || (memoryAccessor = MEMORY_ACCESSOR) == null) ? -1 : memoryAccessor.objectFieldOffset(bufferAddressField2222);
                }
            } catch (Throwable th7) {
                th2 = th7;
                cls2 = int[].class;
                cls = boolean[].class;
                Logger logger32 = logger;
                Level level32 = Level.WARNING;
                String valueOf32 = String.valueOf(th2);
                StringBuilder sb32 = new StringBuilder(valueOf32.length() + 71);
                sb32.append("platform method missing - proto runtime falling back to safer methods: ");
                sb32.append(valueOf32);
                logger32.log(level32, sb32.toString());
                z = false;
                HAS_UNSAFE_BYTEBUFFER_OPERATIONS = z;
                unsafe = UNSAFE;
                if (unsafe == null) {
                }
                HAS_UNSAFE_ARRAY_OPERATIONS = z2;
                arrayBaseOffset(cls);
                arrayIndexScale(cls);
                arrayBaseOffset(cls2);
                arrayIndexScale(cls2);
                arrayBaseOffset(long[].class);
                arrayIndexScale(long[].class);
                arrayBaseOffset(float[].class);
                arrayIndexScale(float[].class);
                arrayBaseOffset(double[].class);
                arrayIndexScale(double[].class);
                arrayBaseOffset(Object[].class);
                arrayIndexScale(Object[].class);
                Field bufferAddressField22222 = bufferAddressField();
                BUFFER_ADDRESS_OFFSET = (bufferAddressField22222 != null || (memoryAccessor = MEMORY_ACCESSOR) == null) ? -1 : memoryAccessor.objectFieldOffset(bufferAddressField22222);
            }
        }
        cls = boolean[].class;
        z = false;
        HAS_UNSAFE_BYTEBUFFER_OPERATIONS = z;
        unsafe = UNSAFE;
        if (unsafe == null) {
        }
        HAS_UNSAFE_ARRAY_OPERATIONS = z2;
        arrayBaseOffset(cls);
        arrayIndexScale(cls);
        arrayBaseOffset(cls2);
        arrayIndexScale(cls2);
        arrayBaseOffset(long[].class);
        arrayIndexScale(long[].class);
        arrayBaseOffset(float[].class);
        arrayIndexScale(float[].class);
        arrayBaseOffset(double[].class);
        arrayIndexScale(double[].class);
        arrayBaseOffset(Object[].class);
        arrayIndexScale(Object[].class);
        Field bufferAddressField222222 = bufferAddressField();
        BUFFER_ADDRESS_OFFSET = (bufferAddressField222222 != null || (memoryAccessor = MEMORY_ACCESSOR) == null) ? -1 : memoryAccessor.objectFieldOffset(bufferAddressField222222);
    }

    public static long addressOffset(ByteBuffer byteBuffer) {
        return MEMORY_ACCESSOR.getLong(byteBuffer, BUFFER_ADDRESS_OFFSET);
    }

    public static <T> T allocateInstance(Class<T> cls) {
        try {
            return (T) UNSAFE.allocateInstance(cls);
        } catch (InstantiationException e) {
            throw new IllegalStateException(e);
        }
    }

    public static int arrayBaseOffset(Class<?> cls) {
        if (HAS_UNSAFE_ARRAY_OPERATIONS) {
            return MEMORY_ACCESSOR.arrayBaseOffset(cls);
        }
        return -1;
    }

    public static int arrayIndexScale(Class<?> cls) {
        if (HAS_UNSAFE_ARRAY_OPERATIONS) {
            return MEMORY_ACCESSOR.arrayIndexScale(cls);
        }
        return -1;
    }

    public static Field bufferAddressField() {
        Field field;
        Field field2;
        if (Android.isOnAndroidDevice()) {
            try {
                field2 = Buffer.class.getDeclaredField("effectiveDirectAddress");
            } catch (Throwable unused) {
                field2 = null;
            }
            if (field2 != null) {
                return field2;
            }
        }
        try {
            field = Buffer.class.getDeclaredField("address");
        } catch (Throwable unused2) {
            field = null;
        }
        if (field == null || field.getType() != Long.TYPE) {
            return null;
        }
        return field;
    }

    public static boolean determineAndroidSupportByAddressSize(Class<?> cls) {
        if (!Android.isOnAndroidDevice()) {
            return false;
        }
        try {
            Class<?> cls2 = MEMORY_CLASS;
            Class<?> cls3 = Boolean.TYPE;
            cls2.getMethod("peekLong", cls, cls3);
            cls2.getMethod("pokeLong", cls, Long.TYPE, cls3);
            Class<?> cls4 = Integer.TYPE;
            cls2.getMethod("pokeInt", cls, cls4, cls3);
            cls2.getMethod("peekInt", cls, cls3);
            cls2.getMethod("pokeByte", cls, Byte.TYPE);
            cls2.getMethod("peekByte", cls);
            cls2.getMethod("pokeByteArray", cls, byte[].class, cls4, cls4);
            cls2.getMethod("peekByteArray", cls, byte[].class, cls4, cls4);
            return true;
        } catch (Throwable unused) {
            return false;
        }
    }

    public static byte getByte(byte[] bArr, long j) {
        return MEMORY_ACCESSOR.getByte(bArr, BYTE_ARRAY_BASE_OFFSET + j);
    }

    public static byte getByteBigEndian(Object obj, long j) {
        return (byte) ((getInt(obj, -4 & j) >>> ((int) (((~j) & 3) << 3))) & KEYRecord.PROTOCOL_ANY);
    }

    public static byte getByteLittleEndian(Object obj, long j) {
        return (byte) ((getInt(obj, -4 & j) >>> ((int) ((j & 3) << 3))) & KEYRecord.PROTOCOL_ANY);
    }

    public static int getInt(Object obj, long j) {
        return MEMORY_ACCESSOR.getInt(obj, j);
    }

    public static long getLong(Object obj, long j) {
        return MEMORY_ACCESSOR.getLong(obj, j);
    }

    public static Object getObject(Object obj, long j) {
        return MEMORY_ACCESSOR.getObject(obj, j);
    }

    public static Unsafe getUnsafe() {
        try {
            return (Unsafe) AccessController.doPrivileged(new PrivilegedExceptionAction<Unsafe>() {
                /* class com.google.protobuf.UnsafeUtil.AnonymousClass1 */

                @Override // java.security.PrivilegedExceptionAction
                public Unsafe run() {
                    Field[] declaredFields = Unsafe.class.getDeclaredFields();
                    for (Field field : declaredFields) {
                        field.setAccessible(true);
                        Object obj = field.get(null);
                        if (Unsafe.class.isInstance(obj)) {
                            return (Unsafe) Unsafe.class.cast(obj);
                        }
                    }
                    return null;
                }
            });
        } catch (Throwable unused) {
            return null;
        }
    }

    public static long objectFieldOffset(Field field) {
        return MEMORY_ACCESSOR.objectFieldOffset(field);
    }

    public static void putBoolean(Object obj, long j, boolean z) {
        MEMORY_ACCESSOR.putBoolean(obj, j, z);
    }

    public static void putByte(byte[] bArr, long j, byte b) {
        MEMORY_ACCESSOR.putByte(bArr, BYTE_ARRAY_BASE_OFFSET + j, b);
    }

    public static void putByteBigEndian(Object obj, long j, byte b) {
        long j2 = -4 & j;
        int i = getInt(obj, j2);
        int i2 = ((~((int) j)) & 3) << 3;
        MemoryAccessor memoryAccessor = MEMORY_ACCESSOR;
        memoryAccessor.putInt(obj, j2, ((255 & b) << i2) | (i & (~(KEYRecord.PROTOCOL_ANY << i2))));
    }

    public static void putByteLittleEndian(Object obj, long j, byte b) {
        long j2 = -4 & j;
        int i = (((int) j) & 3) << 3;
        MemoryAccessor memoryAccessor = MEMORY_ACCESSOR;
        memoryAccessor.putInt(obj, j2, ((255 & b) << i) | (getInt(obj, j2) & (~(KEYRecord.PROTOCOL_ANY << i))));
    }

    public static void putDouble(Object obj, long j, double d) {
        MEMORY_ACCESSOR.putDouble(obj, j, d);
    }

    public static void putFloat(Object obj, long j, float f) {
        MEMORY_ACCESSOR.putFloat(obj, j, f);
    }

    public static void putInt(Object obj, long j, int i) {
        MEMORY_ACCESSOR.putInt(obj, j, i);
    }

    public static void putLong(Object obj, long j, long j2) {
        MEMORY_ACCESSOR.putLong(obj, j, j2);
    }

    public static void putObject(Object obj, long j, Object obj2) {
        MEMORY_ACCESSOR.putObject(obj, j, obj2);
    }

    public static byte getByte(long j) {
        return MEMORY_ACCESSOR.getByte(j);
    }
}
