package com.google.zxing.oned;

import com.google.zxing.BarcodeFormat;
import com.google.zxing.ChecksumException;
import com.google.zxing.DecodeHintType;
import com.google.zxing.FormatException;
import com.google.zxing.NotFoundException;
import com.google.zxing.Result;
import com.google.zxing.ResultPoint;
import com.google.zxing.common.BitArray;
import java.util.ArrayList;
import java.util.Map;

public final class Code128Reader extends OneDReader {
    public static final int[][] CODE_PATTERNS = {new int[]{2, 1, 2, 2, 2, 2}, new int[]{2, 2, 2, 1, 2, 2}, new int[]{2, 2, 2, 2, 2, 1}, new int[]{1, 2, 1, 2, 2, 3}, new int[]{1, 2, 1, 3, 2, 2}, new int[]{1, 3, 1, 2, 2, 2}, new int[]{1, 2, 2, 2, 1, 3}, new int[]{1, 2, 2, 3, 1, 2}, new int[]{1, 3, 2, 2, 1, 2}, new int[]{2, 2, 1, 2, 1, 3}, new int[]{2, 2, 1, 3, 1, 2}, new int[]{2, 3, 1, 2, 1, 2}, new int[]{1, 1, 2, 2, 3, 2}, new int[]{1, 2, 2, 1, 3, 2}, new int[]{1, 2, 2, 2, 3, 1}, new int[]{1, 1, 3, 2, 2, 2}, new int[]{1, 2, 3, 1, 2, 2}, new int[]{1, 2, 3, 2, 2, 1}, new int[]{2, 2, 3, 2, 1, 1}, new int[]{2, 2, 1, 1, 3, 2}, new int[]{2, 2, 1, 2, 3, 1}, new int[]{2, 1, 3, 2, 1, 2}, new int[]{2, 2, 3, 1, 1, 2}, new int[]{3, 1, 2, 1, 3, 1}, new int[]{3, 1, 1, 2, 2, 2}, new int[]{3, 2, 1, 1, 2, 2}, new int[]{3, 2, 1, 2, 2, 1}, new int[]{3, 1, 2, 2, 1, 2}, new int[]{3, 2, 2, 1, 1, 2}, new int[]{3, 2, 2, 2, 1, 1}, new int[]{2, 1, 2, 1, 2, 3}, new int[]{2, 1, 2, 3, 2, 1}, new int[]{2, 3, 2, 1, 2, 1}, new int[]{1, 1, 1, 3, 2, 3}, new int[]{1, 3, 1, 1, 2, 3}, new int[]{1, 3, 1, 3, 2, 1}, new int[]{1, 1, 2, 3, 1, 3}, new int[]{1, 3, 2, 1, 1, 3}, new int[]{1, 3, 2, 3, 1, 1}, new int[]{2, 1, 1, 3, 1, 3}, new int[]{2, 3, 1, 1, 1, 3}, new int[]{2, 3, 1, 3, 1, 1}, new int[]{1, 1, 2, 1, 3, 3}, new int[]{1, 1, 2, 3, 3, 1}, new int[]{1, 3, 2, 1, 3, 1}, new int[]{1, 1, 3, 1, 2, 3}, new int[]{1, 1, 3, 3, 2, 1}, new int[]{1, 3, 3, 1, 2, 1}, new int[]{3, 1, 3, 1, 2, 1}, new int[]{2, 1, 1, 3, 3, 1}, new int[]{2, 3, 1, 1, 3, 1}, new int[]{2, 1, 3, 1, 1, 3}, new int[]{2, 1, 3, 3, 1, 1}, new int[]{2, 1, 3, 1, 3, 1}, new int[]{3, 1, 1, 1, 2, 3}, new int[]{3, 1, 1, 3, 2, 1}, new int[]{3, 3, 1, 1, 2, 1}, new int[]{3, 1, 2, 1, 1, 3}, new int[]{3, 1, 2, 3, 1, 1}, new int[]{3, 3, 2, 1, 1, 1}, new int[]{3, 1, 4, 1, 1, 1}, new int[]{2, 2, 1, 4, 1, 1}, new int[]{4, 3, 1, 1, 1, 1}, new int[]{1, 1, 1, 2, 2, 4}, new int[]{1, 1, 1, 4, 2, 2}, new int[]{1, 2, 1, 1, 2, 4}, new int[]{1, 2, 1, 4, 2, 1}, new int[]{1, 4, 1, 1, 2, 2}, new int[]{1, 4, 1, 2, 2, 1}, new int[]{1, 1, 2, 2, 1, 4}, new int[]{1, 1, 2, 4, 1, 2}, new int[]{1, 2, 2, 1, 1, 4}, new int[]{1, 2, 2, 4, 1, 1}, new int[]{1, 4, 2, 1, 1, 2}, new int[]{1, 4, 2, 2, 1, 1}, new int[]{2, 4, 1, 2, 1, 1}, new int[]{2, 2, 1, 1, 1, 4}, new int[]{4, 1, 3, 1, 1, 1}, new int[]{2, 4, 1, 1, 1, 2}, new int[]{1, 3, 4, 1, 1, 1}, new int[]{1, 1, 1, 2, 4, 2}, new int[]{1, 2, 1, 1, 4, 2}, new int[]{1, 2, 1, 2, 4, 1}, new int[]{1, 1, 4, 2, 1, 2}, new int[]{1, 2, 4, 1, 1, 2}, new int[]{1, 2, 4, 2, 1, 1}, new int[]{4, 1, 1, 2, 1, 2}, new int[]{4, 2, 1, 1, 1, 2}, new int[]{4, 2, 1, 2, 1, 1}, new int[]{2, 1, 2, 1, 4, 1}, new int[]{2, 1, 4, 1, 2, 1}, new int[]{4, 1, 2, 1, 2, 1}, new int[]{1, 1, 1, 1, 4, 3}, new int[]{1, 1, 1, 3, 4, 1}, new int[]{1, 3, 1, 1, 4, 1}, new int[]{1, 1, 4, 1, 1, 3}, new int[]{1, 1, 4, 3, 1, 1}, new int[]{4, 1, 1, 1, 1, 3}, new int[]{4, 1, 1, 3, 1, 1}, new int[]{1, 1, 3, 1, 4, 1}, new int[]{1, 1, 4, 1, 3, 1}, new int[]{3, 1, 1, 1, 4, 1}, new int[]{4, 1, 1, 1, 3, 1}, new int[]{2, 1, 1, 4, 1, 2}, new int[]{2, 1, 1, 2, 1, 4}, new int[]{2, 1, 1, 2, 3, 2}, new int[]{2, 3, 3, 1, 1, 1, 2}};

    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:89:0x017f */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:116:0x01d4 */
    /* JADX DEBUG: Multi-variable search result rejected for r27v0, resolved type: com.google.zxing.common.BitArray */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r3v0 */
    /* JADX WARN: Type inference failed for: r3v1, types: [boolean] */
    /* JADX WARN: Type inference failed for: r3v2 */
    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    /* JADX WARNING: Code restructure failed: missing block: B:100:0x01a4, code lost:
        if (r3 != false) goto L_0x01a6;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:101:0x01a6, code lost:
        r3 = false;
        r10 = false;
        r13 = false;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:76:0x0153, code lost:
        if (r3 != false) goto L_0x01a6;
     */
    /* JADX WARNING: Removed duplicated region for block: B:103:0x01ae A[PHI: r19 
      PHI: (r19v12 boolean) = (r19v16 boolean), (r19v19 boolean) binds: [B:89:0x017f, B:67:0x0133] A[DONT_GENERATE, DONT_INLINE]] */
    /* JADX WARNING: Removed duplicated region for block: B:105:0x01b8 A[PHI: r3 r18 r19 
      PHI: (r3v16 boolean) = (r3v7 boolean), (r3v17 boolean), (r3v20 boolean), (r3v7 boolean), (r3v7 boolean), (r3v7 boolean), (r3v7 boolean), (r3v7 boolean), (r3v7 boolean), (r3v7 boolean), (r3v7 boolean), (r3v7 boolean) binds: [B:51:0x00f8, B:102:0x01ac, B:84:0x0175, B:89:0x017f, B:90:0x0183, B:94:0x018f, B:93:0x018b, B:79:0x015f, B:67:0x0133, B:68:0x0138, B:72:0x0145, B:71:0x0140] A[DONT_GENERATE, DONT_INLINE]
      PHI: (r18v5 boolean) = (r18v1 boolean), (r18v1 boolean), (r18v1 boolean), (r18v1 boolean), (r18v1 boolean), (r18v1 boolean), (r18v1 boolean), (r18v6 boolean), (r18v1 boolean), (r18v1 boolean), (r18v1 boolean), (r18v1 boolean) binds: [B:51:0x00f8, B:102:0x01ac, B:84:0x0175, B:89:0x017f, B:90:0x0183, B:94:0x018f, B:93:0x018b, B:79:0x015f, B:67:0x0133, B:68:0x0138, B:72:0x0145, B:71:0x0140] A[DONT_GENERATE, DONT_INLINE]
      PHI: (r19v11 boolean) = (r19v2 boolean), (r19v13 boolean), (r19v2 boolean), (r19v16 boolean), (r19v16 boolean), (r19v16 boolean), (r19v16 boolean), (r19v18 boolean), (r19v19 boolean), (r19v19 boolean), (r19v19 boolean), (r19v19 boolean) binds: [B:51:0x00f8, B:102:0x01ac, B:84:0x0175, B:89:0x017f, B:90:0x0183, B:94:0x018f, B:93:0x018b, B:79:0x015f, B:67:0x0133, B:68:0x0138, B:72:0x0145, B:71:0x0140] A[DONT_GENERATE, DONT_INLINE]] */
    /* JADX WARNING: Unknown variable types count: 1 */
    @Override // com.google.zxing.oned.OneDReader
    public Result decodeRow(int i, BitArray bitArray, Map<DecodeHintType, ?> map) {
        float f;
        char c;
        boolean z;
        boolean z2;
        int i2 = 1;
        ?? r3 = 0;
        boolean z3 = map != null && map.containsKey(DecodeHintType.ASSUME_GS1);
        int i3 = bitArray.size;
        int nextSet = bitArray.getNextSet(0);
        int i4 = 6;
        int[] iArr = new int[6];
        int i5 = nextSet;
        boolean z4 = false;
        int i6 = 0;
        while (nextSet < i3) {
            if (bitArray.get(nextSet) ^ z4) {
                iArr[i6] = iArr[i6] + i2;
            } else {
                if (i6 == 5) {
                    int i7 = 103;
                    int i8 = -1;
                    float f2 = 0.25f;
                    while (true) {
                        f = 0.7f;
                        if (i7 > 105) {
                            break;
                        }
                        float patternMatchVariance = OneDReader.patternMatchVariance(iArr, CODE_PATTERNS[i7], 0.7f);
                        if (patternMatchVariance < f2) {
                            f2 = patternMatchVariance;
                            i8 = i7;
                        }
                        i7++;
                    }
                    if (i8 >= 0) {
                        int i9 = r3 == true ? 1 : 0;
                        int i10 = r3 == true ? 1 : 0;
                        int i11 = r3 == true ? 1 : 0;
                        int i12 = r3 == true ? 1 : 0;
                        int i13 = r3 == true ? 1 : 0;
                        int i14 = r3 == true ? 1 : 0;
                        int i15 = r3 == true ? 1 : 0;
                        int i16 = r3 == true ? 1 : 0;
                        int i17 = r3 == true ? 1 : 0;
                        int i18 = r3 == true ? 1 : 0;
                        if (bitArray.isRange(Math.max(i9, i5 - ((nextSet - i5) / 2)), i5, r3)) {
                            int[] iArr2 = new int[3];
                            char c2 = r3 == true ? 1 : 0;
                            char c3 = r3 == true ? 1 : 0;
                            char c4 = r3 == true ? 1 : 0;
                            char c5 = r3 == true ? 1 : 0;
                            char c6 = r3 == true ? 1 : 0;
                            char c7 = r3 == true ? 1 : 0;
                            char c8 = r3 == true ? 1 : 0;
                            char c9 = r3 == true ? 1 : 0;
                            char c10 = r3 == true ? 1 : 0;
                            char c11 = r3 == true ? 1 : 0;
                            iArr2[c2] = i5;
                            iArr2[i2] = nextSet;
                            iArr2[2] = i8;
                            int i19 = iArr2[2];
                            ArrayList arrayList = new ArrayList(20);
                            arrayList.add(Byte.valueOf((byte) i19));
                            switch (i19) {
                                case 103:
                                    c = 'e';
                                    break;
                                case 104:
                                    c = 'd';
                                    break;
                                case 105:
                                    c = 'c';
                                    break;
                                default:
                                    throw FormatException.getFormatInstance();
                            }
                            StringBuilder sb = new StringBuilder(20);
                            int i20 = iArr2[r3];
                            int i21 = iArr2[i2];
                            int[] iArr3 = new int[i4];
                            char c12 = c;
                            boolean z5 = false;
                            boolean z6 = false;
                            boolean z7 = true;
                            boolean z8 = false;
                            int i22 = 0;
                            int i23 = 0;
                            int i24 = 0;
                            int i25 = i20;
                            int i26 = i21;
                            boolean z9 = r3;
                            while (!z6) {
                                OneDReader.recordPattern(bitArray, i26, iArr3);
                                int i27 = -1;
                                int i28 = 0;
                                float f3 = 0.25f;
                                while (true) {
                                    int[][] iArr4 = CODE_PATTERNS;
                                    if (i28 < iArr4.length) {
                                        float patternMatchVariance2 = OneDReader.patternMatchVariance(iArr3, iArr4[i28], f);
                                        if (patternMatchVariance2 < f3) {
                                            f3 = patternMatchVariance2;
                                            i27 = i28;
                                        }
                                        i28++;
                                    } else if (i27 >= 0) {
                                        arrayList.add(Byte.valueOf((byte) i27));
                                        if (i27 != 106) {
                                            z7 = true;
                                        }
                                        if (i27 != 106) {
                                            i23++;
                                            i19 = (i23 * i27) + i19;
                                        }
                                        int i29 = i26;
                                        for (int i30 = 0; i30 < 6; i30++) {
                                            i29 += iArr3[i30];
                                        }
                                        switch (i27) {
                                            case 103:
                                            case 104:
                                            case 105:
                                                throw FormatException.getFormatInstance();
                                            default:
                                                switch (c12) {
                                                    case 'c':
                                                        if (i27 >= 100) {
                                                            if (i27 != 106) {
                                                                z7 = false;
                                                            }
                                                            if (i27 != 106) {
                                                                switch (i27) {
                                                                    case 100:
                                                                        z = false;
                                                                        c12 = 'd';
                                                                        z2 = z9;
                                                                        break;
                                                                    case 101:
                                                                        z = false;
                                                                        c12 = 'e';
                                                                        z2 = z9;
                                                                        break;
                                                                    case 102:
                                                                        if (z3) {
                                                                            if (sb.length() == 0) {
                                                                                sb.append("]C1");
                                                                            } else {
                                                                                sb.append((char) 29);
                                                                            }
                                                                        }
                                                                    default:
                                                                        z = false;
                                                                        z2 = z9;
                                                                        break;
                                                                }
                                                            } else {
                                                                z = false;
                                                                z6 = true;
                                                                z2 = z9;
                                                                break;
                                                            }
                                                        } else {
                                                            if (i27 < 10) {
                                                                sb.append('0');
                                                            }
                                                            sb.append(i27);
                                                        }
                                                        z = false;
                                                        z2 = z9;
                                                    case 'd':
                                                        if (i27 < 96) {
                                                            if (z9 == z5) {
                                                                sb.append((char) (i27 + 32));
                                                            } else {
                                                                sb.append((char) (i27 + 32 + 128));
                                                            }
                                                            z9 = false;
                                                            z = false;
                                                            z2 = z9;
                                                            break;
                                                        } else {
                                                            if (i27 != 106) {
                                                                z7 = false;
                                                            }
                                                            if (i27 != 106) {
                                                                switch (i27) {
                                                                    case 96:
                                                                    case 97:
                                                                    default:
                                                                        z = false;
                                                                        z2 = z9;
                                                                        break;
                                                                    case 98:
                                                                        z = true;
                                                                        c12 = 'e';
                                                                        z2 = z9;
                                                                        break;
                                                                    case 99:
                                                                        z = false;
                                                                        c12 = 'c';
                                                                        z2 = z9;
                                                                        break;
                                                                    case 100:
                                                                        if (z5 || !z9) {
                                                                            if (z5) {
                                                                            }
                                                                            z9 = true;
                                                                            z = false;
                                                                            z2 = z9;
                                                                            break;
                                                                        }
                                                                        z2 = false;
                                                                        z = false;
                                                                        z5 = true;
                                                                        break;
                                                                    case 101:
                                                                        z = false;
                                                                        c12 = 'e';
                                                                        z2 = z9;
                                                                        break;
                                                                    case 102:
                                                                        if (z3) {
                                                                            if (sb.length() == 0) {
                                                                                sb.append("]C1");
                                                                            } else {
                                                                                sb.append((char) 29);
                                                                            }
                                                                        }
                                                                        z = false;
                                                                        z2 = z9;
                                                                        break;
                                                                }
                                                            }
                                                            z6 = true;
                                                            z = false;
                                                            z2 = z9;
                                                        }
                                                        break;
                                                    case 'e':
                                                        if (i27 < 64) {
                                                            if (z9 == z5) {
                                                                sb.append((char) (i27 + 32));
                                                            } else {
                                                                sb.append((char) (i27 + 32 + 128));
                                                            }
                                                        } else if (i27 >= 96) {
                                                            if (i27 != 106) {
                                                                z7 = false;
                                                            }
                                                            if (i27 != 106) {
                                                                switch (i27) {
                                                                    case 98:
                                                                        z = true;
                                                                        c12 = 'd';
                                                                        z2 = z9;
                                                                        break;
                                                                    case 100:
                                                                        z = false;
                                                                        c12 = 'd';
                                                                        z2 = z9;
                                                                        break;
                                                                    case 101:
                                                                        if (z5 || !z9) {
                                                                            if (z5) {
                                                                            }
                                                                            z9 = true;
                                                                            z = false;
                                                                            z2 = z9;
                                                                            break;
                                                                        }
                                                                        z2 = false;
                                                                        z = false;
                                                                        z5 = true;
                                                                        break;
                                                                    case 102:
                                                                        if (z3) {
                                                                            if (sb.length() == 0) {
                                                                                sb.append("]C1");
                                                                            } else {
                                                                                sb.append((char) 29);
                                                                            }
                                                                        }
                                                                        z = false;
                                                                        z2 = z9;
                                                                        break;
                                                                }
                                                            }
                                                            z6 = true;
                                                            z = false;
                                                            z2 = z9;
                                                        } else if (z9 == z5) {
                                                            sb.append((char) (i27 - 64));
                                                        } else {
                                                            sb.append((char) (i27 + 64));
                                                        }
                                                        z9 = false;
                                                        z = false;
                                                        z2 = z9;
                                                        break;
                                                }
                                                if (z8) {
                                                    c12 = c12 == 'e' ? 'd' : 'e';
                                                }
                                                z8 = z;
                                                i24 = i22;
                                                f = 0.7f;
                                                i22 = i27;
                                                i25 = i26;
                                                i26 = i29;
                                                z9 = z2;
                                                break;
                                        }
                                    } else {
                                        throw NotFoundException.getNotFoundInstance();
                                    }
                                }
                            }
                            int i31 = i26 - i25;
                            int nextUnset = bitArray.getNextUnset(i26);
                            if (!bitArray.isRange(nextUnset, Math.min(bitArray.size, ((nextUnset - i25) / 2) + nextUnset), false)) {
                                throw NotFoundException.getNotFoundInstance();
                            } else if ((i19 - (i23 * i24)) % 103 == i24) {
                                int length = sb.length();
                                if (length != 0) {
                                    if (length > 0 && z7) {
                                        if (c12 == 'c') {
                                            sb.delete(length - 2, length);
                                        } else {
                                            sb.delete(length - 1, length);
                                        }
                                    }
                                    float f4 = ((float) (iArr2[1] + iArr2[0])) / 2.0f;
                                    float f5 = (((float) i31) / 2.0f) + ((float) i25);
                                    int size = arrayList.size();
                                    byte[] bArr = new byte[size];
                                    for (int i32 = 0; i32 < size; i32++) {
                                        bArr[i32] = ((Byte) arrayList.get(i32)).byteValue();
                                    }
                                    float f6 = (float) i;
                                    return new Result(sb.toString(), bArr, new ResultPoint[]{new ResultPoint(f4, f6), new ResultPoint(f5, f6)}, BarcodeFormat.CODE_128);
                                }
                                throw NotFoundException.getNotFoundInstance();
                            } else {
                                throw ChecksumException.getChecksumInstance();
                            }
                        }
                    }
                    i5 += iArr[0] + iArr[1];
                    System.arraycopy(iArr, 2, iArr, 0, 4);
                    iArr[4] = 0;
                    iArr[5] = 0;
                    i6--;
                } else {
                    i6++;
                }
                iArr[i6] = 1;
                z4 = !z4;
            }
            nextSet++;
            i2 = 1;
            r3 = 0;
            i4 = 6;
        }
        throw NotFoundException.getNotFoundInstance();
    }
}
