package io.netty.resolver;

import com.android.tools.r8.GeneratedOutlineSupport;
import io.netty.util.NetUtil;
import io.netty.util.internal.ObjectUtil;
import io.netty.util.internal.PlatformDependent;
import io.netty.util.internal.logging.InternalLogger;
import io.netty.util.internal.logging.InternalLoggerFactory;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.Reader;
import java.net.Inet4Address;
import java.net.InetAddress;
import java.nio.charset.Charset;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.regex.Pattern;

public final class HostsFileEntriesProvider {
    public static final HostsFileEntriesProvider EMPTY = new HostsFileEntriesProvider(Collections.emptyMap(), Collections.emptyMap());
    private final Map<String, List<InetAddress>> ipv4Entries;
    private final Map<String, List<InetAddress>> ipv6Entries;

    public interface Parser {
        HostsFileEntriesProvider parse();

        HostsFileEntriesProvider parse(File file, Charset... charsetArr);

        HostsFileEntriesProvider parse(Reader reader);

        HostsFileEntriesProvider parse(Charset... charsetArr);

        HostsFileEntriesProvider parseSilently();

        HostsFileEntriesProvider parseSilently(File file, Charset... charsetArr);

        HostsFileEntriesProvider parseSilently(Charset... charsetArr);
    }

    public static final class ParserImpl implements Parser {
        public static final ParserImpl INSTANCE = new ParserImpl();
        private static final Pattern WHITESPACES = Pattern.compile("[ \t]+");
        private static final String WINDOWS_DEFAULT_SYSTEM_ROOT = "C:\\Windows";
        private static final String WINDOWS_HOSTS_FILE_RELATIVE_PATH = "\\system32\\drivers\\etc\\hosts";
        private static final String X_PLATFORMS_HOSTS_FILE_PATH = "/etc/hosts";
        private static final InternalLogger logger = InternalLoggerFactory.getInstance(Parser.class);

        private ParserImpl() {
        }

        private static File locateHostsFile() {
            if (!PlatformDependent.isWindows()) {
                return new File(X_PLATFORMS_HOSTS_FILE_PATH);
            }
            File file = new File(System.getenv("SystemRoot") + WINDOWS_HOSTS_FILE_RELATIVE_PATH);
            if (!file.exists()) {
                return new File("C:\\Windows\\system32\\drivers\\etc\\hosts");
            }
            return file;
        }

        @Override // io.netty.resolver.HostsFileEntriesProvider.Parser
        public HostsFileEntriesProvider parse() {
            return parse(locateHostsFile(), Charset.defaultCharset());
        }

        @Override // io.netty.resolver.HostsFileEntriesProvider.Parser
        public HostsFileEntriesProvider parseSilently() {
            return parseSilently(locateHostsFile(), Charset.defaultCharset());
        }

        @Override // io.netty.resolver.HostsFileEntriesProvider.Parser
        public HostsFileEntriesProvider parse(Charset... charsetArr) {
            return parse(locateHostsFile(), charsetArr);
        }

        @Override // io.netty.resolver.HostsFileEntriesProvider.Parser
        public HostsFileEntriesProvider parseSilently(Charset... charsetArr) {
            return parseSilently(locateHostsFile(), charsetArr);
        }

        /* JADX INFO: finally extract failed */
        @Override // io.netty.resolver.HostsFileEntriesProvider.Parser
        public HostsFileEntriesProvider parse(File file, Charset... charsetArr) {
            ObjectUtil.checkNotNull(file, "file");
            ObjectUtil.checkNotNull(charsetArr, "charsets");
            if (charsetArr.length == 0) {
                charsetArr = new Charset[]{Charset.defaultCharset()};
            }
            if (file.exists() && file.isFile()) {
                for (Charset charset : charsetArr) {
                    BufferedReader bufferedReader = new BufferedReader(new InputStreamReader(new FileInputStream(file), charset));
                    try {
                        HostsFileEntriesProvider parse = parse(bufferedReader);
                        if (parse != HostsFileEntriesProvider.EMPTY) {
                            bufferedReader.close();
                            return parse;
                        }
                        bufferedReader.close();
                    } catch (Throwable th) {
                        bufferedReader.close();
                        throw th;
                    }
                }
            }
            return HostsFileEntriesProvider.EMPTY;
        }

        @Override // io.netty.resolver.HostsFileEntriesProvider.Parser
        public HostsFileEntriesProvider parseSilently(File file, Charset... charsetArr) {
            try {
                return parse(file, charsetArr);
            } catch (IOException e) {
                if (logger.isWarnEnabled()) {
                    InternalLogger internalLogger = logger;
                    StringBuilder outline25 = GeneratedOutlineSupport.outline25("Failed to load and parse hosts file at ");
                    outline25.append(file.getPath());
                    internalLogger.warn(outline25.toString(), (Throwable) e);
                }
                return HostsFileEntriesProvider.EMPTY;
            }
        }

        @Override // io.netty.resolver.HostsFileEntriesProvider.Parser
        public HostsFileEntriesProvider parse(Reader reader) {
            List list;
            ObjectUtil.checkNotNull(reader, "reader");
            BufferedReader bufferedReader = new BufferedReader(reader);
            try {
                HashMap hashMap = new HashMap();
                HashMap hashMap2 = new HashMap();
                while (true) {
                    String readLine = bufferedReader.readLine();
                    if (readLine == null) {
                        break;
                    }
                    int indexOf = readLine.indexOf(35);
                    if (indexOf != -1) {
                        readLine = readLine.substring(0, indexOf);
                    }
                    String trim = readLine.trim();
                    if (!trim.isEmpty()) {
                        ArrayList arrayList = new ArrayList();
                        String[] split = WHITESPACES.split(trim);
                        for (String str : split) {
                            if (!str.isEmpty()) {
                                arrayList.add(str);
                            }
                        }
                        if (arrayList.size() >= 2) {
                            byte[] createByteArrayFromIpAddressString = NetUtil.createByteArrayFromIpAddressString((String) arrayList.get(0));
                            if (createByteArrayFromIpAddressString != null) {
                                for (int i = 1; i < arrayList.size(); i++) {
                                    String str2 = (String) arrayList.get(i);
                                    String lowerCase = str2.toLowerCase(Locale.ENGLISH);
                                    InetAddress byAddress = InetAddress.getByAddress(str2, createByteArrayFromIpAddressString);
                                    if (byAddress instanceof Inet4Address) {
                                        list = (List) hashMap.get(lowerCase);
                                        if (list == null) {
                                            list = new ArrayList();
                                            hashMap.put(lowerCase, list);
                                        }
                                    } else {
                                        list = (List) hashMap2.get(lowerCase);
                                        if (list == null) {
                                            list = new ArrayList();
                                            hashMap2.put(lowerCase, list);
                                        }
                                    }
                                    list.add(byAddress);
                                }
                            }
                        }
                    }
                }
                return (!hashMap.isEmpty() || !hashMap2.isEmpty()) ? new HostsFileEntriesProvider(hashMap, hashMap2) : HostsFileEntriesProvider.EMPTY;
            } finally {
                try {
                    bufferedReader.close();
                } catch (IOException e) {
                    logger.warn("Failed to close a reader", (Throwable) e);
                }
            }
        }
    }

    public HostsFileEntriesProvider(Map<String, List<InetAddress>> map, Map<String, List<InetAddress>> map2) {
        this.ipv4Entries = Collections.unmodifiableMap(new HashMap(map));
        this.ipv6Entries = Collections.unmodifiableMap(new HashMap(map2));
    }

    public static Parser parser() {
        return ParserImpl.INSTANCE;
    }

    public Map<String, List<InetAddress>> ipv4Entries() {
        return this.ipv4Entries;
    }

    public Map<String, List<InetAddress>> ipv6Entries() {
        return this.ipv6Entries;
    }
}
