package okhttp3.internal.http2;

import com.faster.cheetah.sdk.strongswan.data.VpnProfileDataSource;
import java.io.IOException;
import java.net.ProtocolException;
import java.util.ArrayList;
import java.util.List;
import java.util.Locale;
import java.util.Objects;
import java.util.concurrent.TimeUnit;
import kotlin.jvm.internal.Intrinsics;
import kotlin.text.StringsKt__IndentKt;
import okhttp3.Headers;
import okhttp3.HttpUrl;
import okhttp3.OkHttpClient;
import okhttp3.Protocol;
import okhttp3.Request;
import okhttp3.Response;
import okhttp3.internal.Util;
import okhttp3.internal.connection.RealConnection;
import okhttp3.internal.http.ExchangeCodec;
import okhttp3.internal.http.HttpHeaders;
import okhttp3.internal.http.RealInterceptorChain;
import okhttp3.internal.http.StatusLine;
import okhttp3.internal.http2.Http2Stream;
import okio.ByteString;
import okio.Sink;
import okio.Source;

/* compiled from: Http2ExchangeCodec.kt */
public final class Http2ExchangeCodec implements ExchangeCodec {
    public static final List<String> HTTP_2_SKIPPED_REQUEST_HEADERS = Util.immutableListOf("connection", "host", "keep-alive", "proxy-connection", "te", "transfer-encoding", "encoding", "upgrade", ":method", ":path", ":scheme", ":authority");
    public static final List<String> HTTP_2_SKIPPED_RESPONSE_HEADERS = Util.immutableListOf("connection", "host", "keep-alive", "proxy-connection", "te", "transfer-encoding", "encoding", "upgrade");
    public volatile boolean canceled;
    public final RealInterceptorChain chain;
    public final RealConnection connection;
    public final Http2Connection http2Connection;
    public final Protocol protocol;
    public volatile Http2Stream stream;

    public Http2ExchangeCodec(OkHttpClient okHttpClient, RealConnection realConnection, RealInterceptorChain realInterceptorChain, Http2Connection http2Connection2) {
        Intrinsics.checkNotNullParameter(okHttpClient, "client");
        Intrinsics.checkNotNullParameter(realConnection, "connection");
        Intrinsics.checkNotNullParameter(realInterceptorChain, "chain");
        Intrinsics.checkNotNullParameter(http2Connection2, "http2Connection");
        this.connection = realConnection;
        this.chain = realInterceptorChain;
        this.http2Connection = http2Connection2;
        List<Protocol> list = okHttpClient.protocols;
        Protocol protocol2 = Protocol.H2_PRIOR_KNOWLEDGE;
        this.protocol = !list.contains(protocol2) ? Protocol.HTTP_2 : protocol2;
    }

    @Override // okhttp3.internal.http.ExchangeCodec
    public void cancel() {
        this.canceled = true;
        Http2Stream http2Stream = this.stream;
        if (http2Stream != null) {
            http2Stream.closeLater(ErrorCode.CANCEL);
        }
    }

    @Override // okhttp3.internal.http.ExchangeCodec
    public Sink createRequestBody(Request request, long j) {
        Intrinsics.checkNotNullParameter(request, "request");
        Http2Stream http2Stream = this.stream;
        Intrinsics.checkNotNull(http2Stream);
        return http2Stream.getSink();
    }

    @Override // okhttp3.internal.http.ExchangeCodec
    public void finishRequest() {
        Http2Stream http2Stream = this.stream;
        Intrinsics.checkNotNull(http2Stream);
        ((Http2Stream.FramingSink) http2Stream.getSink()).close();
    }

    @Override // okhttp3.internal.http.ExchangeCodec
    public void flushRequest() {
        this.http2Connection.writer.flush();
    }

    @Override // okhttp3.internal.http.ExchangeCodec
    public RealConnection getConnection() {
        return this.connection;
    }

    @Override // okhttp3.internal.http.ExchangeCodec
    public Source openResponseBodySource(Response response) {
        Intrinsics.checkNotNullParameter(response, "response");
        Http2Stream http2Stream = this.stream;
        Intrinsics.checkNotNull(http2Stream);
        return http2Stream.source;
    }

    /* JADX INFO: finally extract failed */
    @Override // okhttp3.internal.http.ExchangeCodec
    public Response.Builder readResponseHeaders(boolean z) {
        Headers headers;
        Http2Stream http2Stream = this.stream;
        Intrinsics.checkNotNull(http2Stream);
        synchronized (http2Stream) {
            http2Stream.readTimeout.enter();
            while (http2Stream.headersQueue.isEmpty() && http2Stream.errorCode == null) {
                try {
                    http2Stream.waitForIo$okhttp();
                } catch (Throwable th) {
                    http2Stream.readTimeout.exitAndThrowIfTimedOut();
                    throw th;
                }
            }
            http2Stream.readTimeout.exitAndThrowIfTimedOut();
            if (!http2Stream.headersQueue.isEmpty()) {
                Headers removeFirst = http2Stream.headersQueue.removeFirst();
                Intrinsics.checkNotNullExpressionValue(removeFirst, "headersQueue.removeFirst()");
                headers = removeFirst;
            } else {
                IOException iOException = http2Stream.errorException;
                if (iOException != null) {
                    throw iOException;
                }
                ErrorCode errorCode = http2Stream.errorCode;
                Intrinsics.checkNotNull(errorCode);
                throw new StreamResetException(errorCode);
            }
        }
        Protocol protocol2 = this.protocol;
        Intrinsics.checkNotNullParameter(headers, "headerBlock");
        Intrinsics.checkNotNullParameter(protocol2, "protocol");
        ArrayList arrayList = new ArrayList(20);
        int size = headers.size();
        StatusLine statusLine = null;
        for (int i = 0; i < size; i++) {
            String name = headers.name(i);
            String value = headers.value(i);
            if (Intrinsics.areEqual(name, ":status")) {
                statusLine = StatusLine.parse("HTTP/1.1 " + value);
            } else if (!HTTP_2_SKIPPED_RESPONSE_HEADERS.contains(name)) {
                Intrinsics.checkNotNullParameter(name, VpnProfileDataSource.KEY_NAME);
                Intrinsics.checkNotNullParameter(value, "value");
                arrayList.add(name);
                arrayList.add(StringsKt__IndentKt.trim(value).toString());
            }
        }
        if (statusLine != null) {
            Response.Builder builder = new Response.Builder();
            builder.protocol(protocol2);
            builder.code = statusLine.code;
            builder.message(statusLine.message);
            Object[] array = arrayList.toArray(new String[0]);
            Objects.requireNonNull(array, "null cannot be cast to non-null type kotlin.Array<T>");
            builder.headers(new Headers((String[]) array, null));
            if (!z || builder.code != 100) {
                return builder;
            }
            return null;
        }
        throw new ProtocolException("Expected ':status' header not present");
    }

    @Override // okhttp3.internal.http.ExchangeCodec
    public long reportedContentLength(Response response) {
        Intrinsics.checkNotNullParameter(response, "response");
        if (!HttpHeaders.promisesBody(response)) {
            return 0;
        }
        return Util.headersContentLength(response);
    }

    @Override // okhttp3.internal.http.ExchangeCodec
    public void writeRequestHeaders(Request request) {
        int i;
        Http2Stream http2Stream;
        Intrinsics.checkNotNullParameter(request, "request");
        if (this.stream == null) {
            boolean z = false;
            boolean z2 = request.body != null;
            Intrinsics.checkNotNullParameter(request, "request");
            Headers headers = request.headers;
            ArrayList arrayList = new ArrayList(headers.size() + 4);
            arrayList.add(new Header(Header.TARGET_METHOD, request.method));
            ByteString byteString = Header.TARGET_PATH;
            HttpUrl httpUrl = request.url;
            Intrinsics.checkNotNullParameter(httpUrl, "url");
            String encodedPath = httpUrl.encodedPath();
            String encodedQuery = httpUrl.encodedQuery();
            if (encodedQuery != null) {
                encodedPath = encodedPath + '?' + encodedQuery;
            }
            arrayList.add(new Header(byteString, encodedPath));
            String header = request.header("Host");
            if (header != null) {
                arrayList.add(new Header(Header.TARGET_AUTHORITY, header));
            }
            arrayList.add(new Header(Header.TARGET_SCHEME, request.url.scheme));
            int size = headers.size();
            for (int i2 = 0; i2 < size; i2++) {
                String name = headers.name(i2);
                Locale locale = Locale.US;
                Intrinsics.checkNotNullExpressionValue(locale, "Locale.US");
                Objects.requireNonNull(name, "null cannot be cast to non-null type java.lang.String");
                String lowerCase = name.toLowerCase(locale);
                Intrinsics.checkNotNullExpressionValue(lowerCase, "(this as java.lang.String).toLowerCase(locale)");
                if (!HTTP_2_SKIPPED_REQUEST_HEADERS.contains(lowerCase) || (Intrinsics.areEqual(lowerCase, "te") && Intrinsics.areEqual(headers.value(i2), "trailers"))) {
                    arrayList.add(new Header(lowerCase, headers.value(i2)));
                }
            }
            Http2Connection http2Connection2 = this.http2Connection;
            Objects.requireNonNull(http2Connection2);
            Intrinsics.checkNotNullParameter(arrayList, "requestHeaders");
            boolean z3 = !z2;
            synchronized (http2Connection2.writer) {
                synchronized (http2Connection2) {
                    if (http2Connection2.nextStreamId > 1073741823) {
                        http2Connection2.shutdown(ErrorCode.REFUSED_STREAM);
                    }
                    if (!http2Connection2.isShutdown) {
                        i = http2Connection2.nextStreamId;
                        http2Connection2.nextStreamId = i + 2;
                        http2Stream = new Http2Stream(i, http2Connection2, z3, false, null);
                        if (!z2 || http2Connection2.writeBytesTotal >= http2Connection2.writeBytesMaximum || http2Stream.writeBytesTotal >= http2Stream.writeBytesMaximum) {
                            z = true;
                        }
                        if (http2Stream.isOpen()) {
                            http2Connection2.streams.put(Integer.valueOf(i), http2Stream);
                        }
                    } else {
                        throw new ConnectionShutdownException();
                    }
                }
                http2Connection2.writer.headers(z3, i, arrayList);
            }
            if (z) {
                http2Connection2.writer.flush();
            }
            this.stream = http2Stream;
            if (!this.canceled) {
                Http2Stream http2Stream2 = this.stream;
                Intrinsics.checkNotNull(http2Stream2);
                TimeUnit timeUnit = TimeUnit.MILLISECONDS;
                http2Stream2.readTimeout.timeout((long) this.chain.readTimeoutMillis, timeUnit);
                Http2Stream http2Stream3 = this.stream;
                Intrinsics.checkNotNull(http2Stream3);
                http2Stream3.writeTimeout.timeout((long) this.chain.writeTimeoutMillis, timeUnit);
                return;
            }
            Http2Stream http2Stream4 = this.stream;
            Intrinsics.checkNotNull(http2Stream4);
            http2Stream4.closeLater(ErrorCode.CANCEL);
            throw new IOException("Canceled");
        }
    }
}
