package org.bouncycastle.crypto.engines;

import kotlinx.coroutines.internal.SystemPropsKt;
import org.bouncycastle.crypto.CipherParameters;
import org.bouncycastle.crypto.DataLengthException;
import org.bouncycastle.crypto.MaxBytesExceededException;
import org.bouncycastle.crypto.OutputLengthException;
import org.bouncycastle.crypto.StreamCipher;
import org.bouncycastle.crypto.params.KeyParameter;
import org.bouncycastle.crypto.params.ParametersWithIV;
import org.bouncycastle.util.Strings;

public abstract class Salsa20Engine implements StreamCipher {
    public static final int[] TAU_SIGMA;
    public int cW0;
    public int cW1;
    public int cW2;
    public int[] engineState = new int[16];
    public int index = 0;
    public boolean initialised = false;
    public byte[] keyStream = new byte[64];
    public int rounds = 20;
    public int[] x = new int[16];

    static {
        byte[] byteArray = Strings.toByteArray("expand 16-byte kexpand 32-byte k");
        int[] iArr = new int[8];
        int i = 0;
        for (int i2 = 0; i2 < 8; i2++) {
            iArr[i2] = SystemPropsKt.littleEndianToInt(byteArray, i);
            i += 4;
        }
        TAU_SIGMA = iArr;
        Strings.toByteArray("expand 32-byte k");
        Strings.toByteArray("expand 16-byte k");
    }

    public static int rotl(int i, int i2) {
        return (i >>> (-i2)) | (i << i2);
    }

    public abstract void advanceCounter();

    public abstract void generateKeyStream(byte[] bArr);

    public abstract String getAlgorithmName();

    public int getNonceSize() {
        return 8;
    }

    @Override // org.bouncycastle.crypto.StreamCipher
    public void init(boolean z, CipherParameters cipherParameters) {
        if (cipherParameters instanceof ParametersWithIV) {
            ParametersWithIV parametersWithIV = (ParametersWithIV) cipherParameters;
            byte[] bArr = parametersWithIV.iv;
            if (bArr == null || bArr.length != getNonceSize()) {
                throw new IllegalArgumentException(getAlgorithmName() + " requires exactly " + getNonceSize() + " bytes of IV");
            }
            CipherParameters cipherParameters2 = parametersWithIV.parameters;
            if (cipherParameters2 == null) {
                if (this.initialised) {
                    setKey(null, bArr);
                } else {
                    throw new IllegalStateException(getAlgorithmName() + " KeyParameter can not be null for first initialisation");
                }
            } else if (cipherParameters2 instanceof KeyParameter) {
                setKey(((KeyParameter) cipherParameters2).key, bArr);
            } else {
                throw new IllegalArgumentException(getAlgorithmName() + " Init parameters must contain a KeyParameter (or null for re-init)");
            }
            this.index = 0;
            this.cW0 = 0;
            this.cW1 = 0;
            this.cW2 = 0;
            resetCounter();
            generateKeyStream(this.keyStream);
            this.initialised = true;
            return;
        }
        throw new IllegalArgumentException(getAlgorithmName() + " Init parameters must include an IV");
    }

    public void packTauOrSigma(int i, int[] iArr, int i2) {
        int i3 = (i - 16) / 4;
        int[] iArr2 = TAU_SIGMA;
        iArr[i2] = iArr2[i3];
        iArr[i2 + 1] = iArr2[i3 + 1];
        iArr[i2 + 2] = iArr2[i3 + 2];
        iArr[i2 + 3] = iArr2[i3 + 3];
    }

    /* JADX WARNING: Removed duplicated region for block: B:16:0x002e A[LOOP:0: B:16:0x002e->B:20:0x004f, LOOP_START, PHI: r1 
      PHI: (r1v3 int) = (r1v2 int), (r1v4 int) binds: [B:15:0x002c, B:20:0x004f] A[DONT_GENERATE, DONT_INLINE]] */
    /* JADX WARNING: Removed duplicated region for block: B:22:0x0053  */
    @Override // org.bouncycastle.crypto.StreamCipher
    public int processBytes(byte[] bArr, int i, int i2, byte[] bArr2, int i3) {
        boolean z;
        if (!this.initialised) {
            throw new IllegalStateException(getAlgorithmName() + " not initialised");
        } else if (i + i2 > bArr.length) {
            throw new DataLengthException("input buffer too short");
        } else if (i3 + i2 <= bArr2.length) {
            int i4 = this.cW0 + i2;
            this.cW0 = i4;
            if (i4 < i2 && i4 >= 0) {
                int i5 = this.cW1 + 1;
                this.cW1 = i5;
                if (i5 == 0) {
                    int i6 = this.cW2 + 1;
                    this.cW2 = i6;
                    if ((i6 & 32) != 0) {
                        z = true;
                        if (z) {
                            for (int i7 = 0; i7 < i2; i7++) {
                                byte[] bArr3 = this.keyStream;
                                int i8 = this.index;
                                bArr2[i7 + i3] = (byte) (bArr3[i8] ^ bArr[i7 + i]);
                                int i9 = (i8 + 1) & 63;
                                this.index = i9;
                                if (i9 == 0) {
                                    advanceCounter();
                                    generateKeyStream(this.keyStream);
                                }
                            }
                            return i2;
                        }
                        throw new MaxBytesExceededException("2^70 byte limit per IV would be exceeded; Change IV");
                    }
                }
            }
            z = false;
            if (z) {
            }
        } else {
            throw new OutputLengthException("output buffer too short");
        }
    }

    public abstract void resetCounter();

    public abstract void setKey(byte[] bArr, byte[] bArr2);
}
